package com.sunxung.factoring.component.annotation;

import static java.lang.annotation.ElementType.ANNOTATION_TYPE;
import static java.lang.annotation.ElementType.CONSTRUCTOR;
import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.PARAMETER;
import static java.lang.annotation.RetentionPolicy.RUNTIME;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;
import javax.validation.Constraint;
import javax.validation.Payload;

import com.sunxung.factoring.component.validator.ConstraintEntityValidator;

/**
 * @Description 1：自定义对象或者对象属性验证。
 * @author zhuhao
 * @date 2017年2月23日10:43:02
 * @version 1.0
 */
@Constraint(validatedBy = {
        ConstraintEntityValidator.class
})
@Target({
        METHOD, FIELD, ANNOTATION_TYPE, CONSTRUCTOR, PARAMETER
})
@Retention(RUNTIME)
public @interface ObjectValidator {

    /**
     * 1：需要验证的属性，通过方法。
     * 
     * @return
     */
    String fieldName() default "id";

    /**
     * 1：自定义校验信息。
     * 
     * @return
     */
    String message() default "{com.sunxung.factoring.component.annotation.ObjectValidator.message}";

    /**
     * 1：分组。
     * 
     * @return
     */
    Class<?>[] groups() default {};

    /**
     * 1：负载。
     * 
     * @return
     */
    Class<? extends Payload>[] payload() default {};

    /**
     * 1：指定多个时使用。
     * 
     * @author
     */
    @Target({
            FIELD, METHOD, PARAMETER, ANNOTATION_TYPE
    })
    @Retention(RUNTIME)
    @interface List {

        ObjectValidator[] value();
    }
}
