package com.sunxung.factoring.component.constance;

import java.math.BigDecimal;

/**
 * 供应商打分模型
 */
public class SupplierScoringModel {

    /**
     * 企业主体基本情况 权重体系
     */
    public static final BigDecimal ENTERPRISE_RATIO = new BigDecimal("0.1");
    /**
     * 股东标准分
     */
    public static final BigDecimal SHAREHOLDER_STANDARD = BigDecimal.TEN;
    /**
     * 成立年限准分
     */
    public static final BigDecimal ESTABLISHMENT_PERIOD_STANDARD = new BigDecimal("15");
    /**
     * 注册资本标准分
     */
    public static final BigDecimal REGISTERED_CAPITAL_STANDARD = new BigDecimal("15");
    /**
     * 注册地址标准分1
     */
    public static final BigDecimal REGISTERED_ADDRESS_STANDARD_ONE = new BigDecimal("10");
    /**
     * 注册地址标准分2
     */
    public static final BigDecimal REGISTERED_ADDRESS_STANDARD_TWO = new BigDecimal("8");
    /**
     * 注册地址标准分3
     */
    public static final BigDecimal REGISTERED_ADDRESS_STANDARD_THREE = new BigDecimal("6");
    /**
     * 注册地址标准分4
     */
    public static final BigDecimal REGISTERED_ADDRESS_STANDARD_FORE = new BigDecimal("4");
    /**
     * 注册地址标准分5
     */
    public static final BigDecimal REGISTERED_ADDRESS_STANDARD_FIVE = new BigDecimal("2");
    /**
     * 注册地址标准分6
     */
    public static final BigDecimal REGISTERED_ADDRESS_STANDARD_SIX = new BigDecimal("2");
    /**
     * 注册地址标准分7
     */
    public static final BigDecimal REGISTERED_ADDRESS_STANDARD_SEVEN = BigDecimal.ONE;
    /**
     * 注册地址标准分8
     */
    public static final BigDecimal REGISTERED_ADDRESS_STANDARD_EIGHT = BigDecimal.ZERO;
    /**
     * 定位图、租房合同、房屋房费缴纳流水、办公环境照片得分总和。标准分
     */
    public static final BigDecimal PICTURES_STANDARD = new BigDecimal("20");
    /**
     * 所属行业标准分
     */
    public static final BigDecimal INDUSTRY_STANDARD = BigDecimal.ZERO;
    /**
     * 经营范围标准分
     */
    public static final BigDecimal BUSINESS_SCOPE_STANDARD = BigDecimal.TEN;
    /**
     * 基本变动信息标准分
     */
    public static final BigDecimal BASIC_CHANGE_STANDARD = BigDecimal.TEN;
    /**
     * 关联企业标准分
     */
    public static final BigDecimal ASSOCIATED_ENTERPRISE_STANDARD = BigDecimal.ZERO;

    /**
     * 人员 权重体系
     */
    public static final BigDecimal PERSON_RATIO = new BigDecimal("0.4");
    /**
     * 无逾期
     */
    public static final BigDecimal NO_OVERDUE_STANDARD = new BigDecimal("15");
    /**
     * 近两年发生过逾期的账户数＜3且合计金额＜5000元
     */
    public static final BigDecimal OVERDUE_STANDARD_ONE = new BigDecimal("10");
    /**
     * 近两年发生过逾期的账户数＜3且合计金额≥5000元
     */
    public static final BigDecimal OVERDUE_STANDARD_TWO = new BigDecimal("5");
    /**
     * 近两年发生过逾期的账户数≥3且合计金额＜5000元
     */
    public static final BigDecimal OVERDUE_STANDARD_THREE = new BigDecimal("5");
    /**
     * 近两年发生过逾期的账户数≥3且合计金额≥5000元
     */
    public static final BigDecimal OVERDUE_STANDARD_FORE = new BigDecimal("0");
    /**
     * 发生过90天以上逾期的账户数=0
     */
    public static final BigDecimal OVERDUE_90DAYS_STANDARD_ONE = new BigDecimal("15");
    /**
     * 发生过90天以上逾期的账户数≥1
     */
    public static final BigDecimal OVERDUE_90DAYS_STANDARD_TWO = new BigDecimal("0");
    /**
     * 近两年贷款、信用卡无逾期且近两年无逾期还款记录
     */
    public static final BigDecimal OVERDUE_THREE_SIX_STANDARD_ONE = new BigDecimal("15");
    /**
     * 近两年贷款、信用卡无逾期且近两年逾期还款记录累计次数≤5次
     */
    public static final BigDecimal OVERDUE_THREE_SIX_STANDARD_TWO = new BigDecimal("10");
    /**
     * 近两年贷款、信用卡无逾期且近两年逾期还款记录累计次数＞5次
     */
    public static final BigDecimal OVERDUE_THREE_SIX_STANDARD_THREE = new BigDecimal("5");
    /**
     * 近两年贷款、信用卡连续1个月或2个月逾期且近两年无逾期还款记录
     */
    public static final BigDecimal OVERDUE_THREE_SIX_STANDARD_FORE = new BigDecimal("10");
    /**
     * 近两年贷款、信用卡连续1个月或2个月逾期且近两年逾期还款记录累计次数≤5次
     */
    public static final BigDecimal OVERDUE_THREE_SIX_STANDARD_FIVE = new BigDecimal("10");
    /**
     * 近两年贷款、信用卡连续1个月或2个月逾期且近两年逾期还款记录累计次数＞5次
     */
    public static final BigDecimal OVERDUE_THREE_SIX_STANDARD_SIX = new BigDecimal("5");
    /**
     * 近两年贷款、信用卡连续逾期月数＞2个月且近两年无逾期还款记录
     */
    public static final BigDecimal OVERDUE_THREE_SIX_STANDARD_SEVEN = new BigDecimal("5");
    /**
     * 近两年贷款、信用卡连续逾期月数＞2个月且近两年逾期还款记录累计次数≤5次
     */
    public static final BigDecimal OVERDUE_THREE_SIX_STANDARD_EIGHT = new BigDecimal("5");
    /**
     * 近两年贷款、信用卡连续逾期月数＞2个月且近两年逾期还款记录累计次数＞5次
     */
    public static final BigDecimal OVERDUE_THREE_SIX_STANDARD_NINE = new BigDecimal("0");
    /**
     * 近半年来征信查询次数≤6
     */
    public static final BigDecimal CREDIT_INQUIRY_STANDARD_ONE = new BigDecimal("3");
    /**
     * 半年来征信查询次数＞6
     */
    public static final BigDecimal CREDIT_INQUIRY_STANDARD_TWO = new BigDecimal("1");
    /**
     * 担保金额≤500万元
     */
    public static final BigDecimal GUARANTEE_AMOUNT_STANDARD_ONE = new BigDecimal("2");
    /**
     * 担保金额＞500万元
     */
    public static final BigDecimal GUARANTEE_AMOUNT_STANDARD_TWO = new BigDecimal("0");
    /**
     * 无关注类和不良类贷款
     */
    public static final BigDecimal NON_PERFORMING_LOANS_STANDARD_NO = new BigDecimal("5");
    /**
     * 有关注类和不良类贷款
     */
    public static final BigDecimal NON_PERFORMING_LOANS_STANDARD_YES = new BigDecimal("0");
    /**
     * 当前无失信被执行记录
     */
    public static final BigDecimal SHI_XIN_STANDARD_NO = new BigDecimal("15");
    /**
     * 当前存在失信被执行记录
     */
    public static final BigDecimal SHI_XIN_STANDARD_YES = new BigDecimal("0");
    /**
     * 当前无被执行
     */
    public static final BigDecimal ZHI_XING_STANDARD_NO = new BigDecimal("15");
    /**
     * 当当前存在被执行记录
     */
    public static final BigDecimal ZHI_XING_STANDARD_YES = new BigDecimal("0");
    /**
     * 当前无限制高消费
     */
    public static final BigDecimal ST_STANDARD_NO = new BigDecimal("15");
    /**
     * 当前存在限制高消费
     */
    public static final BigDecimal ST_STANDARD_YES = new BigDecimal("0");

    /**
     * 企业商誉 权重体系
     */
    public static final BigDecimal ENTERPRISE_GOODWILL_RATIO = new BigDecimal("0.4");
    /**
     * 被追偿余额、关注类余额、不良类余额 余额=0
     */
    public static final BigDecimal BAD_BALANCE_STANDARD_NO = new BigDecimal("12");
    /**
     * 被追偿余额、关注类余额、不良类余额 余额＞0
     */
    public static final BigDecimal BAD_BALANCE_STANDARD_YES = new BigDecimal("0");
    /**
     * 未结清信贷的关注类账户数 =0
     */
    public static final BigDecimal UNCLEARED_FOCUS_STANDARD_NO = new BigDecimal("12");
    /**
     * 未结清信贷的关注类账户数 ＞0
     */
    public static final BigDecimal UNCLEARED_FOCUS_STANDARD_YES = new BigDecimal("0");
    /**
     * 未结清信贷的不良类账户数 =0
     */
    public static final BigDecimal UNCLEARED_BAD_STANDARD_NO = new BigDecimal("12");
    /**
     * 未结清信贷的不良类账户数 ＞0
     */
    public static final BigDecimal UNCLEARED_BAD_STANDARD_YES = new BigDecimal("0");
    /**
     * 未结清短期借款余额 金额≤1000万元
     */
    public static final BigDecimal UNCLEARED_LOAN_BALANCE_STANDARD_ONE = new BigDecimal("4");
    /**
     * 未结清短期借款余额 金额＞1000万元
     */
    public static final BigDecimal UNCLEARED_LOAN_BALANCE_STANDARD_TWO = new BigDecimal("2");
    /**
     * 当前与历史无失信被执行记录
     */
    public static final BigDecimal ENTERPRISE_NO_SHI_XIN_STANDARD = new BigDecimal("12");
    /**
     * 历史存在失信被执行记录
     */
    public static final BigDecimal ENTERPRISE_HISTORY_SHI_XIN_STANDARD = new BigDecimal("5");
    /**
     * 当前存在失信被执行记录
     */
    public static final BigDecimal ENTERPRISE_SHI_XIN_STANDARD = new BigDecimal("0");
    /**
     * 当前与历史无被执行
     */
    public static final BigDecimal ENTERPRISE_NO_ZHI_XING_STANDARD = new BigDecimal("12");
    /**
     * 历史存在被执行记录
     */
    public static final BigDecimal ENTERPRISE_HISTORY_ZHI_XING_STANDARD = new BigDecimal("5");
    /**
     * 当前存在被执行记录
     */
    public static final BigDecimal ENTERPRISE_ZHI_XING_STANDARD = new BigDecimal("0");
    /**
     * 当前与历史无限制高消费
     */
    public static final BigDecimal ENTERPRISE_NO_ST_STANDARD = new BigDecimal("12");
    /**
     * 历史存在限制高消费
     */
    public static final BigDecimal ENTERPRISE_HISTORY_ST_STANDARD = new BigDecimal("5");
    /**
     * 当前存在限制高消费
     */
    public static final BigDecimal ENTERPRISE_ST_STANDARD = new BigDecimal("0");
    /**
     * 近两年无行政处罚
     */
    public static final BigDecimal ENTERPRISE_ADMINISTRATIVE_PENALTY_STANDARD_ONE = new BigDecimal("12");
    /**
     * 近两年行政处罚数量≤2，近两年行政处罚金额≤5万元
     */
    public static final BigDecimal ENTERPRISE_ADMINISTRATIVE_PENALTY_STANDARD_TWO = new BigDecimal("6");
    /**
     * 近两年行政处罚数量＞2，近两年行政处罚金额≤5万元
     */
    public static final BigDecimal ENTERPRISE_ADMINISTRATIVE_PENALTY_STANDARD_THREE = new BigDecimal("3");
    /**
     * 近两年行政处罚数量<=2，近两年行政处罚金额 >5万元
     */
    public static final BigDecimal ENTERPRISE_ADMINISTRATIVE_PENALTY_STANDARD_FORE = new BigDecimal("3");
    /**
     * 近两年行政处罚数量＞2，近两年行政处罚金额＞5万元
     */
    public static final BigDecimal ENTERPRISE_ADMINISTRATIVE_PENALTY_STANDARD_FIVE = new BigDecimal("0");
    /**
     * 无各类涉诉
     */
    public static final BigDecimal ENTERPRISE_INVOLVING_LAWSUITS_STANDARD_ONE = new BigDecimal("6");
    /**
     * 存在涉诉（作为原告，无作为被告）
     */
    public static final BigDecimal ENTERPRISE_INVOLVING_LAWSUITS_STANDARD_TWO = new BigDecimal("3");
    /**
     * 存在涉诉（作为被告，无所谓是否存在作为原告）
     */
    public static final BigDecimal ENTERPRISE_INVOLVING_LAWSUITS_STANDARD_THREE = new BigDecimal("2");
    /**
     * 金融机构涉诉或民间借贷纠纷
     */
    public static final BigDecimal ENTERPRISE_INVOLVING_LAWSUITS_STANDARD_FORE = new BigDecimal("0");
    /**
     * 无严重违法行为
     */
    public static final BigDecimal ENTERPRISE_OPERATING_RISK_STANDARD_ONE = new BigDecimal("1");
    /**
     * 无欠税公告
     */
    public static final BigDecimal ENTERPRISE_OPERATING_RISK_STANDARD_TWO = new BigDecimal("1");
    /**
     * 无税务违法
     */
    public static final BigDecimal ENTERPRISE_OPERATING_RISK_STANDARD_THREE = new BigDecimal("1");
    /**
     * 无黑名单信息
     */
    public static final BigDecimal ENTERPRISE_OPERATING_RISK_STANDARD_FORE = new BigDecimal("1");
    /**
     * 无其他重大异常影响正常经营情况
     */
    public static final BigDecimal ENTERPRISE_OPERATING_RISK_STANDARD_FIVE = new BigDecimal("1");
    /**
     * 无负面新闻舆情
     */
    public static final BigDecimal ENTERPRISE_OPERATING_RISK_STANDARD_SIX = new BigDecimal("1");
    /**
     * 动产融资登记 历史是否有过保理业务
     */
    public static final BigDecimal ENTERPRISE_MOVABLE_PROPERTY_FINANCING_STANDARD = new BigDecimal("0");

    /**
     * 企业经营与财务 权重体系
     */
    public static final BigDecimal ENTERPRISE_FINANCE_RATIO = new BigDecimal("0.1");
    /**
     * 上年度营业收入≥1亿元
     */
    public static final BigDecimal ENTERPRISE_CORPORATE_FINANCE_STANDARD_ONE = new BigDecimal("20");

    /**
     * 上年度营业收入＜1亿元
     */
    public static final BigDecimal ENTERPRISE_CORPORATE_FINANCE_STANDARD_TWO = new BigDecimal("10");

    /**
     * 上年度毛利率≥3%
     */
    public static final BigDecimal ENTERPRISE_CORPORATE_FINANCE_STANDARD_THREE = new BigDecimal("20");

    /**
     * 上游采购单据
     */
    public static final BigDecimal UPSTREAN_PROCUREMENT_STANDARD_THREE = new BigDecimal("20");

    /**
     * 下游销售单据
     */
    public static final BigDecimal SALES_DOCUMENTS_STANDARD_THREE = new BigDecimal("10");

    /**
     * 收入≤5000万元
     */
    public static final String INCOME_LEVEL_E = "E";
    /**
     * 5000万元＜收入≤1亿元
     */
    public static final String INCOME_LEVEL_D = "D";
    /**
     * 1亿元＜收入≤5亿元
     */
    public static final String INCOME_LEVEL_C = "C";
    /**
     * 5亿元＜收入≤15亿元
     */
    public static final String INCOME_LEVEL_B = "B";
    /**
     * 15亿元＜收入
     */
    public static final String INCOME_LEVEL_A = "A";
    /**
     * 准入
     */
    public static final String ADMITTED = "准入";
    /**
     * 不准入
     */
    public static final String NOT_ADMITTED = "不准入";

}
