package com.sunxung.factoring.dict.impl;

import com.sunxung.factoring.component.exception.ValidatorException;
import com.sunxung.factoring.component.util.CodeUtil;
import com.sunxung.factoring.dict.Dict;
import com.sunxung.factoring.entity.sys.Dictionary;
import com.sunxung.factoring.service.sys.DictionaryService;

/**
 * @Description TODO
 * @Author Yafan Wang
 * @Date 2024/9/2 9:55
 */
public class BocomTransRecordsFundSourceDic  extends Dict {

    /**
     * 编码
     */
    public static String CODE = "bocomTransRecordsFundSource";
    /**
     * 中文名称
     */
    public static String CNAME = "交行交易记录-资金来源";

    /**
     * 子项枚举
     */
    public static enum ChildEnum {
        /**
         * 外部-->静默户
         */
        OUTSIDE_TO_SILENT("outsideToSilent", "外部-->静默户"),
        /**
         * 静默户-->静默户
         */
        SILENT_TO_SILENT("silentToSilent", "静默户-->静默户"),
        /**
         * 静默户-->登记簿
         **/
        SILENT_TO_VIPACCOUNT("silentToVipAccount", "静默户-->登记簿"),
        /**
         * 登记簿-->长银登记簿
         */
        VIPACCOUNT_TO_INKASSO("vipAccountToInkasso", "登记簿-->长银登记簿"),
        /**
         * 登记簿-->登记簿
         */
        VIPACCOUNT_TO_VIPACCOUNT("vipAccountToVipAccount", "登记簿-->登记簿"),
        /**
         * 长银登记簿-->登记簿
         **/
        INKASSO_TO_VIPACCOUNT("InkassoToVipAccount", "长银登记簿-->登记簿"),
        /**
         * 登记簿-->实体卡
         */
        VIPACCOUNT_TO_BANK_CARD("vipAccountToBankCard", "登记簿-->实体卡"),
        /**
         * 外部-->登记簿
         */
        OUTSIDE_TO_VIPACCOUNT("outsideToVipAccount", "外部-->登记簿");
        /**
         * 编码
         */
        private String code;
        /**
         * 名称
         */
        private String cname;

        ChildEnum(String code, String cname) {
            this.code = code;
            this.cname = cname;
        }

        public String getCode() {
            return code;
        }

        public String getCname() {
            return cname;
        }
    }

    @Override
    public void add(int gradation) {
        Dictionary domain = addDomainDictionary(null, gradation, dictionaryService);
        if (domain == null) {
            throw new ValidatorException(CodeUtil.FAIL, "交行交易记录-资金来源字典新增失败");
        }
        for (FileModuleDict.ChildEnum child : FileModuleDict.ChildEnum.values()) {
            addChildEnumDictionary(domain.getId(), child);
        }
    }

    private Dictionary addChildEnumDictionary(Long parentId, FileModuleDict.ChildEnum child) {
        Dictionary dictionary = new Dictionary();
        dictionary.setParentId(parentId);
        dictionary.setName(child.getCname());
        dictionary.setCode(child.getCode());
        dictionary.setGradation(child.ordinal());
        return dictionaryService.add(dictionary);
    }

    private Dictionary addDomainDictionary(Long parentId, int gradation, DictionaryService dictionaryService) {
        Dictionary dictionary = new Dictionary();
        dictionary.setParentId(parentId);
        dictionary.setName(CNAME);
        dictionary.setCode(CODE);
        dictionary.setGradation(gradation);
        return dictionaryService.add(dictionary);
    }
}
