package com.sunxung.factoring.dict.impl;

import com.sunxung.factoring.component.exception.ValidatorException;
import com.sunxung.factoring.component.util.CodeUtil;
import com.sunxung.factoring.dict.Dict;
import com.sunxung.factoring.entity.sys.Dictionary;
import com.sunxung.factoring.service.sys.DictionaryService;

/**
 * @Description 账户信息管理字典类
 * @Author Yafan Wang
 * @Date 2024/9/6 9:15
 */
public class BocomVipAccountStatusDic extends Dict {

    /**
     * 编码
     */
    public static String CODE = "bocomVipAccountStatus";
    /**
     * 中文名称
     */
    public static String CNAME = "交行会员登记簿状态";

    /**
     * 子项枚举
     */
    public static enum ChildEnum {
        /**
         * 生效
         */
        VIP_ACCOUNT_EFFECT("vipAccountEffect", "生效"),
        /**
         * 待生效
         */
        VIP_ACCOUNT_PENDING_EFFECT("vipAccountPendingEffect", "待生效"),
        /**
         * 失效
         **/
        VIP_ACCOUNT_PENDING_EXPIRE("vipAccountPendingExpire", "失效"),
        /**
         * 开通失败
         **/
        VIP_ACCOUNT_OPENING_FAILED("vipAccountOpeningFailed", "开通失败");

        /**
         * 编码
         */
        private String code;
        /**
         * 名称
         */
        private String cname;

        ChildEnum(String code, String cname) {
            this.code = code;
            this.cname = cname;
        }

        public String getCode() {
            return code;
        }

        public String getCname() {
            return cname;
        }
    }

    @Override
    public void add(int gradation) {
        Dictionary domain = addDomainDictionary(null, gradation, dictionaryService);
        if (domain == null) {
            throw new ValidatorException(CodeUtil.FAIL, "业务阶段字典新增失败");
        }
        for (FileModuleDict.ChildEnum child : FileModuleDict.ChildEnum.values()) {
            addChildEnumDictionary(domain.getId(), child);
        }
    }

    private Dictionary addChildEnumDictionary(Long parentId, FileModuleDict.ChildEnum child) {
        Dictionary dictionary = new Dictionary();
        dictionary.setParentId(parentId);
        dictionary.setName(child.getCname());
        dictionary.setCode(child.getCode());
        dictionary.setGradation(child.ordinal());
        return dictionaryService.add(dictionary);
    }

    private Dictionary addDomainDictionary(Long parentId, int gradation, DictionaryService dictionaryService) {
        Dictionary dictionary = new Dictionary();
        dictionary.setParentId(parentId);
        dictionary.setName(CNAME);
        dictionary.setCode(CODE);
        dictionary.setGradation(gradation);
        return dictionaryService.add(dictionary);
    }
}
