package com.sunxung.factoring.dict.impl;

import com.sunxung.factoring.component.exception.ValidatorException;
import com.sunxung.factoring.component.util.CodeUtil;
import com.sunxung.factoring.dict.Dict;
import com.sunxung.factoring.entity.sys.Dictionary;
import com.sunxung.factoring.service.sys.DictionaryService;

/**
 * @author liutao
 * @date 2021.09.17
 */
public class HoldingRatioDict extends Dict {
    /**
     * 编码
     */
    public static String CODE = "holdingRatio";
    /**
     * 中文名称
     */
    public static String CNAME = "B端_控股比例";

    /**
     * 子项枚举
     */
    public static enum ChildEnum {
        /**
         * 控股比例＜51%
         */
        ONE("holdingRatio_1", "控股比例＜51%"),
        /**
         * 51%≤控股比例≤67%
         */
        TWO("holdingRatio_2", "51%≤控股比例≤67%"),
        /**
         * 控股比例>67%
         */
        THREE("holdingRatio_3", "控股比例>67%"),
        /**
         * 民营主板、科创板上市公司
         */
        FORE("holdingRatio_4", "民营主板、科创板上市公司"),
        /**
         * 事业单位
         */
        FIVE("holdingRatio_5", "事业单位/学校/机关单位"),
        /**
         * 民营非上市公司
         */
        SIX("holdingRatio_6", "民营非上市公司");
        /**
         * 编码
         */
        private String code;
        /**
         * 名称
         */
        private String cname;

        ChildEnum(String code, String cname) {
            this.code = code;
            this.cname = cname;
        }

        public String getCode() {
            return code;
        }

        public String getCname() {
            return cname;
        }
    }

    @Override
    public void add(int gradation) {
        Dictionary domain = addDomainDictionary(null, gradation, dictionaryService);
        if (domain == null) {
            throw new ValidatorException(CodeUtil.FAIL, "B端_企业性质字典新增失败");
        }
        for (FileModuleDict.ChildEnum child : FileModuleDict.ChildEnum.values()) {
            addChildEnumDictionary(domain.getId(), child);
        }
    }

    private Dictionary addChildEnumDictionary(Long parentId, FileModuleDict.ChildEnum child) {
        Dictionary dictionary = new Dictionary();
        dictionary.setParentId(parentId);
        dictionary.setName(child.getCname());
        dictionary.setCode(child.getCode());
        dictionary.setGradation(child.ordinal());
        return dictionaryService.add(dictionary);
    }

    private Dictionary addDomainDictionary(Long parentId, int gradation, DictionaryService dictionaryService) {
        Dictionary dictionary = new Dictionary();
        dictionary.setParentId(parentId);
        dictionary.setName(CNAME);
        dictionary.setCode(CODE);
        dictionary.setGradation(gradation);
        return dictionaryService.add(dictionary);
    }
}
