package com.sunxung.factoring.entity.bocom.request;

import com.bocom.api.AbstractBocomRequest;
import com.bocom.api.BizContent;
import com.bocom.api.utils.enums.SecurityLevel;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.sunxung.factoring.entity.bocom.response.B2BJEBP1001ResponseV2;

import java.util.List;


public class B2BJEBP1001RequestV2 extends AbstractBocomRequest<B2BJEBP1001ResponseV2> {

    @Override
    public Class<B2BJEBP1001ResponseV2> getResponseClass() {
        return B2BJEBP1001ResponseV2.class;
    }

    @Override
    public boolean isNeedEncrypt() {
        return false;
    }

    @Override
    public String getMethod() {
        return "POST";
    }

    @Override
    public Class<? extends BizContent> getBizContentClass() {
        return B2BJEBP1001RequestV2Biz.class;
    }

    @Override
    public SecurityLevel getSecurityLevel() {
        return SecurityLevel.HIGH;
    }

    public static class B2BJEBP1001RequestV2Biz implements BizContent {

        /**
         * ""
         */
        @JsonProperty("pptm_head")
        private PptmHead pptmHead = new PptmHead();
        /**
         * ""
         */
        @JsonProperty("pptm_body")
        private PptmBody pptmBody;

        public static class PptmBody extends BasicPptmBody {

            /**
             * 平台流水号
             */
            @JsonProperty("plfm_ser_no")
            private String plfmSerNo;

            /**
             * 交易日期
             */
            @JsonProperty("txn_dt")
            private String txnDt;

            /**
             * 交易发送时间
             */
            @JsonProperty("txn_send_tme")
            private String txnSendTme;

            /**
             * 平台业务订单号
             */
            @JsonProperty("plfm_bsn_ordr_no")
            private String plfmBsnOrdrNo;

            /**
             * 平台业务类型（平台自定义）
             */
            @JsonProperty("bsn_ordr_tp")
            private String bsnOrdrTp;

            /**
             * 平台支付订单号
             */
            @JsonProperty("plfm_pay_ordr_no")
            private String plfmPayOrdrNo;

            /**
             * 交易类型 03-直接付款 04-担保付款 05-冻结付款（买方冻结） 06-冻结付款（卖方冻结）
             */
            @JsonProperty("txn_tp")
            private String txnTp;

            /**
             * 付款方客户号
             */
            @JsonProperty("payr_cust_id")
            private String payrCustId;

            /**
             * 付款方登记簿编号
             */
            @JsonProperty("payr_rgsn_book_id")
            private String payrRgsnBookId;

            /**
             * "交易信息"
             */
            @JsonProperty("txn_inf")
            private List<TxnInf> txnInf;

            public static class TxnInf {
                /**
                 * 平台订单号
                 */
                @JsonProperty("plfm_ordr_no")
                private String plfmOrdrNo;

                /**
                 * 收款方客户号
                 */
                @JsonProperty("rcvr_cust_id")
                private String rcvrCustId;

                /**
                 * 收款方登记簿编号
                 */
                @JsonProperty("rcvr_rgsn_book_id")
                private String rcvrRgsnBookId;

                /**
                 * 交易币种（CNY）
                 */
                @JsonProperty("txn_ccy")
                private String txnCcy;

                /**
                 * 订单金额
                 */
                @JsonProperty("ordr_amt")
                private String ordrAmt;

                /**
                 * 交易金额
                 */
                @JsonProperty("txn_amt")
                private String txnAmt;

                /**
                 * 分账模式0-空中分润1-落地分润（单笔）2-落地分润（单笔自动）3-落地分润（汇总）
                 */
                @JsonProperty("acct_dvsn_mode")
                private String acctDvsnMode;

                /**
                 * "分账信息列表"
                 */
                @JsonProperty("acct_dvsn_inf")
                private List<AcctDvsnInf> acctDvsnInf;

                public static class AcctDvsnInf {
                    /**
                     * 分账方客户号
                     */
                    @JsonProperty("acct_dvsn_pty_cust_id")
                    private String acctDvsnPtyCustId;

                    /**
                     * 分账方登记簿编号
                     */
                    @JsonProperty("acct_dvsn_pty_rbook_id")
                    private String acctDvsnPtyRbookId;

                    /**
                     * 分账金额
                     */
                    @JsonProperty("acct_dvsn_amt")
                    private String acctDvsnAmt;

                    public String getAcctDvsnPtyCustId() {
                        return acctDvsnPtyCustId;
                    }

                    public void setAcctDvsnPtyCustId(String acctDvsnPtyCustId) {
                        this.acctDvsnPtyCustId = acctDvsnPtyCustId;
                    }

                    public String getAcctDvsnPtyRbookId() {
                        return acctDvsnPtyRbookId;
                    }

                    public void setAcctDvsnPtyRbookId(String acctDvsnPtyRbookId) {
                        this.acctDvsnPtyRbookId = acctDvsnPtyRbookId;
                    }

                    public String getAcctDvsnAmt() {
                        return acctDvsnAmt;
                    }

                    public void setAcctDvsnAmt(String acctDvsnAmt) {
                        this.acctDvsnAmt = acctDvsnAmt;
                    }
                }

                public String getPlfmOrdrNo() {
                    return plfmOrdrNo;
                }

                public void setPlfmOrdrNo(String plfmOrdrNo) {
                    this.plfmOrdrNo = plfmOrdrNo;
                }

                public String getRcvrCustId() {
                    return rcvrCustId;
                }

                public void setRcvrCustId(String rcvrCustId) {
                    this.rcvrCustId = rcvrCustId;
                }

                public String getRcvrRgsnBookId() {
                    return rcvrRgsnBookId;
                }

                public void setRcvrRgsnBookId(String rcvrRgsnBookId) {
                    this.rcvrRgsnBookId = rcvrRgsnBookId;
                }

                public String getTxnCcy() {
                    return txnCcy;
                }

                public void setTxnCcy(String txnCcy) {
                    this.txnCcy = txnCcy;
                }

                public String getOrdrAmt() {
                    return ordrAmt;
                }

                public void setOrdrAmt(String ordrAmt) {
                    this.ordrAmt = ordrAmt;
                }

                public String getTxnAmt() {
                    return txnAmt;
                }

                public void setTxnAmt(String txnAmt) {
                    this.txnAmt = txnAmt;
                }

                public String getAcctDvsnMode() {
                    return acctDvsnMode;
                }

                public void setAcctDvsnMode(String acctDvsnMode) {
                    this.acctDvsnMode = acctDvsnMode;
                }

                public List<AcctDvsnInf> getAcctDvsnInf() {
                    return acctDvsnInf;
                }

                public void setAcctDvsnInf(List<AcctDvsnInf> acctDvsnInf) {
                    this.acctDvsnInf = acctDvsnInf;
                }
            }

            /**
             * 业务摘要
             */
            @JsonProperty("bsn_sumry")
            private String bsnSumry;

            /**
             * 鉴权模式
             * 0-不鉴权；1-小程序；2-金服APP；3-金服APP 蓝牙Key；
             */
            @JsonProperty("auth_pattern")
            private String authPattern;

            public String getPlfmSerNo() {
                return plfmSerNo;
            }

            public void setPlfmSerNo(String plfmSerNo) {
                this.plfmSerNo = plfmSerNo;
            }

            public String getTxnDt() {
                return txnDt;
            }

            public void setTxnDt(String txnDt) {
                this.txnDt = txnDt;
            }

            public String getTxnSendTme() {
                return txnSendTme;
            }

            public void setTxnSendTme(String txnSendTme) {
                this.txnSendTme = txnSendTme;
            }

            public String getPlfmBsnOrdrNo() {
                return plfmBsnOrdrNo;
            }

            public void setPlfmBsnOrdrNo(String plfmBsnOrdrNo) {
                this.plfmBsnOrdrNo = plfmBsnOrdrNo;
            }

            public String getBsnOrdrTp() {
                return bsnOrdrTp;
            }

            public void setBsnOrdrTp(String bsnOrdrTp) {
                this.bsnOrdrTp = bsnOrdrTp;
            }

            public String getPlfmPayOrdrNo() {
                return plfmPayOrdrNo;
            }

            public void setPlfmPayOrdrNo(String plfmPayOrdrNo) {
                this.plfmPayOrdrNo = plfmPayOrdrNo;
            }

            public String getTxnTp() {
                return txnTp;
            }

            public void setTxnTp(String txnTp) {
                this.txnTp = txnTp;
            }

            public String getPayrCustId() {
                return payrCustId;
            }

            public void setPayrCustId(String payrCustId) {
                this.payrCustId = payrCustId;
            }

            public String getPayrRgsnBookId() {
                return payrRgsnBookId;
            }

            public void setPayrRgsnBookId(String payrRgsnBookId) {
                this.payrRgsnBookId = payrRgsnBookId;
            }

            public List<TxnInf> getTxnInf() {
                return txnInf;
            }

            public void setTxnInf(List<TxnInf> txnInf) {
                this.txnInf = txnInf;
            }

            public String getBsnSumry() {
                return bsnSumry;
            }

            public void setBsnSumry(String bsnSumry) {
                this.bsnSumry = bsnSumry;
            }

            public String getAuthPattern() {
                return authPattern;
            }

            public void setAuthPattern(String authPattern) {
                this.authPattern = authPattern;
            }
        }

        public PptmHead getPptmHead() {
            return pptmHead;
        }

        public void setPptmHead(PptmHead pptmHead) {
            this.pptmHead = pptmHead;
        }

        public PptmBody getPptmBody() {
            return pptmBody;
        }

        public void setPptmBody(PptmBody pptmBody) {
            this.pptmBody = pptmBody;
        }
    }
}
