package com.sunxung.factoring.entity.financing.review;

import com.baomidou.mybatisplus.annotation.TableField;
import com.sunxung.factoring.entity.BaseEntity;
import org.hibernate.validator.constraints.Length;
import org.hibernate.validator.constraints.NotEmpty;

/**
 * @className:ReviewBasicContractChangeContent
 * @description:三方协议基础交易合同变更内容
 * @author:杜小姣
 * @e-mail:1261237207@qq.com
 * @date:2018年10月18日 上午10:42:04
 */
public class ReviewBasicContractChangeContent extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /**
     * 基础交易合同信息ID
     */
    private Long reviewBasicContractId;

    /**
     * 基础交易合同编号:获取的是所选应收账款中的合同编号
     **/
    @NotEmpty(message = "基础交易合同编号不能为空", groups = {
            Add.class, Update.class
    })
    @Length(max = 50, message = "基础交易合同编号不能超过50个字符")
    private String contractNo;
    /**
     * 基础交易合同名称:获取的是所选应收账款中的合同名称
     **/
    @NotEmpty(message = "基础交易合同名称不能为空", groups = {
            Add.class, Update.class
    })
    @Length(max = 50, message = "基础交易合同名称不能超过50个字符")
    private String contractName;
    @NotEmpty(message = "原合同内容不能为空", groups = {
            Add.class, Update.class
    })
    @Length(max = 500, message = "原合同内容不能超过500个字符")
    private String originalContractContent;
    @NotEmpty(message = "变更后内容不能为空", groups = {
            Add.class, Update.class
    })
    @Length(max = 500, message = "变更后内容不能超过500个字符")
    private String postChangeContent;

    /**
     * 其他特殊约定-固定内容
     */
    private String specialAgreementBasic;

    /**
     * 所选底层资产的ID
     ***/
    @TableField(exist = false)
    private Long underlyingAssetsId;

    public ReviewBasicContractChangeContent() {
    }

    public String getContractNo() {
        return contractNo;
    }

    public void setContractNo(String contractNo) {
        this.contractNo = contractNo;
    }

    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getOriginalContractContent() {
        return originalContractContent;
    }

    public void setOriginalContractContent(String originalContractContent) {
        this.originalContractContent = originalContractContent;
    }

    public String getPostChangeContent() {
        return postChangeContent;
    }

    public void setPostChangeContent(String postChangeContent) {
        this.postChangeContent = postChangeContent;
    }

    public Long getReviewBasicContractId() {
        return reviewBasicContractId;
    }

    public void setReviewBasicContractId(Long reviewBasicContractId) {
        this.reviewBasicContractId = reviewBasicContractId;
    }

    public String getSpecialAgreementBasic() {
        return specialAgreementBasic;
    }

    public void setSpecialAgreementBasic(String specialAgreementBasic) {
        this.specialAgreementBasic = specialAgreementBasic;
    }

    public Long getUnderlyingAssetsId() {
        return underlyingAssetsId;
    }

    public void setUnderlyingAssetsId(Long underlyingAssetsId) {
        this.underlyingAssetsId = underlyingAssetsId;
    }
}
