package com.sunxung.factoring.entity.underlying.sop;

import com.sunxung.factoring.component.annotation.ObjectValidator;
import com.sunxung.factoring.entity.cashflowmanage.sop.BankAccountInfo;
import com.sunxung.factoring.entity.sys.User;

import javax.validation.constraints.NotNull;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @description:保理业务放款（出账）记录实体 -- 对应sop
 * @author:吴端丽
 * @e-mail:1912942707@qq.com
 * @date:2018年8月30日 上午11:51:58
 */
public class BillingFactoringBusinessLoanRecord {

    private static final long serialVersionUID = 1L;

    /**
     * 银行账户id
     **/
    private BankAccountInfo bankAccountInfo;

    /**
     * 此次放款金额
     **/
    @NotNull(message = "此次放款金额不能为空")
    private BigDecimal thisLoanAmount;
    /**
     * 此次放款日期
     **/
    @NotNull(message = "此次放款日期不能为空")
    private Date thisLoanDate;
    /**
     * 当前执行人
     **/
    @ObjectValidator(message = "当前执行人不能为空")
    private User thisExecutor;


    public BigDecimal getThisLoanAmount() {
        return thisLoanAmount;
    }

    public void setThisLoanAmount(BigDecimal thisLoanAmount) {
        this.thisLoanAmount = thisLoanAmount;
    }

    public Date getThisLoanDate() {
        return thisLoanDate;
    }

    public void setThisLoanDate(Date thisLoanDate) {
        this.thisLoanDate = thisLoanDate;
    }

    public User getThisExecutor() {
        return thisExecutor;
    }

    public void setThisExecutor(User thisExecutor) {
        this.thisExecutor = thisExecutor;
    }

    public BankAccountInfo getBankAccountInfo() {
        return bankAccountInfo;
    }

    public void setBankAccountInfo(BankAccountInfo bankAccountInfo) {
        this.bankAccountInfo = bankAccountInfo;
    }
}
