package com.sunxung.factoring.job.impl;

import com.sunxung.factoring.service.bocom.vipaccount.IBocomVipAccountBasicInfoService;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

/**
 * @Description 会员登记簿信息批量刷新
 * @Author Yafan Wang
 * @Date 2024/8/8 15:21
 */
@Component
@EnableScheduling
public class BocomVipAccountJob {

    private static Logger log = LogManager.getLogger(BocomVipAccountJob.class);

    @Autowired
    private IBocomVipAccountBasicInfoService bocomVipAccountBasicInfoService;

    @Scheduled(fixedRate = 1800000)
    public void batchBocomVipAccountProcess() {
        try {
            log.info("系统自动批量刷新会员登记簿基础信息开始(start)...");
            bocomVipAccountBasicInfoService.refreshBatchBocomVipAccount();
            log.info("系统自动批量刷新会员登记簿基础信息结束(end)...");
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    @Scheduled(fixedRate = 1800000)
    public void batchBocomVipBindAccountProcess() {
        try {
            log.info("系统自动批量刷新会员登记簿绑定账户信息开始(start)...");
            bocomVipAccountBasicInfoService.refreshBatchBindAccountStatus();
            log.info("系统自动批量刷新会员登记簿绑定账户信息结束(end)...");
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    @Scheduled(fixedRate = 30000)
    public void updateBatchTranserResult() {
        try {
            log.info("系统自动批量刷新交易记录结果开始(start)...");
            bocomVipAccountBasicInfoService.updateBatchTranserResult();
            log.info("系统自动批量刷新交易记录结果结束(end)...");
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    //    @Scheduled(cron = "0 0 1 1 * ?")
    @Scheduled(fixedRate = 3600000)
    public void updateBatchTradeDetailFile() {
        try {
            log.info("系统自动批量从交行拉取上个月的综合明细开始(start)...");
            bocomVipAccountBasicInfoService.updateBatchTradeDetailFile();
            log.info("系统自动批量从交行拉取上个月的综合明细结束(end)...");
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    @Scheduled(fixedRate = 3600000)
    public void batchRgsnBookThaw() {
        try {
            log.info("系统自动批量解冻会员登记簿开始(start)...");
            bocomVipAccountBasicInfoService.batchRgsnBookThaw();
            log.info("系统自动批量解冻会员登记簿结束(end)...");
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    @Scheduled(fixedRate = 3600000)
    public void batchRgsnBookBuckling() {
        try {
            log.info("系统自动批量划转静默户金额开始(start)...");
            bocomVipAccountBasicInfoService.batchRgsnBookBuckling();
            log.info("系统自动批量划转静默户金额结束(end)...");
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    @Scheduled(fixedRate = 3600000)
    public void batchTransferInkasso() {
        try {
            log.info("系统自动批量划转登记簿的钱到长银开始(start)...");
            bocomVipAccountBasicInfoService.batchTransferInkasso();
            log.info("系统自动批量划转登记簿的钱到长银结束(end)...");
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

}
