package com.sunxung.factoring.mapper.ledger;

import com.sunxung.factoring.entity.ledger.LedgerFundGoodsAssign;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * @Description : 分账管理Mapper
 * @Author : L.Jia
 * @Date: 2022-04-15 14:28
 */
@Mapper
public interface LedgerManagementMapper {

    /**
     * 根据供应商查询所有已开票的底层信息
     *
     * @param enterpriseId
     * @return
     */
    List<Long> findAccountsReceivableIdsBySupplierId(@Param("enterpriseId")Long enterpriseId);

    /**
     * 根据核心企业查询所有已开票的底层信息
     *
     * @param enterpriseId
     * @return
     */
    List<Long> findAccountsReceivableIdsByEnterpriseId(@Param("enterpriseId")Long enterpriseId);

    /**
     * 根据供应商查询所有已开票的验收单货物信息
     *
     * @param enterpriseId
     * @return
     */
    List<LedgerFundGoodsAssign> findAcceptanceBySupplierId(@Param("enterpriseId") Long enterpriseId);

    /**
     * 根据核心企业查询所有已开票的验收单货物信息
     *
     * @param enterpriseId
     * @return
     */
    List<LedgerFundGoodsAssign> findAcceptanceByEnterpriseId(@Param("enterpriseId") Long enterpriseId);

    /**
     * 根据供应商Id查询对应的业务经理
     *
     * @param supplierInfoId
     * @return
     */
    List<Long> getProjectManagerBySupplierInfoId(@Param("supplierInfoId") Long supplierInfoId);

    /**
     * 根据核心企业Id查询对应的业务经理
     *
     * @param projectCoreEnterpriseIds
     * @return
     */
    List<Long> getProjectManagerByEnterpriseId(@Param("enterpriseIds") List<Long> projectCoreEnterpriseIds);
}
