package com.sunxung.factoring.service.bocom.register;

import com.baomidou.mybatisplus.extension.service.IService;
import com.sunxung.factoring.component.exception.BusinessException;
import com.sunxung.factoring.component.util.CodeUtil;
import com.sunxung.factoring.entity.BaseSearch;
import com.sunxung.factoring.entity.GridPage;
import com.sunxung.factoring.entity.bocom.register.BocomBasicInfo;
import com.sunxung.factoring.entity.bocom.register.BocomBasicInfoHistory;
import com.sunxung.factoring.entity.bocom.register.vo.BocomSearchVo;
import com.sunxung.factoring.entity.bocom.register.vo.EnterpriseDetailVo;
import com.sunxung.factoring.entity.bocom.request.B2BJEBM2001RequestV1;
import com.sunxung.factoring.entity.bocom.response.B2BJEBM2001ResponseV1;
import com.sunxung.factoring.entity.bocom.vipaccount.BocomVipAccountBasicInfo;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 交通银行客户信息 服务类
 * </p>
 *
 * @author liutao
 * @since 2024-07-29
 */
public interface IBocomBasicInfoService extends IService<BocomBasicInfo> {

    /**
     * B端 暂存 提交
     *
     * @param bocomBasicInfo
     */
    void add(BocomBasicInfo bocomBasicInfo);

    /**
     * c端用户提交
     *
     * @param bocomBasicInfo
     */
    void process(BocomBasicInfo bocomBasicInfo);

    /**
     * 获取详情
     *
     * @param id
     * @return
     */
    BocomBasicInfo getDetail(Long id);

    /**
     * 风控审核
     *
     * @param bocomBasicInfo
     */
    void riskReview(BocomBasicInfo bocomBasicInfo);

    /**
     * 修改数据
     *
     * @param bocomBasicInfo
     */
    void updateBocomInfo(BocomBasicInfo bocomBasicInfo);

    /**
     * 变更数据
     * @param bocomBasicInfo
     */
    void changeBocomInfo(BocomBasicInfo bocomBasicInfo);

    /**
     * 根据id查询所需数据 流程控制反射调用
     *
     * @param id
     * @return
     */
    BocomBasicInfo get(Long id);

    /**
     * 建工查看表单详情
     *
     * @param id
     * @return
     */
    BocomBasicInfoHistory getView(Long id);

    /**
     * 根据条件查询
     *
     * @param bocomSearchVo
     * @return
     */
    GridPage<BocomBasicInfo> findBySearch(BocomSearchVo bocomSearchVo);

    /**
     * 获取企业信息
     * @param keyword
     * @return
     */
    EnterpriseDetailVo getBasicDetailsByName(String keyword);

    /**
     * 终止
     * @param id
     */
    void termination(Long id);

    /**
     * 批量刷新
     */
    void batchReSearch();

    /**
     * 重新查询会员信息
     * @param id
     */
    void research(Long id);
    /**
     * 根据客户号查询 客户状态为生效中 并且 核验状态为核验成功 的账户信息
     * @param customerNumber
     * @return
     */
    BocomBasicInfo findByCustomerNumber(String customerNumber);

    /**
     * 查询生效中的账户信息
     * @return
     */
    List<BocomBasicInfo> findSuccessCustomer();

    /**
     * 当前登录人录入的数据
     * @return
     */
    GridPage<BocomBasicInfo> findUserData(BaseSearch baseSearch);

    /**
     * 查詢原因
     * @param id
     * @return
     */
    List<String> getReason(Long id);

    /**
     * 重置授权码
     * @param id
     * @return
     */
   BocomBasicInfo resetUrlAuthorized(Long id);

}
