package com.sunxung.factoring.service.bocom.register.impl;

import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.sunxung.factoring.component.constance.BocomApiConstant;
import com.sunxung.factoring.component.enums.BocomCustomerStageEnums;
import com.sunxung.factoring.component.enums.BocomCustomerStatuEnums;
import com.sunxung.factoring.component.exception.BusinessException;
import com.sunxung.factoring.component.exception.ValidatorException;
import com.sunxung.factoring.component.util.*;
import com.sunxung.factoring.dict.impl.BocomVipAccountStatusDic;
import com.sunxung.factoring.dict.impl.FileModuleDict;
import com.sunxung.factoring.entity.BaseSearch;
import com.sunxung.factoring.entity.GridPage;
import com.sunxung.factoring.entity.ResponseJson;
import com.sunxung.factoring.entity.bocom.register.*;
import com.sunxung.factoring.entity.bocom.register.vo.BocomSearchVo;
import com.sunxung.factoring.entity.bocom.register.vo.EnterpriseDetailVo;
import com.sunxung.factoring.entity.bocom.request.B2BJEBM1101RequestV2;
import com.sunxung.factoring.entity.bocom.request.B2BJEBM1102RequestV2;
import com.sunxung.factoring.entity.bocom.request.B2BJEBM2001RequestV1;
import com.sunxung.factoring.entity.bocom.response.B2BJEBM1101ResponseV2;
import com.sunxung.factoring.entity.bocom.response.B2BJEBM1102ResponseV2;
import com.sunxung.factoring.entity.bocom.response.B2BJEBM2001ResponseV1;
import com.sunxung.factoring.entity.bocom.response.FileUploadResponseV1;
import com.sunxung.factoring.entity.bocom.vipaccount.BocomVipAccountBasicInfo;
import com.sunxung.factoring.entity.project.BusinessProcessingLog;
import com.sunxung.factoring.entity.project.vo.BusinessProcessingLogDetailVo;
import com.sunxung.factoring.entity.sys.Dictionary;
import com.sunxung.factoring.entity.sys.*;
import com.sunxung.factoring.mapper.bocom.register.BocomBasicInfoMapper;
import com.sunxung.factoring.service.bocom.api.IBocomApiService;
import com.sunxung.factoring.service.bocom.register.*;
import com.sunxung.factoring.service.bocom.vipaccount.BocomVipCommonService;
import com.sunxung.factoring.service.bocom.vipaccount.IBocomVipAccountBasicInfoService;
import com.sunxung.factoring.service.project.BusinessProcessingLogService;
import com.sunxung.factoring.service.sys.*;
import com.sunxung.factoring.service.sys.flowable.FlowableService;
import org.flowable.bpmn.model.BpmnModel;
import org.flowable.bpmn.model.EndEvent;
import org.flowable.bpmn.model.Process;
import org.flowable.engine.RepositoryService;
import org.flowable.engine.RuntimeService;
import org.flowable.engine.TaskService;
import org.flowable.engine.runtime.Execution;
import org.flowable.engine.runtime.ProcessInstance;
import org.flowable.task.api.Task;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.client.RestTemplate;

import java.io.File;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 交通银行客户信息 服务实现类
 * </p>
 *
 * @author liutao
 * @since 2024-07-29
 */
@Service
public class BocomBasicInfoServiceImpl extends ServiceImpl<BocomBasicInfoMapper, BocomBasicInfo> implements IBocomBasicInfoService {

    @Autowired
    private IBocomBasicInfoHistoryService bocomBasicInfoHistoryService;

    @Autowired
    private IBocomLegalPersonInfoService bocomLegalPersonInfoService;

    @Autowired
    private IBocomLegalPersonInfoHistoryService bocomLegalPersonInfoHistoryService;

    @Autowired
    private IBocomShareholderActualControllerService bocomShareholderActualControllerService;

    @Autowired
    private IBocomShareholderActualControllerHistoryService bocomShareholderActualControllerHistoryService;

    @Autowired
    private IBocomBeneficiaryInfoService bocomBeneficiaryInfoService;

    @Autowired
    private IBocomBeneficiaryInfoHistoryService bocomBeneficiaryInfoHistoryService;

    @Autowired
    private IBocomAuthorizedAgentService bocomAuthorizedAgentService;

    @Autowired
    private IBocomAuthorizedAgentHistoryService bocomAuthorizedAgentHistoryService;

    @Autowired
    private FileService fileService;

    @Autowired
    private UserService userService;

    @Autowired
    private PermissionService permissionService;

    @Autowired
    private BusinessProcessingLogService businessProcessingLogService;

    @Autowired
    private FlowableService flowableService;

    @Autowired
    private IBocomApprovalService bocomApprovalService;

    @Autowired
    private RestTemplate restTemplate;

    @Value("${sop.getEnterpriseDetail}")
    private String getEnterpriseDetail;

    @Value("${sop.partnerList}")
    private String partnerListUrl;

    @Value("${sop.actualControl}")
    private String actualControlUrl;

    @Value("${sop.beneficialOwner}")
    private String beneficialOwnerUrl;

    @Autowired
    private IBocomApiService bocomApiService;

    @Autowired
    private SerialNumberGenerator serialNumberGenerator;

    @Autowired
    private DictionaryService dictionaryService;

    @Autowired
    private CUserService cUserService;

    @Autowired
    private TaskService taskService;

    @Autowired
    private RuntimeService runtimeService;

    @Autowired
    protected RepositoryService repositoryService;

    @Autowired
    private IBocomVipAccountBasicInfoService bocomVipAccountBasicInfoService;

    @Autowired
    private BocomVipCommonService bocomVipCommonService;

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void add(BocomBasicInfo bocomBasicInfo) {
        //修改主表信息
        if (bocomBasicInfo.getId() != null) {
            this.updateById(bocomBasicInfo);
        } else {
            Integer count = this.lambdaQuery().notIn(BocomBasicInfo::getVerificationStatus, "核验失败").eq(BocomBasicInfo::getSocialCreditCode, bocomBasicInfo.getSocialCreditCode()).count();
            if (count > 0) {
                throw new BusinessException(CodeUtil.FAIL, "该用户有在途的开户数据！");
            }
            this.baseMapper.save(bocomBasicInfo);
        }
        //删除之前的文件
        fileService.lambdaUpdate().eq(FileStorageDO::getBusinessType, FileModuleDict.ChildEnum.BOCOM_REGISTER_BUSINESS_LICENSE.getCode()).eq(FileStorageDO::getBusinessId, bocomBasicInfo.getId()).set(FileStorageDO::getBusinessId, null).update();
        Long fileId = bocomBasicInfo.getFileId();
        Long front1 = bocomBasicInfo.getFront();
        Long back1 = bocomBasicInfo.getBack();
        if (fileId != null) {
            FileStorageDO fileStorageDO = fileService.getById(fileId);
            fileStorageDO.setId(null);
            fileStorageDO.setBusinessId(bocomBasicInfo.getId());
            fileService.save(fileStorageDO);
        }
        if (front1 != null) {
            FileStorageDO fileStorageDO = fileService.getById(front1);
            fileStorageDO.setId(null);
            fileStorageDO.setBusinessId(bocomBasicInfo.getId());
            fileService.save(fileStorageDO);
        }
        if (back1 != null) {
            FileStorageDO fileStorageDO = fileService.getById(back1);
            fileStorageDO.setId(null);
            fileStorageDO.setBusinessId(bocomBasicInfo.getId());
            fileService.save(fileStorageDO);
        }
        //删除历史数据
        bocomLegalPersonInfoService.lambdaUpdate().eq(BocomLegalPersonInfo::getBocomBasicInfoId, bocomBasicInfo.getId()).remove();
        bocomShareholderActualControllerService.lambdaUpdate().eq(BocomShareholderActualController::getBocomBasicInfoId, bocomBasicInfo.getId()).remove();
        bocomBeneficiaryInfoService.lambdaUpdate().eq(BocomBeneficiaryInfo::getBocomBasicInfoId, bocomBasicInfo.getId()).remove();
        bocomAuthorizedAgentService.lambdaUpdate().eq(BocomAuthorizedAgent::getBocomBasicInfoId, bocomBasicInfo.getId()).remove();
        //保存新数据
        BocomLegalPersonInfo bocomLegalPersonInfo = bocomBasicInfo.getBocomLegalPersonInfo();
        if (bocomLegalPersonInfo != null) {
            bocomLegalPersonInfo.setBocomBasicInfoId(bocomBasicInfo.getId());
            bocomLegalPersonInfoService.save(bocomLegalPersonInfo);
            Long front = bocomLegalPersonInfo.getFront();
            if (front != null) {
                FileStorageDO fileStorageDO = fileService.getById(front);
                fileStorageDO.setId(null);
                fileStorageDO.setBusinessId(bocomLegalPersonInfo.getId());
                fileService.save(fileStorageDO);
            }
            Long back = bocomLegalPersonInfo.getBack();
            if (back != null) {
                FileStorageDO fileStorageDOBack = fileService.getById(back);
                fileStorageDOBack.setId(null);
                fileStorageDOBack.setBusinessId(bocomLegalPersonInfo.getId());
                fileService.save(fileStorageDOBack);
            }
        }
        List<BocomShareholderActualController> bocomShareholderActualControllers = bocomBasicInfo.getBocomShareholderActualControllers();
        if (CollectionUtil.isNotEmpty(bocomShareholderActualControllers)) {
            for (BocomShareholderActualController bocomShareholderActualController : bocomShareholderActualControllers) {
                bocomShareholderActualController.setBocomBasicInfoId(bocomBasicInfo.getId());
                bocomShareholderActualControllerService.save(bocomShareholderActualController);
                Long front = bocomShareholderActualController.getFront();
                if (front != null) {
                    FileStorageDO fileStorageDO = fileService.getById(front);
                    fileStorageDO.setId(null);
                    fileStorageDO.setBusinessId(bocomShareholderActualController.getId());
                    fileStorageDO.setBusinessType(FileModuleDict.ChildEnum.BOCOM_SHAREHOLDER_IDCARD_FRONT.getCode());
                    fileService.save(fileStorageDO);
                }
                Long back = bocomShareholderActualController.getBack();
                if (back != null) {
                    FileStorageDO fileStorageDOBack = fileService.getById(back);
                    fileStorageDOBack.setId(null);
                    fileStorageDOBack.setBusinessId(bocomShareholderActualController.getId());
                    fileStorageDOBack.setBusinessType(FileModuleDict.ChildEnum.BOCOM_SHAREHOLDER_IDCARD_BACK.getCode());
                    fileService.save(fileStorageDOBack);
                }
            }
        }
        List<BocomBeneficiaryInfo> bocomBeneficiaryInfos = bocomBasicInfo.getBocomBeneficiaryInfos();
        if (CollectionUtil.isNotEmpty(bocomBeneficiaryInfos)) {
            for (BocomBeneficiaryInfo bocomBeneficiaryInfo : bocomBeneficiaryInfos) {
                bocomBeneficiaryInfo.setBocomBasicInfoId(bocomBasicInfo.getId());
                bocomBeneficiaryInfoService.save(bocomBeneficiaryInfo);
                Long front = bocomBeneficiaryInfo.getFront();
                if (front != null) {
                    FileStorageDO fileStorageDO = fileService.getById(front);
                    fileStorageDO.setId(null);
                    fileStorageDO.setBusinessId(bocomBeneficiaryInfo.getId());
                    fileStorageDO.setBusinessType(FileModuleDict.ChildEnum.BOCOM_BENEFICIARY_IDCARD_FRONT.getCode());
                    fileService.save(fileStorageDO);
                }
                Long back = bocomBeneficiaryInfo.getBack();
                if (back != null) {
                    FileStorageDO fileStorageDOBack = fileService.getById(back);
                    fileStorageDOBack.setId(null);
                    fileStorageDOBack.setBusinessId(bocomBeneficiaryInfo.getId());
                    fileStorageDOBack.setBusinessType(FileModuleDict.ChildEnum.BOCOM_BENEFICIARY_IDCARD_BACK.getCode());
                    fileService.save(fileStorageDOBack);
                }
            }
        }
        BocomAuthorizedAgent bocomAuthorizedAgent = bocomBasicInfo.getBocomAuthorizedAgent();
        if (bocomAuthorizedAgent != null) {
            bocomAuthorizedAgent.setBocomBasicInfoId(bocomBasicInfo.getId());
            bocomAuthorizedAgentService.save(bocomAuthorizedAgent);
            Long front = bocomAuthorizedAgent.getFront();
            if (front != null) {
                FileStorageDO fileStorageDO = fileService.getById(front);
                fileStorageDO.setId(null);
                fileStorageDO.setBusinessId(bocomAuthorizedAgent.getId());
                fileStorageDO.setBusinessType(FileModuleDict.ChildEnum.BOCOM_AUTHORIZED_AGENT_IDCARD_FRONT.getCode());
                fileService.save(fileStorageDO);
            }
            Long back = bocomAuthorizedAgent.getBack();
            if (back != null) {
                FileStorageDO fileStorageDOBack = fileService.getById(back);
                fileStorageDOBack.setId(null);
                fileStorageDOBack.setBusinessId(bocomAuthorizedAgent.getId());
                fileStorageDOBack.setBusinessType(FileModuleDict.ChildEnum.BOCOM_AUTHORIZED_AGENT_IDCARD_BACK.getCode());
                fileService.save(fileStorageDOBack);
            }
        }
        if (bocomBasicInfo.getVisible()) {
            bocomBasicInfo.setStage(BocomCustomerStageEnums.REVIEW.getCode());
            this.updateById(bocomBasicInfo);
            //保存历史
            Long historyId = addHistory(bocomBasicInfo);
            bocomBasicInfo.setHistoryId(historyId);
            //流程
            process(bocomBasicInfo);
        } else {
            bocomBasicInfo.setStage(BocomCustomerStageEnums.STAGING.getCode());
            this.updateById(bocomBasicInfo);
        }
    }

    private Long addHistory(BocomBasicInfo bocomBasicInfo) {
        //主表信息
        BocomBasicInfoHistory bocomBasicInfoHistory = BeanUtilsProxy.copyProperties(bocomBasicInfo, BocomBasicInfoHistory.class);
        bocomBasicInfoHistory.setId(null);
        bocomBasicInfoHistoryService.save(bocomBasicInfoHistory);
        Long fileId = bocomBasicInfo.getFileId();
        Long front1 = bocomBasicInfo.getFront();
        Long back1 = bocomBasicInfo.getBack();
        if (front1 != null) {
            FileStorageDO existsFile = fileService.getById(front1);
            existsFile.setId(null);
            existsFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_IDCARD_FRONT_HISTORY.getCode());
            existsFile.setBusinessId(bocomBasicInfoHistory.getId());
            fileService.save(existsFile);
        }
        if (back1 != null) {
            FileStorageDO existsFile = fileService.getById(back1);
            existsFile.setId(null);
            existsFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_IDCARD_BACK_HISTORY.getCode());
            existsFile.setBusinessId(bocomBasicInfoHistory.getId());
            fileService.save(existsFile);
        }
        if (fileId != null) {
            FileStorageDO existsFile = fileService.getById(fileId);
            existsFile.setId(null);
            existsFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_REGISTER_BUSINESS_LICENSE_HISTORY.getCode());
            existsFile.setBusinessId(bocomBasicInfoHistory.getId());
            fileService.save(existsFile);
        }
        //法定代表人信息
        BocomLegalPersonInfo bocomLegalPersonInfo = bocomBasicInfo.getBocomLegalPersonInfo();
        if (bocomLegalPersonInfo != null) {
            BocomLegalPersonInfoHistory bocomLegalPersonInfoHistory = BeanUtilsProxy.copyProperties(bocomLegalPersonInfo, BocomLegalPersonInfoHistory.class);
            bocomLegalPersonInfoHistory.setId(null);
            bocomLegalPersonInfoHistory.setBocomBasicInfoId(bocomBasicInfoHistory.getId());
            bocomLegalPersonInfoHistoryService.save(bocomLegalPersonInfoHistory);
            Long front = bocomLegalPersonInfo.getFront();
            if (front != null) {
                FileStorageDO frontFile = fileService.getById(front);
                frontFile.setId(null);
                frontFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_LEGAL_REPRESENTATIVE_IDCARD_FRONT_HISTORY.getCode());
                frontFile.setBusinessId(bocomLegalPersonInfoHistory.getId());
                fileService.save(frontFile);
            }
            Long back = bocomLegalPersonInfo.getBack();
            if (back != null) {
                FileStorageDO backFile = fileService.getById(back);
                backFile.setId(null);
                backFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_LEGAL_REPRESENTATIVE_IDCARD_BACK_HISTORY.getCode());
                backFile.setBusinessId(bocomLegalPersonInfoHistory.getId());
                fileService.save(backFile);
            }
        }
        List<BocomShareholderActualController> bocomShareholderActualControllers = bocomBasicInfo.getBocomShareholderActualControllers();
        if (CollectionUtil.isNotEmpty(bocomShareholderActualControllers)) {
            for (BocomShareholderActualController bocomShareholderActualController : bocomShareholderActualControllers) {
                BocomShareholderActualControllerHistory bocomShareholderActualControllerHistory = BeanUtilsProxy.copyProperties(bocomShareholderActualController, BocomShareholderActualControllerHistory.class);
                bocomShareholderActualControllerHistory.setId(null);
                bocomShareholderActualControllerHistory.setBocomBasicInfoId(bocomBasicInfoHistory.getId());
                bocomShareholderActualControllerHistoryService.save(bocomShareholderActualControllerHistory);
                Long front = bocomShareholderActualController.getFront();
                if (front != null) {
                    FileStorageDO frontFile = fileService.getById(front);
                    frontFile.setId(null);
                    frontFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_SHAREHOLDER_IDCARD_FRONT_HISTORY.getCode());
                    frontFile.setBusinessId(bocomShareholderActualControllerHistory.getId());
                    fileService.save(frontFile);
                }
                Long back = bocomShareholderActualController.getBack();
                if (back != null) {
                    FileStorageDO backFile = fileService.getById(back);
                    backFile.setId(null);
                    backFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_SHAREHOLDER_IDCARD_BACK_HISTORY.getCode());
                    backFile.setBusinessId(bocomShareholderActualControllerHistory.getId());
                    fileService.save(backFile);
                }
            }
        }
        List<BocomBeneficiaryInfo> bocomBeneficiaryInfos = bocomBasicInfo.getBocomBeneficiaryInfos();
        if (CollectionUtil.isNotEmpty(bocomBeneficiaryInfos)) {
            for (BocomBeneficiaryInfo bocomBeneficiaryInfo : bocomBeneficiaryInfos) {
                BocomBeneficiaryInfoHistory bocomBeneficiaryInfoHistory = BeanUtilsProxy.copyProperties(bocomBeneficiaryInfo, BocomBeneficiaryInfoHistory.class);
                bocomBeneficiaryInfoHistory.setId(null);
                bocomBeneficiaryInfoHistory.setBocomBasicInfoId(bocomBasicInfoHistory.getId());
                bocomBeneficiaryInfoHistoryService.save(bocomBeneficiaryInfoHistory);
                Long front = bocomBeneficiaryInfo.getFront();
                if (front != null) {
                    FileStorageDO frontFile = fileService.getById(front);
                    frontFile.setId(null);
                    frontFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_BENEFICIARY_IDCARD_FRONT_HISTORY.getCode());
                    frontFile.setBusinessId(bocomBeneficiaryInfoHistory.getId());
                    fileService.save(frontFile);
                }
                Long back = bocomBeneficiaryInfo.getBack();
                if (back != null) {
                    FileStorageDO backFile = fileService.getById(back);
                    backFile.setId(null);
                    backFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_BENEFICIARY_IDCARD_BACK_HISTORY.getCode());
                    backFile.setBusinessId(bocomBeneficiaryInfoHistory.getId());
                    fileService.save(backFile);
                }
            }
        }
        BocomAuthorizedAgent bocomAuthorizedAgent = bocomBasicInfo.getBocomAuthorizedAgent();
        if (bocomAuthorizedAgent != null) {
            BocomAuthorizedAgentHistory bocomAuthorizedAgentHistory = BeanUtilsProxy.copyProperties(bocomAuthorizedAgent, BocomAuthorizedAgentHistory.class);
            bocomAuthorizedAgentHistory.setId(null);
            bocomAuthorizedAgentHistory.setBocomBasicInfoId(bocomBasicInfoHistory.getId());
            bocomAuthorizedAgentHistoryService.save(bocomAuthorizedAgentHistory);
            Long front = bocomAuthorizedAgent.getFront();
            if (front != null) {
                FileStorageDO frontFile = fileService.getById(front);
                frontFile.setId(null);
                frontFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_AUTHORIZED_AGENT_IDCARD_FRONT_HISTORY.getCode());
                frontFile.setBusinessId(bocomAuthorizedAgentHistory.getId());
                fileService.save(frontFile);
            }
            Long back = bocomAuthorizedAgent.getBack();
            if (back != null) {
                FileStorageDO backFile = fileService.getById(back);
                backFile.setId(null);
                backFile.setBusinessType(FileModuleDict.ChildEnum.BOCOM_AUTHORIZED_AGENT_IDCARD_BACK_HISTORY.getCode());
                backFile.setBusinessId(bocomAuthorizedAgentHistory.getId());
                fileService.save(backFile);
            }
        }
        return bocomBasicInfoHistory.getId();
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void process(BocomBasicInfo bocomBasicInfo) {
        User user = ThreadLocalUtil.getUser();
        Long userId;
        if (user == null) {
            User admin = userService.getByLoginName("admin");
            ThreadLocalUtil.setUser(admin);
            userId = admin.getId();
        } else {
            userId = user.getId();
        }
        Long historyId = bocomBasicInfo.getHistoryId();
        //自动完成流程第一步 businessProcessingLog 有的话说明在后面的节点有过退回  就走审核过的节点
        List<BusinessProcessingLogDetailVo> list = businessProcessingLogService.findByBusiness(bocomBasicInfo.getId(), ConstantUtil.BOCOM_BASIC_INFO);
        String taskId;
        Map<String, Object> procVariables = new HashMap<>();
        //获取风控
        List<Long> riskControlOwner = userService.findUserIdByRole(ConstantUtil.RISK_CONTROL_MANAGER);
        if (riskControlOwner == null || riskControlOwner.size() == 0) {
            throw new ValidatorException(CodeUtil.FAIL, ConstantUtil.RISK_CONTROL_MANAGER + "角色内无任何用户！");
        }
        if (CollectionUtil.isEmpty(list)) {
            //3.开启流程实例
            procVariables.put(ConstantUtil.CUSTOMER_ADD_ASSIGNEE, userId);
            //查询条件：供应商企业名称 建工行业
            String queryBusiness = bocomBasicInfo.getCustomerName();
            ProcessInstance processInst = flowableService.startProcessInstance(bocomBasicInfo, procVariables,
                    FlowableUtil.generateBusinessKey(bocomBasicInfo, ConstantUtil.BOCOM_BASIC_INFO, queryBusiness), null, ConstantUtil.BOCOM_BASIC_INFO);
            if (processInst == null) {
                throw new BusinessException(CodeUtil.FAIL, "流程启动失败");
            }
            String riskControlOwnerIds = riskControlOwner.stream().map(c -> c.toString()).collect(Collectors.joining(","));
            procVariables.put(ConstantUtil.RISK_REVIEW_CANDIDATE, riskControlOwnerIds);
            String processInstId = processInst.getId();
            Task task = flowableService.findRuntimeTaskByProcessInstId(processInstId).get(0);
            taskId = task.getId();
        } else {
            BusinessProcessingLog lastLog = businessProcessingLogService.getByBusinessTypeBusinessKey(ConstantUtil.BOCOM_BASIC_INFO, bocomBasicInfo.getId());
            taskId = lastLog.getHistoricTaskId();
        }
        //流程第一步
        Map<String, Object> msgVariables = new HashMap<>();
        msgVariables.put(ConstantUtil.FLOWABLE_MSG_TITLE, "客户名称：" + bocomBasicInfo.getCustomerName());
        msgVariables.put(ConstantUtil.FLOWABLE_MSG_CONTENT,
                "客户名称“" + bocomBasicInfo.getCustomerName() + "”的交通银行开户流程已进入“"
                        + ConstantConversionUtil.flowBusinessKeyNames.get(ConstantUtil.BOCOM_BASIC_INFO) + "—审核，"
                        + ConstantUtil.FLOWABLE_MSG_ASSIGNEE);
        flowableService.completeMyTask(taskId, bocomBasicInfo, procVariables, null, historyId, msgVariables, ConstantUtil.BOCOM_BASIC_INFO, riskControlOwner);
    }

    @Override
    public BocomBasicInfo getDetail(Long id) {
        //基础信息
        BocomBasicInfo bocomBasicInfo = baseMapper.get(id);
        FileStorageDO file = fileService.findOneByBusinessId(id, FileModuleDict.ChildEnum.BOCOM_REGISTER_BUSINESS_LICENSE.getCode());
        FileStorageDO customerFront = fileService.findOneByBusinessId(id, FileModuleDict.ChildEnum.BOCOM_IDCARD_FRONT.getCode());
        FileStorageDO customerBack = fileService.findOneByBusinessId(id, FileModuleDict.ChildEnum.BOCOM_IDCARD_BACK.getCode());
        bocomBasicInfo.setFile(file);
        bocomBasicInfo.setFrontFile(customerFront);
        bocomBasicInfo.setBackFile(customerBack);
        BocomLegalPersonInfo bocomLegalPersonInfo = bocomLegalPersonInfoService.lambdaQuery().eq(BocomLegalPersonInfo::getBocomBasicInfoId, bocomBasicInfo.getId()).one();
        if (bocomLegalPersonInfo != null) {
            FileStorageDO front = fileService.findOneByBusinessId(bocomLegalPersonInfo.getId(), FileModuleDict.ChildEnum.BOCOM_LEGAL_REPRESENTATIVE_IDCARD_FRONT.getCode());
            FileStorageDO back = fileService.findOneByBusinessId(bocomLegalPersonInfo.getId(), FileModuleDict.ChildEnum.BOCOM_LEGAL_REPRESENTATIVE_IDCARD_BACK.getCode());
            bocomLegalPersonInfo.setFrontFile(front);
            bocomLegalPersonInfo.setBackFile(back);
            bocomBasicInfo.setBocomLegalPersonInfo(bocomLegalPersonInfo);
        }
        List<BocomShareholderActualController> bocomShareholderActualControllers = bocomShareholderActualControllerService.lambdaQuery().eq(BocomShareholderActualController::getBocomBasicInfoId, bocomBasicInfo.getId()).list();
        if (CollectionUtil.isNotEmpty(bocomShareholderActualControllers)) {
            for (BocomShareholderActualController bocomShareholderActualController : bocomShareholderActualControllers) {
                FileStorageDO front = fileService.findOneByBusinessId(bocomShareholderActualController.getId(), FileModuleDict.ChildEnum.BOCOM_SHAREHOLDER_IDCARD_FRONT.getCode());
                FileStorageDO back = fileService.findOneByBusinessId(bocomShareholderActualController.getId(), FileModuleDict.ChildEnum.BOCOM_SHAREHOLDER_IDCARD_BACK.getCode());
                bocomShareholderActualController.setFrontFile(front);
                bocomShareholderActualController.setBackFile(back);
            }
            bocomBasicInfo.setBocomShareholderActualControllers(bocomShareholderActualControllers);
        }
        List<BocomBeneficiaryInfo> bocomBeneficiaryInfos = bocomBeneficiaryInfoService.lambdaQuery().eq(BocomBeneficiaryInfo::getBocomBasicInfoId, bocomBasicInfo.getId()).list();
        if (CollectionUtil.isNotEmpty(bocomBeneficiaryInfos)) {
            for (BocomBeneficiaryInfo bocomBeneficiaryInfo : bocomBeneficiaryInfos) {
                FileStorageDO front = fileService.findOneByBusinessId(bocomBeneficiaryInfo.getId(), FileModuleDict.ChildEnum.BOCOM_BENEFICIARY_IDCARD_FRONT.getCode());
                FileStorageDO back = fileService.findOneByBusinessId(bocomBeneficiaryInfo.getId(), FileModuleDict.ChildEnum.BOCOM_BENEFICIARY_IDCARD_BACK.getCode());
                bocomBeneficiaryInfo.setFrontFile(front);
                bocomBeneficiaryInfo.setBackFile(back);
            }
            bocomBasicInfo.setBocomBeneficiaryInfos(bocomBeneficiaryInfos);
        }
        BocomAuthorizedAgent bocomAuthorizedAgent = bocomAuthorizedAgentService.lambdaQuery().eq(BocomAuthorizedAgent::getBocomBasicInfoId, bocomBasicInfo.getId()).one();
        if (bocomAuthorizedAgent != null) {
            FileStorageDO front = fileService.findOneByBusinessId(bocomAuthorizedAgent.getId(), FileModuleDict.ChildEnum.BOCOM_AUTHORIZED_AGENT_IDCARD_FRONT.getCode());
            FileStorageDO back = fileService.findOneByBusinessId(bocomAuthorizedAgent.getId(), FileModuleDict.ChildEnum.BOCOM_AUTHORIZED_AGENT_IDCARD_BACK.getCode());
            bocomAuthorizedAgent.setFrontFile(front);
            bocomAuthorizedAgent.setBackFile(back);
            bocomBasicInfo.setBocomAuthorizedAgent(bocomAuthorizedAgent);
        }
        BocomApproval bocomApproval = bocomApprovalService.lambdaQuery().eq(BocomApproval::getBocomBasicInfoId, bocomBasicInfo.getId()).isNull(BocomApproval::getBocomBasicInfoHistoryId).one();
        if (bocomApproval != null) {
            bocomBasicInfo.setApprovalComment(bocomApproval.getApprovalComment());
            bocomBasicInfo.setApprovalConclusion(bocomApproval.getApprovalConclusion());
        }
        return bocomBasicInfo;
    }

    @Override
    public List<String> getReason(Long id) {
        BocomBasicInfo bocomBasicInfo = this.get(id);
        String vrfyFailStsWord = bocomBasicInfo.getVrfyFailStsWord();
        List<String> reason = new ArrayList<>();
        if (StringUtil.isNotEmpty(vrfyFailStsWord)) {
            char charToFind = '1';
            int index = vrfyFailStsWord.indexOf(charToFind);
            if (index >= 0) {
                String reasons = findReasons(index);
                reason.add(reasons);
            }
            while (index >= 0) {
                index = vrfyFailStsWord.indexOf(charToFind, index + 1);
                if (index >= 0) {
                    String reasons = findReasons(index);
                    reason.add(reasons);
                }
            }
        }
        return reason;
    }

    @Override
    public BocomBasicInfo resetUrlAuthorized(Long id) {

        BocomBasicInfo bocomBasicInfo = baseMapper.get(id);
        if (bocomBasicInfo == null) {
            throw new BusinessException(CodeUtil.FAIL, "会员账户信息不能为空！");
        }
        resetUrlAuthorized(bocomBasicInfo);
        //填充法人授权人
        if (bocomBasicInfo.getCustomerType() == 0) {
            BocomLegalPersonInfo legalPersonInfo = bocomLegalPersonInfoService.lambdaQuery().eq(BocomLegalPersonInfo::getBocomBasicInfoId, bocomBasicInfo.getId())
                    .one();
            if (legalPersonInfo != null) {
                bocomBasicInfo.setAuthenticator(legalPersonInfo.getName());
            }
        } else if (bocomBasicInfo.getCustomerType() == 1) {
            BocomShareholderActualController actualController = bocomShareholderActualControllerService.lambdaQuery().eq(BocomShareholderActualController::getBocomBasicInfoId, bocomBasicInfo.getId())
                    .eq(BocomShareholderActualController::getPersonType, 2)
                    .one();
            if (actualController != null) {
                bocomBasicInfo.setAuthenticator(actualController.getName());
            }
        }
        return bocomBasicInfo;
    }


    private String findReasons(int index) {
        int number = index + 1;
        String result = "";
        if (number == 1) {
            result = "营业执照影像文件docid错误";
        } else if (number == 2) {
            result = "营业执照影像文件OCR识别未通过";
        } else if (number == 3) {
            result = "个人证件影像文件docid错误";
        } else if (number == 4) {
            result = "个人证件影像文件OCR识别未通过";
        } else if (number == 5) {
            result = "法定代表人/负责人证件影像文件docid错误";
        } else if (number == 6) {
            result = "法定代表人/负责人证件影像文件OCR识别未通过";
        } else if (number == 7) {
            result = "受益人证件影像文件docid错误";
        } else if (number == 8) {
            result = "受益人证件影像文件OCR识别未通过";
        } else if (number == 9) {
            result = "控制人证件影像文件docid错误";
        } else if (number == 10) {
            result = "控制人证件影像文件OCR识别未通过";
        } else if (number == 11) {
            result = "股东证件影像文件docid错误";
        } else if (number == 12) {
            result = "股东证件影像文件OCR识别未通过";
        } else if (number == 13) {
            result = "授权代理人证件影像文件docid错误";
        } else if (number == 14) {
            result = "授权代理人证件影像文件OCR识别未通过";
        } else if (number == 15) {
            result = "公司客户工商联网校验未通过";
        } else if (number == 16) {
            result = "公司客户红盾校验失败";
        } else if (number == 17) {
            result = "客户反洗钱特殊名单未通过";
        } else if (number == 18) {
            result = "客户反洗钱风险等级较高";
        } else if (number == 19) {
            result = "客户电信诈骗黑名单校验未通过";
        } else if (number == 20) {
            result = "法定代表人/负责人公安联网核查未通过";
        } else if (number == 21) {
            result = "法定代表人/负责人反洗钱特殊名单未通过";
        } else if (number == 22) {
            result = "法定代表人/负责人反洗钱风险等级较高";
        } else if (number == 23) {
            result = "法定代表人/负责人手机实名制认证失败";
        } else if (number == 24) {
            result = "个人客户公安联网核查失败";
        } else if (number == 25) {
            result = "个人手机实名制认证失败";
        } else if (number == 26) {
            result = "授权代理人风险等级较高";
        } else if (number == 27) {
            result = "授权代理人公安联网核查失败";
        } else if (number == 28) {
            result = "授权代理人手机实名制认证失败";
        } else if (number == 29) {
            result = "授权代理人反洗钱特殊名单未通过";
        } else if (number == 30) {
            result = "受益人公安联网核查失败";
        } else if (number == 31) {
            result = "受益人反洗钱特殊名单未通过";
        } else if (number == 32) {
            result = "受益人反洗钱风险等级较高";
        } else if (number == 33) {
            result = "受益人电信诈骗核验失败";
        } else if (number == 34) {
            result = "国际负面清单";
        } else if (number == 35) {
            result = "控制人公安联网核查失败";
        } else if (number == 36) {
            result = "控制人反洗钱特殊名单未通过";
        } else if (number == 37) {
            result = "控制人反洗钱风险等级较高";
        } else if (number == 38) {
            result = "控制人电信诈骗核验失败";
        } else if (number == 39) {
            result = "股东公安联网核查失败（股东为个人时）";
        } else if (number == 40) {
            result = "股东反洗钱特殊名单未通过";
        } else if (number == 41) {
            result = "股东反洗钱风险等级较高";
        } else if (number == 42) {
            result = "股东电信诈骗核验失败";
        } else if (number == 43) {
            result = "股东工商校验未通过（股东为公司时）";
        } else if (number == 44) {
            result = "企业会员法人业务授权docid错误";
        } else if (number == 45) {
            result = "授权代理人个保授权docid错误";
        } else if (number == 46) {
            result = "法人/负责人个人信息使用授权docid错误";
        } else if (number == 47) {
            result = "个人业务授权docid错误";
        } else if (number == 48) {
            result = "个人个保授权docid错误）";
        } else if (number == 49) {
            result = "法人电信诈骗黑名单校验未通过";
        } else if (number == 50) {
            result = "负责人电信诈骗黑名单校验未通";
        } else if (number == 51) {
            result = "授权代理人电信诈骗黑名单校验未通过";
        } else if (number == 52) {
            result = "授权代理人业务授权docid错误";
        }
        return result;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void riskReview(BocomBasicInfo bocomBasicInfo) {
        //修改数据
        updateInfo(bocomBasicInfo);
        String taskId = bocomBasicInfo.getTaskId();
        //删除暂存的审批
        bocomApprovalService.lambdaUpdate().isNull(BocomApproval::getBocomBasicInfoHistoryId).remove();
        //添加审批
        BocomApproval bocomApproval = new BocomApproval();
        bocomApproval.setBocomBasicInfoId(bocomBasicInfo.getId());
        bocomApproval.setApprovalComment(bocomBasicInfo.getApprovalComment());
        bocomApproval.setApprovalConclusion(bocomBasicInfo.getApprovalConclusion());
        bocomApprovalService.save(bocomApproval);
        if (bocomBasicInfo.getVisible()) {
            Long historyId = addHistory(bocomBasicInfo);
            bocomApproval.setBocomBasicInfoHistoryId(historyId);
            bocomApprovalService.updateById(bocomApproval);
            //流程处理
            Map<String, Object> msgVariables = new HashMap<>();
            msgVariables.put(ConstantUtil.FLOWABLE_MSG_TITLE, "客户名称：" + bocomBasicInfo.getCustomerName());
            String result;
            if (bocomApproval.getApprovalConclusion().equals(ConstantConversionUtil.APPROVAL_RESULT_PASS)) {
                result = "通过";
                msgVariables.put(ConstantUtil.FLOWABLE_MSG_CONTENT,
                        "客户名称“" + bocomBasicInfo.getCustomerName() + "”的交通银行开户流程已进入“"
                                + ConstantConversionUtil.flowBusinessKeyNames.get(ConstantUtil.BOCOM_BASIC_INFO) + "—审核，"
                                + ConstantUtil.FLOWABLE_MSG_ASSIGNEE);
                bocomBasicInfo = register(bocomBasicInfo.getId());
            } else if (bocomApproval.getApprovalConclusion().equals(ConstantConversionUtil.APPROVAL_RESULT_BACK)) {
                bocomBasicInfo.setStage(BocomCustomerStageEnums.BACK.getCode());
                result = "退回";
                msgVariables.put(ConstantUtil.FLOWABLE_MSG_CONTENT,
                        "客户名称“" + bocomBasicInfo.getCustomerName() + "”的交通银行开户流程已退回“"
                                + ConstantUtil.FLOWABLE_MSG_ASSIGNEE);
            } else {
                throw new BusinessException(CodeUtil.FAIL, "审批结论错误！");
            }
            //修改数据
            this.updateById(bocomBasicInfo);
            flowableService.completeMyTask(taskId, bocomBasicInfo, null, result, historyId, msgVariables, ConstantUtil.BOCOM_BASIC_INFO);
        }
    }

    //注册
    private BocomBasicInfo register(Long id) {
        BocomBasicInfo bocomBasicInfo = getDetail(id);
        B2BJEBM1101RequestV2 b2BJEBM1101RequestV2 = new B2BJEBM1101RequestV2();
        B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz b2BJEBM1101RequestV2Biz = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz();
        B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody pptmBody = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody();
        //操作类型1-建立会员信息2-修改会员信息3-删除会员信息4-修改绿色通道
        pptmBody.setOprTp("1");
        String plfmSerNo = serialNumberGenerator.generatePlfmSerNo();
        //平台流水号
        pptmBody.setPlfmSerNo(plfmSerNo);
        if (bocomBasicInfo.getCustomerType() == 0) {
            pptmBody.setCustTp("B");
            String bocomBasicInfoCertificateType = bocomBasicInfo.getCertificateType();
            String cmpyIdTp = bocomBasicInfoCertificateType.split("_")[1];
            pptmBody.setCmpyNme(bocomBasicInfo.getCustomerName());
            pptmBody.setCmpyIdTp(cmpyIdTp);
            pptmBody.setCmpyIdNo(bocomBasicInfo.getSocialCreditCode());
            String certificateExpirationDate = bocomBasicInfo.getCertificateExpirationDate();
            if (StringUtil.isNotEmpty(certificateExpirationDate)) {
                pptmBody.setCmpyIdDueDt(certificateExpirationDate.replace("-", "").split(" ")[0]);
            } else {
                pptmBody.setCmpyIdDueDt("99991231");
            }
            pptmBody.setRgsAddr(bocomBasicInfo.getRegisteredAddress());
            pptmBody.setOprAddr(bocomBasicInfo.getBusinessAddress());
            pptmBody.setOprScope(bocomBasicInfo.getBusinessScope());
            List<BocomShareholderActualController> bocomShareholderActualControllers = bocomBasicInfo.getBocomShareholderActualControllers();
            BocomShareholderActualController bocomShareholderActualController = bocomShareholderActualControllers.get(0);
            //股东
            if (bocomShareholderActualController.getPersonType() == 0) {
                pptmBody.setCntlgSrhdrNme(bocomShareholderActualController.getName());
                String certificateType = bocomShareholderActualController.getCertificateType();
                String cntlgSrhdrIdTp = certificateType.split("_")[1];
                pptmBody.setCntlgSrhdrIdTp(cntlgSrhdrIdTp);
                pptmBody.setCntlgSrhdrIdNo(bocomShareholderActualController.getCertificateCode());
                pptmBody.setCntlgSrhdrIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                pptmBody.setCntlgSrhdrIdVldDt("20440101");
                //实控人
            } else if (bocomShareholderActualController.getPersonType() == 1) {
                pptmBody.setAtlctlPrsNme(bocomShareholderActualController.getName());
                String certificateType = bocomShareholderActualController.getCertificateType();
                String cntlgSrhdrIdTp = certificateType.split("_")[1];
                pptmBody.setAtlctlPrsIdTp(cntlgSrhdrIdTp);
                pptmBody.setAtlctlPrsIdNo(bocomShareholderActualController.getCertificateCode());
                pptmBody.setAtlctlPrsIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                pptmBody.setAtlctlPrsIdVldDt("20440101");
            }
            //受益人
            List<B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy> bfyList = new ArrayList<>();
            List<BocomBeneficiaryInfo> bocomBeneficiaryInfos = bocomBasicInfo.getBocomBeneficiaryInfos();
            if (CollectionUtil.isEmpty(bocomBeneficiaryInfos)) {
                throw new BusinessException(CodeUtil.FAIL, "参数缺失受益人信息");
            }
            for (BocomBeneficiaryInfo bocomBeneficiaryInfo : bocomBeneficiaryInfos) {
                B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy bfy = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy();
                bfy.setBenryNme(bocomBeneficiaryInfo.getName());
                String certificateType = bocomBeneficiaryInfo.getCertificateType();
                String benryIdTp = certificateType.split("_")[1];
                bfy.setBenryIdTp(benryIdTp);
                bfy.setBenryIdNo(bocomBeneficiaryInfo.getCertificateCode());
                bfy.setBenryIdVldDt(bocomBeneficiaryInfo.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                bfy.setBenryIdVldDt("20440101");
                String country = bocomBeneficiaryInfo.getCountry();
                String countryStr = country.split("_")[1];
                bfy.setBenryCtzn(countryStr);
                bfy.setBenryAddr(bocomBeneficiaryInfo.getAddress());
                FileStorageDO frontFile = bocomBeneficiaryInfo.getFrontFile();
                FileUploadResponseV1 frontFileRes = bocomApiService.fileUploadV1(new File(frontFile.getAbsolutePath()));
                bfy.setBenryIdImgFrtId(frontFileRes.getDocumentId());
                FileStorageDO backFile = bocomBeneficiaryInfo.getBackFile();
                FileUploadResponseV1 backFileRes = bocomApiService.fileUploadV1(new File(backFile.getAbsolutePath()));
                bfy.setBenryIdImgBackId(backFileRes.getDocumentId());
                bfyList.add(bfy);
            }
            pptmBody.setBfyList(bfyList);
            //法人
            BocomLegalPersonInfo bocomLegalPersonInfo = bocomBasicInfo.getBocomLegalPersonInfo();
            pptmBody.setLglRprsNme(bocomLegalPersonInfo.getName());
            String certificateType = bocomLegalPersonInfo.getCertificateType();
            String lglRprsIdTp = certificateType.split("_")[1];
            pptmBody.setLglRprsIdTp(lglRprsIdTp);
            pptmBody.setLglRprsIdNo(bocomLegalPersonInfo.getCertificateCode());
            pptmBody.setLglRprsIdVldDt(bocomLegalPersonInfo.getPeriodOfValidity().replace("-", ""));
            // TODO: 2024/8/13 测试后删除
            pptmBody.setLglRprsIdVldDt("20440101");
            pptmBody.setLglRprsPhoneNo(bocomLegalPersonInfo.getPhoneNumber());
            FileStorageDO legalPersonInfoFrontFile = bocomLegalPersonInfo.getFrontFile();
            FileUploadResponseV1 fileUploadResponseV12 = bocomApiService.fileUploadV1(new File(legalPersonInfoFrontFile.getAbsolutePath()));
            pptmBody.setLrIdImgFrtId(fileUploadResponseV12.getDocumentId());
            FileStorageDO backFile1 = bocomLegalPersonInfo.getBackFile();
            FileUploadResponseV1 fileUploadResponseV13 = bocomApiService.fileUploadV1(new File(backFile1.getAbsolutePath()));
            pptmBody.setLrIdImgBackId(fileUploadResponseV13.getDocumentId());
            //营业执照
            FileStorageDO file = bocomBasicInfo.getFile();
            FileUploadResponseV1 bsnLicImg = bocomApiService.fileUploadV1(new File(file.getAbsolutePath()));
            pptmBody.setBsnLicImgId(bsnLicImg.getDocumentId());
            //国别
            String registeredCountry = bocomBasicInfo.getRegisteredCountry();
            String country = registeredCountry.split("_")[1];
            pptmBody.setCtzn(country);
            //授权代理人
            BocomAuthorizedAgent bocomAuthorizedAgent = bocomBasicInfo.getBocomAuthorizedAgent();
            pptmBody.setAthAgntNme(bocomAuthorizedAgent.getName());
            String certificateTypeAuthorizedAgent = bocomAuthorizedAgent.getCertificateType();
            String athAgntIdTp = certificateTypeAuthorizedAgent.split("_")[1];
            pptmBody.setAthAgntIdTp(athAgntIdTp);
            pptmBody.setAthAgntIdNo(bocomAuthorizedAgent.getCertificateCode());
            pptmBody.setAthAgntIdVldDt(bocomAuthorizedAgent.getPeriodOfValidity().replace("-", ""));
            // TODO: 2024/8/13 测试后删除
            pptmBody.setAthAgntIdVldDt("20440101");
            String bocomAuthorizedAgentCountry = bocomAuthorizedAgent.getCountry();
            String athAgntCtzn = bocomAuthorizedAgentCountry.split("_")[1];
            pptmBody.setAthAgntCtzn(athAgntCtzn);
            pptmBody.setAthAgntMobNo(bocomAuthorizedAgent.getPhoneNumber());
            FileStorageDO frontFile = bocomAuthorizedAgent.getFrontFile();
            FileUploadResponseV1 fileUploadResponseV1 = bocomApiService.fileUploadV1(new File(frontFile.getAbsolutePath()));
            pptmBody.setAthAgntIdImgFrtId(fileUploadResponseV1.getDocumentId());
            FileStorageDO backFile = bocomAuthorizedAgent.getBackFile();
            FileUploadResponseV1 fileUploadResponseV11 = bocomApiService.fileUploadV1(new File(backFile.getAbsolutePath()));
            pptmBody.setAthAgntIdImgBackId(fileUploadResponseV11.getDocumentId());
        } else if (bocomBasicInfo.getCustomerType() == 1) {
            pptmBody.setCustTp("G");
            pptmBody.setCmpyNme(bocomBasicInfo.getCustomerName());
            String bocomBasicInfoCertificateType = bocomBasicInfo.getCertificateType();
            String cmpyIdTp = bocomBasicInfoCertificateType.split("_")[1];
            pptmBody.setCmpyIdTp(cmpyIdTp);
            pptmBody.setCmpyIdNo(bocomBasicInfo.getSocialCreditCode());
            String certificateExpirationDate = bocomBasicInfo.getCertificateExpirationDate();
            if (StringUtil.isNotEmpty(certificateExpirationDate)) {
                pptmBody.setCmpyIdDueDt(certificateExpirationDate.replace("-", "").split(" ")[0]);
            } else {
                pptmBody.setCmpyIdDueDt("99991231");
            }
            pptmBody.setRgsAddr(bocomBasicInfo.getRegisteredAddress());
            pptmBody.setOprAddr(bocomBasicInfo.getBusinessAddress());
            pptmBody.setOprScope(bocomBasicInfo.getBusinessScope());
            List<BocomShareholderActualController> bocomShareholderActualControllers = bocomBasicInfo.getBocomShareholderActualControllers();
            BocomShareholderActualController bocomShareholderActualController = bocomShareholderActualControllers.get(0);
            //负责人
            pptmBody.setRspsbPrsNme(bocomShareholderActualController.getName());
            String certificateTypeShareholderActualController = bocomShareholderActualController.getCertificateType();
            String cntlgSrhdrIdTp = certificateTypeShareholderActualController.split("_")[1];
            pptmBody.setRspsbPrsIdTp(cntlgSrhdrIdTp);
            pptmBody.setRspsbPrsIdNo(bocomShareholderActualController.getCertificateCode());
            pptmBody.setRspsbPrsIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
            FileStorageDO controllerFrontFile = bocomShareholderActualController.getFrontFile();
            FileUploadResponseV1 fileUploadV1 = bocomApiService.fileUploadV1(new File(controllerFrontFile.getAbsolutePath()));
            pptmBody.setLrIdImgFrtId(fileUploadV1.getDocumentId());
            FileStorageDO actualControllerBackFile = bocomShareholderActualController.getBackFile();
            FileUploadResponseV1 uploadV1 = bocomApiService.fileUploadV1(new File(actualControllerBackFile.getAbsolutePath()));
            pptmBody.setLrIdImgBackId(uploadV1.getDocumentId());
            // TODO: 2024/8/13 测试后删除
            pptmBody.setRspsbPrsIdVldDt("20440101");
            pptmBody.setRspsbPrsCntctPhoneNo(bocomShareholderActualController.getPhoneNumber());
            //实控人
            pptmBody.setAtlctlPrsNme(bocomShareholderActualController.getName());
            pptmBody.setAtlctlPrsIdTp(cntlgSrhdrIdTp);
            pptmBody.setAtlctlPrsIdNo(bocomShareholderActualController.getCertificateCode());
            pptmBody.setAtlctlPrsIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
            // TODO: 2024/8/13 测试后删除
            pptmBody.setAtlctlPrsIdVldDt("20440101");
            //受益人
            List<B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy> bfyList = new ArrayList<>();
            B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy bfy = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy();
            bfy.setBenryNme(bocomShareholderActualController.getName());
            String certificateType = bocomShareholderActualController.getCertificateType();
            String benryIdTp = certificateType.split("_")[1];
            bfy.setBenryIdTp(benryIdTp);
            bfy.setBenryIdNo(bocomShareholderActualController.getCertificateCode());
            bfy.setBenryIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
            // TODO: 2024/8/13 测试后删除
            bfy.setBenryIdVldDt("20440101");
            String countryBenry = bocomShareholderActualController.getCountry();
            String countryStr = countryBenry.split("_")[1];
            bfy.setBenryCtzn(countryStr);
            bfy.setBenryAddr(bocomShareholderActualController.getAddress());
            FileStorageDO frontFileBenry = bocomShareholderActualController.getFrontFile();
            FileUploadResponseV1 frontFileRes = bocomApiService.fileUploadV1(new File(frontFileBenry.getAbsolutePath()));
            bfy.setBenryIdImgFrtId(frontFileRes.getDocumentId());
            FileStorageDO backFileBenry = bocomShareholderActualController.getBackFile();
            FileUploadResponseV1 backFileRes = bocomApiService.fileUploadV1(new File(backFileBenry.getAbsolutePath()));
            bfy.setBenryIdImgBackId(backFileRes.getDocumentId());
            bfyList.add(bfy);
            pptmBody.setBfyList(bfyList);
            //营业执照
            FileStorageDO file = bocomBasicInfo.getFile();
            FileUploadResponseV1 bsnLicImg = bocomApiService.fileUploadV1(new File(file.getAbsolutePath()));
            pptmBody.setBsnLicImgId(bsnLicImg.getDocumentId());
            //国别
            String registeredCountry = bocomBasicInfo.getRegisteredCountry();
            String country = registeredCountry.split("_")[1];
            pptmBody.setCtzn(country);
            //授权代理人
            BocomAuthorizedAgent bocomAuthorizedAgent = bocomBasicInfo.getBocomAuthorizedAgent();
            pptmBody.setAthAgntNme(bocomAuthorizedAgent.getName());
            String certificateTypeAuthorizedAgent = bocomAuthorizedAgent.getCertificateType();
            String athAgntIdTp = certificateTypeAuthorizedAgent.split("_")[1];
            pptmBody.setAthAgntIdTp(athAgntIdTp);
            pptmBody.setAthAgntIdNo(bocomAuthorizedAgent.getCertificateCode());
            pptmBody.setAthAgntIdVldDt(bocomAuthorizedAgent.getPeriodOfValidity().replace("-", ""));
            // TODO: 2024/8/13 测试后删除
            pptmBody.setAthAgntIdVldDt("20440101");
            String bocomAuthorizedAgentCountry = bocomAuthorizedAgent.getCountry();
            String athAgntCtzn = bocomAuthorizedAgentCountry.split("_")[1];
            pptmBody.setAthAgntCtzn(athAgntCtzn);
            pptmBody.setAthAgntMobNo(bocomAuthorizedAgent.getPhoneNumber());
            FileStorageDO frontFile = bocomAuthorizedAgent.getFrontFile();
            FileUploadResponseV1 fileUploadResponseV1 = bocomApiService.fileUploadV1(new File(frontFile.getAbsolutePath()));
            pptmBody.setAthAgntIdImgFrtId(fileUploadResponseV1.getDocumentId());
            FileStorageDO backFile = bocomAuthorizedAgent.getBackFile();
            FileUploadResponseV1 fileUploadResponseV11 = bocomApiService.fileUploadV1(new File(backFile.getAbsolutePath()));
            pptmBody.setAthAgntIdImgBackId(fileUploadResponseV11.getDocumentId());
        } else if (bocomBasicInfo.getCustomerType() == 2) {
            // 客户类别 新增时必送  P-个人  B-企业  G-个体工商户
            pptmBody.setCustTp("P");
            //个人姓名
            pptmBody.setPsnlCustNme(bocomBasicInfo.getCustomerName());
            String bocomBasicInfoCertificateType = bocomBasicInfo.getCertificateType();
            String cmpyIdTp = bocomBasicInfoCertificateType.split("_")[1];
            pptmBody.setPsnlIdTp(cmpyIdTp);
            //个人证件号码
            pptmBody.setPsnlIdNo(bocomBasicInfo.getSocialCreditCode());
            //个人证件有效期
            pptmBody.setPsnlIdVldDt(bocomBasicInfo.getCertificateExpirationDate().replace("-", ""));
            // TODO: 2024/8/13 测试后删除
            pptmBody.setPsnlIdVldDt("20440101");
            //个人手机号
            pptmBody.setPsnlVldIdNo(bocomBasicInfo.getPhoneNumber());
            //联系地址
            pptmBody.setCntctAddr(bocomBasicInfo.getContactAddress());
            //国别
            String registeredCountry = bocomBasicInfo.getRegisteredCountry();
            String country = registeredCountry.split("_")[1];
            pptmBody.setCtzn(country);
            //职业
            String occupation = bocomBasicInfo.getOccupation().split("_")[1];
            pptmBody.setOcp(occupation);
            //性别
            Integer gender = bocomBasicInfo.getGender();
            String genderStr = gender == 0 ? "男" : "女";
            pptmBody.setGender(genderStr);
            bocomBasicInfo.setPushPerson(bocomBasicInfo.getCustomerName());
        } else {
            throw new BusinessException(CodeUtil.FAIL, "企业信息错误！");
        }
        b2BJEBM1101RequestV2Biz.setPptmBody(pptmBody);
        b2BJEBM1101RequestV2.setBizContent(b2BJEBM1101RequestV2Biz);
        B2BJEBM1101ResponseV2 b2BJEBM1101ResponseV2 = bocomApiService.sendToBocom(b2BJEBM1101RequestV2, BocomApiConstant.B2BJEBM_1101_URL);
        B2BJEBM1101ResponseV2.PptmBody body = b2BJEBM1101ResponseV2.getPptmBody();
        if (b2BJEBM1101ResponseV2.isSuccess() && body != null) {
            String custSts = body.getCustSts();
            if (custSts == null) {
                String returnMsg = b2BJEBM1101ResponseV2.getPptmHead().getReturnMsg();
                throw new BusinessException(CodeUtil.FAIL, "交行开户失败" + returnMsg);
            }

            Integer custStsInt = Integer.valueOf(custSts);
            bocomBasicInfo.setCustSts(custStsInt);

            String mshpCustId = body.getMshpCustId();
            String vrfySts = body.getVrfySts();
            if (StringUtil.isNotEmpty(vrfySts)) {
                if (vrfySts.equals("0") && custStsInt == 1) {
                    //生效 + 待系统核验
                    vrfySts = "待系统核验";
                    bocomBasicInfo.setStage(BocomCustomerStageEnums.SUBMIT.getCode());
                } else if (vrfySts.equals("1")) {
                    vrfySts = "核验成功";
                    bocomBasicInfo.setStage("");
                } else if (vrfySts.equals("2")) {
                    vrfySts = "核验失败";
                    bocomBasicInfo.setStage("");
                } else if (vrfySts.equals("3")) {
                    vrfySts = "系统核验中";
                    bocomBasicInfo.setStage(BocomCustomerStageEnums.SUBMIT.getCode());
                } else if (vrfySts.equals("4")) {
                    vrfySts = "银行审核中";
                    bocomBasicInfo.setStage("");
                }
            }
            if (custSts.equals("2")) {
                bocomBasicInfo.setStage("");
            }
            bocomBasicInfo.setVerificationStatus(vrfySts);
            bocomBasicInfo.setPlatformSerialNumber(plfmSerNo);
            bocomBasicInfo.setCustomerNumber(mshpCustId);
            autoCustomerRealStatus(bocomBasicInfo);

            //填充授权二维码和通知推送对象
            if (CollectionUtil.isNotEmpty(body.getNotyQue())) {
                body.getNotyQue().forEach(notyQue -> {
                    if ("1".equals(notyQue.getNotyPushObj())) {
                        bocomBasicInfo.setQrCode(notyQue.getMerchNotyBase64Stream());
                        bocomBasicInfo.setQrCodeEffectTime(new Date());
                        bocomBasicInfo.setPushPerson("法人");
                    }
                });
            }

            return bocomBasicInfo;
        } else {
            String returnMsg = b2BJEBM1101ResponseV2.getPptmHead().getReturnMsg();
            throw new BusinessException(CodeUtil.FAIL, "交行开户失败" + returnMsg);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateBocomInfo(BocomBasicInfo bocomBasicInfo) {

        if (bocomBasicInfo.getId() == null) {
            throw new ValidatorException(CodeUtil.FAIL, "账户id不能为空！");
        }

        checkUpdateBocom(bocomBasicInfo);
        //修改数据
        updateInfo(bocomBasicInfo);
        //添加日志
        BusinessProcessingLog businessProcessingLog = businessProcessingLogService.getByBusinessTypeBusinessKey(ConstantUtil.BOCOM_BASIC_INFO, bocomBasicInfo.getId());
        BusinessProcessingLog processingLog = new BusinessProcessingLog();
        processingLog.setBusnessKey(bocomBasicInfo.getId());
        processingLog.setBusinessType(ConstantUtil.BOCOM_BASIC_INFO);
        processingLog.setHistoricTaskId(businessProcessingLog.getHistoricTaskId() + "1");
        processingLog.setAssignee(ThreadLocalUtil.getUser());
        processingLog.setAssigneeType(ConstantConversionUtil.PROCESS_TASK);
        processingLog.setTaskDefKey("bocom_customer_add");
        processingLog.setTaskName(ConstantUtil.UPDATE);
        processingLog.setStatus(ConstantUtil.UPDATE);
        processingLog.setFormBusinessId(bocomBasicInfo.getHistoryId());
        processingLog.setStartTime(new Date());
        processingLog.setEndTime(new Date());
        businessProcessingLogService.add(processingLog);
        //修改交行信息
        updateBocom(bocomBasicInfo.getId());
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void changeBocomInfo(BocomBasicInfo bocomBasicInfo) {
        //允许变更字段 1.单位名称、印业执照、证件过期时间、证件有效期
        //2.法人证件号码、法人身份证、法人姓名、法人手机号、证件有效期
        //3.授权代理人证件号码、授权代理人身份证、姓名、手机号、证件有效期
        //客户号首位不带PT的字母，只能变更授权代理人。其他字段不可修改

        String modfCntlWord = checkChangeBocom(bocomBasicInfo);
        //修改数据
        updateInfo(bocomBasicInfo);
        //添加日志
        BusinessProcessingLog businessProcessingLog = businessProcessingLogService.getByBusinessTypeBusinessKey(ConstantUtil.BOCOM_BASIC_INFO, bocomBasicInfo.getId());
        BusinessProcessingLog processingLog = new BusinessProcessingLog();
        processingLog.setBusnessKey(bocomBasicInfo.getId());
        processingLog.setBusinessType(ConstantUtil.BOCOM_BASIC_INFO);
        processingLog.setHistoricTaskId(businessProcessingLog.getHistoricTaskId() + "1");
        processingLog.setAssignee(ThreadLocalUtil.getUser());
        processingLog.setAssigneeType(ConstantConversionUtil.PROCESS_TASK);
        processingLog.setTaskDefKey("bocom_customer_add");
        processingLog.setTaskName(ConstantUtil.CHANGE);
        processingLog.setStatus(ConstantUtil.CHANGE);
        processingLog.setFormBusinessId(bocomBasicInfo.getHistoryId());
        processingLog.setStartTime(new Date());
        processingLog.setEndTime(new Date());
        businessProcessingLogService.add(processingLog);
        //变更交行信息
        changeBocom(modfCntlWord, bocomBasicInfo.getId());

    }

    private void updateBocom(Long id) {
        BocomBasicInfo bocomBasicInfo = getDetail(id);
        B2BJEBM1101RequestV2 b2BJEBM1101RequestV2 = new B2BJEBM1101RequestV2();
        B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz b2BJEBM1101RequestV2Biz = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz();
        B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody pptmBody = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody();
        pptmBody.setOprTp("2");
        String plfmSerNo = serialNumberGenerator.generatePlfmSerNo();
        pptmBody.setPlfmSerNo(plfmSerNo);
        pptmBody.setMshpCustId(bocomBasicInfo.getCustomerNumber());
        if (bocomBasicInfo.getCustomerNumber().contains("PT")) {
            if (bocomBasicInfo.getCustomerType() == 0) {
                pptmBody.setModfCntlWord("1001111100");
                pptmBody.setCustTp("B");
                String bocomBasicInfoCertificateType = bocomBasicInfo.getCertificateType();
                String cmpyIdTp = bocomBasicInfoCertificateType.split("_")[1];
                pptmBody.setCmpyNme(bocomBasicInfo.getCustomerName());
                pptmBody.setCmpyIdTp(cmpyIdTp);
                pptmBody.setCmpyIdNo(bocomBasicInfo.getSocialCreditCode());
                String certificateExpirationDate = bocomBasicInfo.getCertificateExpirationDate();
                if (StringUtil.isNotEmpty(certificateExpirationDate)) {
                    pptmBody.setCmpyIdDueDt(certificateExpirationDate.replace("-", "").split(" ")[0]);
                } else {
                    pptmBody.setCmpyIdDueDt("99991231");
                }
                pptmBody.setRgsAddr(bocomBasicInfo.getRegisteredAddress());
                pptmBody.setOprAddr(bocomBasicInfo.getBusinessAddress());
                pptmBody.setOprScope(bocomBasicInfo.getBusinessScope());
                List<BocomShareholderActualController> bocomShareholderActualControllers = bocomBasicInfo.getBocomShareholderActualControllers();
                BocomShareholderActualController bocomShareholderActualController = bocomShareholderActualControllers.get(0);
                //股东
                if (bocomShareholderActualController.getPersonType() == 0) {
                    pptmBody.setCntlgSrhdrNme(bocomShareholderActualController.getName());
                    String certificateType = bocomShareholderActualController.getCertificateType();
                    String cntlgSrhdrIdTp = certificateType.split("_")[1];
                    pptmBody.setCntlgSrhdrIdTp(cntlgSrhdrIdTp);
                    pptmBody.setCntlgSrhdrIdNo(bocomShareholderActualController.getCertificateCode());
                    pptmBody.setCntlgSrhdrIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
                    // TODO: 2024/8/13 测试后删除
                    pptmBody.setCntlgSrhdrIdVldDt("20440101");
                    //实控人
                } else if (bocomShareholderActualController.getPersonType() == 1) {
                    pptmBody.setAtlctlPrsNme(bocomShareholderActualController.getName());
                    String certificateType = bocomShareholderActualController.getCertificateType();
                    String cntlgSrhdrIdTp = certificateType.split("_")[1];
                    pptmBody.setAtlctlPrsIdTp(cntlgSrhdrIdTp);
                    pptmBody.setAtlctlPrsIdNo(bocomShareholderActualController.getCertificateCode());
                    pptmBody.setAtlctlPrsIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
                    // TODO: 2024/8/13 测试后删除
                    pptmBody.setAtlctlPrsIdVldDt("20440101");
                }
                //受益人
                List<B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy> bfyList = new ArrayList<>();
                List<BocomBeneficiaryInfo> bocomBeneficiaryInfos = bocomBasicInfo.getBocomBeneficiaryInfos();
                if (CollectionUtil.isEmpty(bocomBeneficiaryInfos)) {
                    throw new BusinessException(CodeUtil.FAIL, "参数缺失受益人信息");
                }
                for (BocomBeneficiaryInfo bocomBeneficiaryInfo : bocomBeneficiaryInfos) {
                    B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy bfy = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy();
                    bfy.setBenryNme(bocomBeneficiaryInfo.getName());
                    String certificateType = bocomBeneficiaryInfo.getCertificateType();
                    String benryIdTp = certificateType.split("_")[1];
                    bfy.setBenryIdTp(benryIdTp);
                    bfy.setBenryIdNo(bocomBeneficiaryInfo.getCertificateCode());
                    bfy.setBenryIdVldDt(bocomBeneficiaryInfo.getPeriodOfValidity().replace("-", ""));
                    // TODO: 2024/8/13 测试后删除
                    bfy.setBenryIdVldDt("20440101");
                    String country = bocomBeneficiaryInfo.getCountry();
                    String countryStr = country.split("_")[1];
                    bfy.setBenryCtzn(countryStr);
                    bfy.setBenryAddr(bocomBeneficiaryInfo.getAddress());
                    FileStorageDO frontFile = bocomBeneficiaryInfo.getFrontFile();
                    FileUploadResponseV1 frontFileRes = bocomApiService.fileUploadV1(new File(frontFile.getAbsolutePath()));
                    bfy.setBenryIdImgFrtId(frontFileRes.getDocumentId());
                    FileStorageDO backFile = bocomBeneficiaryInfo.getBackFile();
                    FileUploadResponseV1 backFileRes = bocomApiService.fileUploadV1(new File(backFile.getAbsolutePath()));
                    bfy.setBenryIdImgBackId(backFileRes.getDocumentId());
                    bfyList.add(bfy);
                }
                pptmBody.setBfyList(bfyList);
                //法人
                BocomLegalPersonInfo bocomLegalPersonInfo = bocomBasicInfo.getBocomLegalPersonInfo();
                pptmBody.setLglRprsNme(bocomLegalPersonInfo.getName());
                String certificateType = bocomLegalPersonInfo.getCertificateType();
                String lglRprsIdTp = certificateType.split("_")[1];
                pptmBody.setLglRprsIdTp(lglRprsIdTp);
                pptmBody.setLglRprsIdNo(bocomLegalPersonInfo.getCertificateCode());
                pptmBody.setLglRprsIdVldDt(bocomLegalPersonInfo.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                pptmBody.setLglRprsIdVldDt("20440101");
                pptmBody.setLglRprsPhoneNo(bocomLegalPersonInfo.getPhoneNumber());
                FileStorageDO legalPersonInfoFrontFile = bocomLegalPersonInfo.getFrontFile();
                FileUploadResponseV1 fileUploadResponseV12 = bocomApiService.fileUploadV1(new File(legalPersonInfoFrontFile.getAbsolutePath()));
                pptmBody.setLrIdImgFrtId(fileUploadResponseV12.getDocumentId());
                FileStorageDO backFile1 = bocomLegalPersonInfo.getBackFile();
                FileUploadResponseV1 fileUploadResponseV13 = bocomApiService.fileUploadV1(new File(backFile1.getAbsolutePath()));
                pptmBody.setLrIdImgBackId(fileUploadResponseV13.getDocumentId());
                //营业执照
                FileStorageDO file = bocomBasicInfo.getFile();
                FileUploadResponseV1 bsnLicImg = bocomApiService.fileUploadV1(new File(file.getAbsolutePath()));
                pptmBody.setBsnLicImgId(bsnLicImg.getDocumentId());
                //国别
                String registeredCountry = bocomBasicInfo.getRegisteredCountry();
                String country = registeredCountry.split("_")[1];
                pptmBody.setCtzn(country);
                //授权代理人
                BocomAuthorizedAgent bocomAuthorizedAgent = bocomBasicInfo.getBocomAuthorizedAgent();
                pptmBody.setAthAgntNme(bocomAuthorizedAgent.getName());
                String certificateTypeAuthorizedAgent = bocomAuthorizedAgent.getCertificateType();
                String athAgntIdTp = certificateTypeAuthorizedAgent.split("_")[1];
                pptmBody.setAthAgntIdTp(athAgntIdTp);
                pptmBody.setAthAgntIdNo(bocomAuthorizedAgent.getCertificateCode());
                pptmBody.setAthAgntIdVldDt(bocomAuthorizedAgent.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                pptmBody.setAthAgntIdVldDt("20440101");
                String bocomAuthorizedAgentCountry = bocomAuthorizedAgent.getCountry();
                String athAgntCtzn = bocomAuthorizedAgentCountry.split("_")[1];
                pptmBody.setAthAgntCtzn(athAgntCtzn);
                pptmBody.setAthAgntMobNo(bocomAuthorizedAgent.getPhoneNumber());
                FileStorageDO frontFile = bocomAuthorizedAgent.getFrontFile();
                FileUploadResponseV1 fileUploadResponseV1 = bocomApiService.fileUploadV1(new File(frontFile.getAbsolutePath()));
                FileStorageDO backFile = bocomAuthorizedAgent.getBackFile();
                pptmBody.setAthAgntIdImgFrtId(fileUploadResponseV1.getDocumentId());
                FileUploadResponseV1 fileUploadResponseV11 = bocomApiService.fileUploadV1(new File(backFile.getAbsolutePath()));
                pptmBody.setAthAgntIdImgBackId(fileUploadResponseV11.getDocumentId());
            } else if (bocomBasicInfo.getCustomerType() == 1) {
                pptmBody.setModfCntlWord("0101111100");
                pptmBody.setCustTp("G");
                pptmBody.setCmpyNme(bocomBasicInfo.getCustomerName());
                String bocomBasicInfoCertificateType = bocomBasicInfo.getCertificateType();
                String cmpyIdTp = bocomBasicInfoCertificateType.split("_")[1];
                pptmBody.setCmpyIdTp(cmpyIdTp);
                pptmBody.setCmpyIdNo(bocomBasicInfo.getSocialCreditCode());
                String certificateExpirationDate = bocomBasicInfo.getCertificateExpirationDate();
                if (StringUtil.isNotEmpty(certificateExpirationDate)) {
                    pptmBody.setCmpyIdDueDt(certificateExpirationDate.replace("-", "").split(" ")[0]);
                } else {
                    pptmBody.setCmpyIdDueDt("99991231");
                }
                pptmBody.setRgsAddr(bocomBasicInfo.getRegisteredAddress());
                pptmBody.setOprAddr(bocomBasicInfo.getBusinessAddress());
                pptmBody.setOprScope(bocomBasicInfo.getBusinessScope());
                List<BocomShareholderActualController> bocomShareholderActualControllers = bocomBasicInfo.getBocomShareholderActualControllers();
                BocomShareholderActualController bocomShareholderActualController = bocomShareholderActualControllers.get(0);
                //负责人
                pptmBody.setRspsbPrsNme(bocomShareholderActualController.getName());
                String certificateTypeShareholderActualController = bocomShareholderActualController.getCertificateType();
                String cntlgSrhdrIdTp = certificateTypeShareholderActualController.split("_")[1];
                pptmBody.setRspsbPrsIdTp(cntlgSrhdrIdTp);
                pptmBody.setRspsbPrsIdNo(bocomShareholderActualController.getCertificateCode());
                pptmBody.setRspsbPrsIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
                FileStorageDO controllerFrontFile = bocomShareholderActualController.getFrontFile();
                FileUploadResponseV1 fileUploadV1 = bocomApiService.fileUploadV1(new File(controllerFrontFile.getAbsolutePath()));
                pptmBody.setLrIdImgFrtId(fileUploadV1.getDocumentId());
                FileStorageDO actualControllerBackFile = bocomShareholderActualController.getBackFile();
                FileUploadResponseV1 uploadV1 = bocomApiService.fileUploadV1(new File(actualControllerBackFile.getAbsolutePath()));
                pptmBody.setLrIdImgBackId(uploadV1.getDocumentId());
                // TODO: 2024/8/13 测试后删除
                pptmBody.setRspsbPrsIdVldDt("20440101");
                pptmBody.setRspsbPrsCntctPhoneNo(bocomShareholderActualController.getPhoneNumber());
                //实控人
                pptmBody.setAtlctlPrsNme(bocomShareholderActualController.getName());
                pptmBody.setAtlctlPrsIdTp(cntlgSrhdrIdTp);
                pptmBody.setAtlctlPrsIdNo(bocomShareholderActualController.getCertificateCode());
                pptmBody.setAtlctlPrsIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                pptmBody.setAtlctlPrsIdVldDt("20440101");
                //受益人
                List<B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy> bfyList = new ArrayList<>();
                B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy bfy = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy();
                bfy.setBenryNme(bocomShareholderActualController.getName());
                String certificateType = bocomShareholderActualController.getCertificateType();
                String benryIdTp = certificateType.split("_")[1];
                bfy.setBenryIdTp(benryIdTp);
                bfy.setBenryIdNo(bocomShareholderActualController.getCertificateCode());
                bfy.setBenryIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                bfy.setBenryIdVldDt("20440101");
                String countryBenry = bocomShareholderActualController.getCountry();
                String countryStr = countryBenry.split("_")[1];
                bfy.setBenryCtzn(countryStr);
                bfy.setBenryAddr(bocomShareholderActualController.getAddress());
                FileStorageDO frontFileBenry = bocomShareholderActualController.getFrontFile();
                FileUploadResponseV1 frontFileRes = bocomApiService.fileUploadV1(new File(frontFileBenry.getAbsolutePath()));
                bfy.setBenryIdImgFrtId(frontFileRes.getDocumentId());
                FileStorageDO backFileBenry = bocomShareholderActualController.getBackFile();
                FileUploadResponseV1 backFileRes = bocomApiService.fileUploadV1(new File(backFileBenry.getAbsolutePath()));
                bfy.setBenryIdImgBackId(backFileRes.getDocumentId());
                bfyList.add(bfy);
                pptmBody.setBfyList(bfyList);
                //营业执照
                FileStorageDO file = bocomBasicInfo.getFile();
                FileUploadResponseV1 bsnLicImg = bocomApiService.fileUploadV1(new File(file.getAbsolutePath()));
                pptmBody.setBsnLicImgId(bsnLicImg.getDocumentId());
                //国别
                String registeredCountry = bocomBasicInfo.getRegisteredCountry();
                String country = registeredCountry.split("_")[1];
                pptmBody.setCtzn(country);
                //授权代理人
                BocomAuthorizedAgent bocomAuthorizedAgent = bocomBasicInfo.getBocomAuthorizedAgent();
                pptmBody.setAthAgntNme(bocomAuthorizedAgent.getName());
                String certificateTypeAuthorizedAgent = bocomAuthorizedAgent.getCertificateType();
                String athAgntIdTp = certificateTypeAuthorizedAgent.split("_")[1];
                pptmBody.setAthAgntIdTp(athAgntIdTp);
                pptmBody.setAthAgntIdNo(bocomAuthorizedAgent.getCertificateCode());
                pptmBody.setAthAgntIdVldDt(bocomAuthorizedAgent.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                pptmBody.setAthAgntIdVldDt("20440101");
                String bocomAuthorizedAgentCountry = bocomAuthorizedAgent.getCountry();
                String athAgntCtzn = bocomAuthorizedAgentCountry.split("_")[1];
                pptmBody.setAthAgntCtzn(athAgntCtzn);
                pptmBody.setAthAgntMobNo(bocomAuthorizedAgent.getPhoneNumber());
                FileStorageDO frontFile = bocomAuthorizedAgent.getFrontFile();
                FileUploadResponseV1 fileUploadResponseV1 = bocomApiService.fileUploadV1(new File(frontFile.getAbsolutePath()));
                pptmBody.setAthAgntIdImgFrtId(fileUploadResponseV1.getDocumentId());
                FileStorageDO backFile = bocomAuthorizedAgent.getBackFile();
                FileUploadResponseV1 fileUploadResponseV11 = bocomApiService.fileUploadV1(new File(backFile.getAbsolutePath()));
                pptmBody.setAthAgntIdImgBackId(fileUploadResponseV11.getDocumentId());
            } else if (bocomBasicInfo.getCustomerType() == 2) {
                // 客户类别 新增时必送  P-个人  B-企业  G-个体工商户
                pptmBody.setCustTp("P");
                //个人姓名
                pptmBody.setPsnlCustNme(bocomBasicInfo.getCustomerName());
                String bocomBasicInfoCertificateType = bocomBasicInfo.getCertificateType();
                String cmpyIdTp = bocomBasicInfoCertificateType.split("_")[1];
                pptmBody.setPsnlIdTp(cmpyIdTp);
                //个人证件号码
                pptmBody.setPsnlIdNo(bocomBasicInfo.getSocialCreditCode());
                //个人证件有效期
                pptmBody.setPsnlIdVldDt(bocomBasicInfo.getCertificateExpirationDate().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                pptmBody.setPsnlIdVldDt("20440101");
                //个人手机号
                pptmBody.setPsnlVldIdNo(bocomBasicInfo.getPhoneNumber());
                //联系地址
                pptmBody.setCntctAddr(bocomBasicInfo.getContactAddress());
                //国别
                String registeredCountry = bocomBasicInfo.getRegisteredCountry();
                String country = registeredCountry.split("_")[1];
                pptmBody.setCtzn(country);
                //职业
                String occupation = bocomBasicInfo.getOccupation().split("_")[1];
                pptmBody.setOcp(occupation);
                //性别
                Integer gender = bocomBasicInfo.getGender();
                String genderStr = gender == 0 ? "男" : "女";
                pptmBody.setGender(genderStr);
            } else {
                throw new BusinessException(CodeUtil.FAIL, "企业信息错误！");
            }
        }
        b2BJEBM1101RequestV2Biz.setPptmBody(pptmBody);
        b2BJEBM1101RequestV2.setBizContent(b2BJEBM1101RequestV2Biz);
        B2BJEBM1101ResponseV2 b2BJEBM1101ResponseV2 = bocomApiService.sendToBocom(b2BJEBM1101RequestV2, BocomApiConstant.B2BJEBM_1101_URL);
        B2BJEBM1101ResponseV2.PptmBody body = b2BJEBM1101ResponseV2.getPptmBody();
        if (!b2BJEBM1101ResponseV2.isSuccess() || body.getCustSts() == null) {
            String returnMsg = b2BJEBM1101ResponseV2.getPptmHead().getReturnMsg();
            throw new BusinessException(CodeUtil.FAIL, "会员账户修改失败！" + returnMsg);
        }
        //填充授权二维码和通知推送对象
        if (CollectionUtil.isNotEmpty(body.getNotyQue())) {
            body.getNotyQue().forEach(notyQue -> {
                if ("1".equals(notyQue.getNotyPushObj())) {
                    bocomBasicInfo.setQrCode(notyQue.getMerchNotyBase64Stream());
                    bocomBasicInfo.setQrCodeEffectTime(new Date());
                    bocomBasicInfo.setPushPerson("法人");
                }
            });
        }
        lambdaUpdate().eq(BocomBasicInfo::getId, bocomBasicInfo.getId())
                .set(BocomBasicInfo::getQrCode, bocomBasicInfo.getQrCode())
                .update();
    }

    private void changeBocom(String modfCntlWord, Long id) {

        BocomBasicInfo bocomBasicInfo = getDetail(id);
        B2BJEBM1101RequestV2 b2BJEBM1101RequestV2 = new B2BJEBM1101RequestV2();
        B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz b2BJEBM1101RequestV2Biz = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz();
        B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody pptmBody = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody();
        pptmBody.setOprTp("2");
        String plfmSerNo = serialNumberGenerator.generatePlfmSerNo();
        pptmBody.setPlfmSerNo(plfmSerNo);
        pptmBody.setMshpCustId(bocomBasicInfo.getCustomerNumber());
        //授权代理人(不论何种条件下 授权代理人都可变更)
        BocomAuthorizedAgent bocomAuthorizedAgent = bocomBasicInfo.getBocomAuthorizedAgent();
        pptmBody.setAthAgntNme(bocomAuthorizedAgent.getName());
        String certificateTypeAuthorizedAgent = bocomAuthorizedAgent.getCertificateType();
        String athAgntIdTp = certificateTypeAuthorizedAgent.split("_")[1];
        pptmBody.setAthAgntIdTp(athAgntIdTp);
        pptmBody.setAthAgntIdNo(bocomAuthorizedAgent.getCertificateCode());
        pptmBody.setAthAgntIdVldDt(bocomAuthorizedAgent.getPeriodOfValidity().replace("-", ""));
        // TODO: 2024/8/13 测试后删除
        pptmBody.setAthAgntIdVldDt("20440101");
        String bocomAuthorizedAgentCountry = bocomAuthorizedAgent.getCountry();
        String athAgntCtzn = bocomAuthorizedAgentCountry.split("_")[1];
        pptmBody.setAthAgntCtzn(athAgntCtzn);
        pptmBody.setAthAgntMobNo(bocomAuthorizedAgent.getPhoneNumber());
        FileStorageDO frontFile = bocomAuthorizedAgent.getFrontFile();
        FileUploadResponseV1 fileUploadResponseV1 = bocomApiService.fileUploadV1(new File(frontFile.getAbsolutePath()));
        FileStorageDO backFile = bocomAuthorizedAgent.getBackFile();
        pptmBody.setAthAgntIdImgFrtId(fileUploadResponseV1.getDocumentId());
        FileUploadResponseV1 fileUploadResponseV11 = bocomApiService.fileUploadV1(new File(backFile.getAbsolutePath()));
        pptmBody.setAthAgntIdImgBackId(fileUploadResponseV11.getDocumentId());
        if (bocomBasicInfo.getCustomerNumber().contains("PT")) {
            //客户编号带‘PT’时都可以变更 授权代理人和单位名称（单位名称、营业执照、证件过期时间、注册地址）
            String bocomBasicInfoCertificateType = bocomBasicInfo.getCertificateType();
            String cmpyIdTp = bocomBasicInfoCertificateType.split("_")[1];
            pptmBody.setCmpyNme(bocomBasicInfo.getCustomerName());
            pptmBody.setCmpyIdTp(cmpyIdTp);
            pptmBody.setCmpyIdNo(bocomBasicInfo.getSocialCreditCode());
            String certificateExpirationDate = bocomBasicInfo.getCertificateExpirationDate();
            if (StringUtil.isNotEmpty(certificateExpirationDate)) {
                pptmBody.setCmpyIdDueDt(certificateExpirationDate.replace("-", "").split(" ")[0]);
            } else {
                pptmBody.setCmpyIdDueDt("99991231");
            }
            pptmBody.setRgsAddr(bocomBasicInfo.getRegisteredAddress());
            pptmBody.setOprAddr(bocomBasicInfo.getBusinessAddress());
            pptmBody.setOprScope(bocomBasicInfo.getBusinessScope());
            if (bocomBasicInfo.getCustomerType() == 0) {
                pptmBody.setCustTp("B");

                //企业可变更
                //1.单位名称、营业执照、证件过期时间、注册地址
                //2.法人证件号码、法人身份证、法人姓名、法人手机号、证件有效期
                //3.授权代理人证件号码、授权代理人身份证、姓名、手机号、证件有效期

                //法人
                BocomLegalPersonInfo bocomLegalPersonInfo = bocomBasicInfo.getBocomLegalPersonInfo();
                pptmBody.setLglRprsNme(bocomLegalPersonInfo.getName());
                String certificateType = bocomLegalPersonInfo.getCertificateType();
                String lglRprsIdTp = certificateType.split("_")[1];
                pptmBody.setLglRprsIdTp(lglRprsIdTp);
                pptmBody.setLglRprsIdNo(bocomLegalPersonInfo.getCertificateCode());
                pptmBody.setLglRprsIdVldDt(bocomLegalPersonInfo.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                pptmBody.setLglRprsIdVldDt("20440101");
                pptmBody.setLglRprsPhoneNo(bocomLegalPersonInfo.getPhoneNumber());
                FileStorageDO legalPersonInfoFrontFile = bocomLegalPersonInfo.getFrontFile();
                FileUploadResponseV1 fileUploadResponseV12 = bocomApiService.fileUploadV1(new File(legalPersonInfoFrontFile.getAbsolutePath()));
                pptmBody.setLrIdImgFrtId(fileUploadResponseV12.getDocumentId());
                FileStorageDO backFile1 = bocomLegalPersonInfo.getBackFile();
                FileUploadResponseV1 fileUploadResponseV13 = bocomApiService.fileUploadV1(new File(backFile1.getAbsolutePath()));
                pptmBody.setLrIdImgBackId(fileUploadResponseV13.getDocumentId());
                //营业执照
                FileStorageDO file = bocomBasicInfo.getFile();
                FileUploadResponseV1 bsnLicImg = bocomApiService.fileUploadV1(new File(file.getAbsolutePath()));
                pptmBody.setBsnLicImgId(bsnLicImg.getDocumentId());
                //国别
                String registeredCountry = bocomBasicInfo.getRegisteredCountry();
                String country = registeredCountry.split("_")[1];
                pptmBody.setCtzn(country);
            } else if (bocomBasicInfo.getCustomerType() == 1) {
                //个体工商户可变更 1.企业;2.授权代理人;3.负责人
                pptmBody.setCustTp("G");
                List<BocomShareholderActualController> bocomShareholderActualControllers = bocomBasicInfo.getBocomShareholderActualControllers();
                BocomShareholderActualController bocomShareholderActualController = bocomShareholderActualControllers.get(0);
                //负责人
                pptmBody.setRspsbPrsNme(bocomShareholderActualController.getName());
                String certificateTypeShareholderActualController = bocomShareholderActualController.getCertificateType();
                String cntlgSrhdrIdTp = certificateTypeShareholderActualController.split("_")[1];
                pptmBody.setRspsbPrsIdTp(cntlgSrhdrIdTp);
                pptmBody.setRspsbPrsIdNo(bocomShareholderActualController.getCertificateCode());
                pptmBody.setRspsbPrsIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
                FileStorageDO controllerFrontFile = bocomShareholderActualController.getFrontFile();
                FileUploadResponseV1 fileUploadV1 = bocomApiService.fileUploadV1(new File(controllerFrontFile.getAbsolutePath()));
                pptmBody.setLrIdImgFrtId(fileUploadV1.getDocumentId());
                FileStorageDO actualControllerBackFile = bocomShareholderActualController.getBackFile();
                FileUploadResponseV1 uploadV1 = bocomApiService.fileUploadV1(new File(actualControllerBackFile.getAbsolutePath()));
                pptmBody.setLrIdImgBackId(uploadV1.getDocumentId());
                // TODO: 2024/8/13 测试后删除
                pptmBody.setRspsbPrsIdVldDt("20440101");
                pptmBody.setRspsbPrsCntctPhoneNo(bocomShareholderActualController.getPhoneNumber());
                //实控人
                pptmBody.setAtlctlPrsNme(bocomShareholderActualController.getName());
                pptmBody.setAtlctlPrsIdTp(cntlgSrhdrIdTp);
                pptmBody.setAtlctlPrsIdNo(bocomShareholderActualController.getCertificateCode());
                pptmBody.setAtlctlPrsIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                pptmBody.setAtlctlPrsIdVldDt("20440101");
                //受益人
                List<B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy> bfyList = new ArrayList<>();
                B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy bfy = new B2BJEBM1101RequestV2.B2BJEBM1101RequestV2Biz.PptmBody.Bfy();
                bfy.setBenryNme(bocomShareholderActualController.getName());
                String certificateType = bocomShareholderActualController.getCertificateType();
                String benryIdTp = certificateType.split("_")[1];
                bfy.setBenryIdTp(benryIdTp);
                bfy.setBenryIdNo(bocomShareholderActualController.getCertificateCode());
                bfy.setBenryIdVldDt(bocomShareholderActualController.getPeriodOfValidity().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                bfy.setBenryIdVldDt("20440101");
                String countryBenry = bocomShareholderActualController.getCountry();
                String countryStr = countryBenry.split("_")[1];
                bfy.setBenryCtzn(countryStr);
                bfy.setBenryAddr(bocomShareholderActualController.getAddress());
                FileStorageDO frontFileBenry = bocomShareholderActualController.getFrontFile();
                FileUploadResponseV1 frontFileRes = bocomApiService.fileUploadV1(new File(frontFileBenry.getAbsolutePath()));
                bfy.setBenryIdImgFrtId(frontFileRes.getDocumentId());
                FileStorageDO backFileBenry = bocomShareholderActualController.getBackFile();
                FileUploadResponseV1 backFileRes = bocomApiService.fileUploadV1(new File(backFileBenry.getAbsolutePath()));
                bfy.setBenryIdImgBackId(backFileRes.getDocumentId());
                bfyList.add(bfy);
                pptmBody.setBfyList(bfyList);
                //营业执照
                FileStorageDO file = bocomBasicInfo.getFile();
                FileUploadResponseV1 bsnLicImg = bocomApiService.fileUploadV1(new File(file.getAbsolutePath()));
                pptmBody.setBsnLicImgId(bsnLicImg.getDocumentId());
                //国别
                String registeredCountry = bocomBasicInfo.getRegisteredCountry();
                String country = registeredCountry.split("_")[1];
                pptmBody.setCtzn(country);

            } else if (bocomBasicInfo.getCustomerType() == 2) {
                // 客户类别 新增时必送  P-个人  B-企业  G-个体工商户
                pptmBody.setCustTp("P");
                //个人姓名
                pptmBody.setPsnlCustNme(bocomBasicInfo.getCustomerName());
                pptmBody.setPsnlIdTp(cmpyIdTp);
                //个人证件号码
                pptmBody.setPsnlIdNo(bocomBasicInfo.getSocialCreditCode());
                //个人证件有效期
                pptmBody.setPsnlIdVldDt(bocomBasicInfo.getCertificateExpirationDate().replace("-", ""));
                // TODO: 2024/8/13 测试后删除
                pptmBody.setPsnlIdVldDt("20440101");
                //个人手机号
                pptmBody.setPsnlVldIdNo(bocomBasicInfo.getPhoneNumber());
                //联系地址
                pptmBody.setCntctAddr(bocomBasicInfo.getContactAddress());
                //国别
                String registeredCountry = bocomBasicInfo.getRegisteredCountry();
                String country = registeredCountry.split("_")[1];
                pptmBody.setCtzn(country);
                //职业
                String occupation = bocomBasicInfo.getOccupation().split("_")[1];
                pptmBody.setOcp(occupation);
                //性别
                Integer gender = bocomBasicInfo.getGender();
                String genderStr = gender == 0 ? "男" : "女";
                pptmBody.setGender(genderStr);
            } else {
                throw new BusinessException(CodeUtil.FAIL, "企业信息错误！");
            }
        }

        pptmBody.setModfCntlWord(modfCntlWord);

        b2BJEBM1101RequestV2Biz.setPptmBody(pptmBody);
        b2BJEBM1101RequestV2.setBizContent(b2BJEBM1101RequestV2Biz);
        B2BJEBM1101ResponseV2 b2BJEBM1101ResponseV2 = bocomApiService.sendToBocom(b2BJEBM1101RequestV2, BocomApiConstant.B2BJEBM_1101_URL);
        B2BJEBM1101ResponseV2.PptmBody body = b2BJEBM1101ResponseV2.getPptmBody();
        if (!b2BJEBM1101ResponseV2.isSuccess() || body.getCustSts() == null) {
            String returnMsg = b2BJEBM1101ResponseV2.getPptmHead().getReturnMsg();
            throw new BusinessException(CodeUtil.FAIL, "交行变更失败" + returnMsg);
        }
        //填充授权二维码和通知推送对象
        if (CollectionUtil.isNotEmpty(body.getNotyQue())) {
            body.getNotyQue().forEach(notyQue -> {
                if ("1".equals(notyQue.getNotyPushObj())) {
                    bocomBasicInfo.setQrCode(notyQue.getMerchNotyBase64Stream());
                    bocomBasicInfo.setQrCodeEffectTime(new Date());
                    bocomBasicInfo.setPushPerson("法人");
                    bocomBasicInfo.setChangePlatformSerialNumber(plfmSerNo);
                }
            });
        }
        lambdaUpdate().eq(BocomBasicInfo::getId, bocomBasicInfo.getId())
                .set(BocomBasicInfo::getQrCode, bocomBasicInfo.getQrCode())
                .update();

        //变更会员信息后 在途（非生效状态）的会员登记簿置为失效状态
        bocomVipAccountBasicInfoService.lambdaUpdate()
                .eq(BocomVipAccountBasicInfo::getBocomBasicInfoId, bocomBasicInfo.getId())
                .notIn(BocomVipAccountBasicInfo::getChdbokSts, 1)
                .set(BocomVipAccountBasicInfo::getAccountStatus, 3)
                .set(BocomVipAccountBasicInfo::getAccountStatusReal, BocomVipAccountStatusDic.ChildEnum.VIP_ACCOUNT_PENDING_EXPIRE.getCode())
                .update();

    }

    /**
     * 修改时校验
     *
     * @param bocomBasicInfo
     */
    private void checkUpdateBocom(BocomBasicInfo bocomBasicInfo) {
        if (bocomBasicInfo.getId() == null) {
            throw new BusinessException(CodeUtil.FAIL, "账户id不能为空！");
        }
        BocomBasicInfo oldBocomBasicInfo = get(bocomBasicInfo.getId());
        if (!oldBocomBasicInfo.getCustomerNumber().contains("PT")) {
            throw new BusinessException(CodeUtil.FAIL, "当前客户信息不允许修改！");
        }

        //单位名称
        if (!oldBocomBasicInfo.getCustomerName().equals(bocomBasicInfo.getCustomerName())) {
            throw new BusinessException(CodeUtil.FAIL, "单位名称、法人证件号码、授权代理人证件号码“不可修改，如需修改请走变更流程！");
        }
        // 法人
        BocomLegalPersonInfo newLegalPersonInfo = bocomBasicInfo.getBocomLegalPersonInfo();
        if (newLegalPersonInfo != null) {
            BocomLegalPersonInfo oldLegalPersonInfo = bocomLegalPersonInfoService.lambdaQuery()
                    .eq(BocomLegalPersonInfo::getBocomBasicInfoId, bocomBasicInfo.getId())
                    .one();
            if (oldLegalPersonInfo != null) {
                if (!newLegalPersonInfo.getCertificateCode().equals(oldLegalPersonInfo.getCertificateCode())) {
                    throw new BusinessException(CodeUtil.FAIL, "单位名称、法人证件号码、授权代理人证件号码“不可修改，如需修改请走变更流程！");
                }
            }
        }

        //授权代理人
        BocomAuthorizedAgent newAuthorizedAgent = bocomBasicInfo.getBocomAuthorizedAgent();
        if (newAuthorizedAgent != null) {
            BocomAuthorizedAgent oldAuthorizedAgent = bocomAuthorizedAgentService.lambdaQuery()
                    .eq(BocomAuthorizedAgent::getBocomBasicInfoId, bocomBasicInfo.getId())
                    .one();
            if (oldAuthorizedAgent != null) {
                if (!oldAuthorizedAgent.getCertificateCode().equals(oldAuthorizedAgent.getCertificateCode())) {
                    throw new BusinessException(CodeUtil.FAIL, "单位名称、法人证件号码、授权代理人证件号码“不可修改，如需修改请走变更流程！");
                }
            }
        }
    }

    /**
     * 变更时校验
     *
     * @param bocomBasicInfo
     */
    private String checkChangeBocom(BocomBasicInfo bocomBasicInfo) {

        String modfCntlWord = "";
        String agentFlag = "0";
        String legalFlag = "0";
        String companyFlag = "0";

        if (bocomBasicInfo.getId() == null) {
            throw new BusinessException(CodeUtil.FAIL, "账户id不能为空！");
        }
        BocomBasicInfo oldBocomBasicInfo = get(bocomBasicInfo.getId());
        if (!bocomBasicInfo.getCustomerName().equals(oldBocomBasicInfo.getCustomerName())) {
            //公司名称变更
            companyFlag = "1";
        }

        //授权代理人
        BocomAuthorizedAgent oldAgent = bocomAuthorizedAgentService.lambdaQuery()
                .eq(BocomAuthorizedAgent::getBocomBasicInfoId, oldBocomBasicInfo.getId())
                .one();
        BocomAuthorizedAgent newAgent = bocomBasicInfo.getBocomAuthorizedAgent();
        if (!oldAgent.getCertificateCode().equals(newAgent.getCertificateCode())) {
            //授权代理人变更
            agentFlag = "1";
        }

        if (oldBocomBasicInfo != null) {
            if (oldBocomBasicInfo.getCustomerNumber().contains("PT")) {
                if (oldBocomBasicInfo.getCustomerType() == 0) {
                    //法人
                    BocomLegalPersonInfo oldLegalPerson = bocomLegalPersonInfoService.lambdaQuery()
                            .eq(BocomLegalPersonInfo::getBocomBasicInfoId, oldBocomBasicInfo.getId())
                            .one();
                    BocomLegalPersonInfo newLegalPersonInfo = bocomBasicInfo.getBocomLegalPersonInfo();

                    if (!oldLegalPerson.getCertificateCode().equals(newLegalPersonInfo.getCertificateCode())) {
                        //法人变更
                        legalFlag = "1";
                        FileStorageDO fileStorageDO = fileService.lambdaQuery().eq(FileStorageDO::getBusinessType, FileModuleDict.ChildEnum.BOCOM_REGISTER_BUSINESS_LICENSE.getCode())
                                .eq(FileStorageDO::getBusinessId, bocomBasicInfo.getId())
                                .orderByDesc(FileStorageDO::getGmtCreate).one();
                        if (fileStorageDO != null && fileStorageDO.getId().equals(bocomBasicInfo.getFileId())) {
                            throw new BusinessException(CodeUtil.FAIL, "公司法人变更必须重新上传营业执照！");
                        }
                        companyFlag = "1";
                    }

                    //如果单位名称、法人证件号码、授权代理人证件号码与原来一致 抛异常
                    if (oldBocomBasicInfo.getCustomerName().equals(bocomBasicInfo.getCustomerName()) &&
                            oldLegalPerson.getCertificateCode().equals(newLegalPersonInfo.getCertificateCode()) &&
                            oldAgent.getCertificateCode().equals(newAgent.getCertificateCode())) {
                        throw new BusinessException(CodeUtil.FAIL, "单位名称、法人证件号码、授权代理人证件号码“未发生变更，其他信息请走修改流程！");
                    }

                } else if (oldBocomBasicInfo.getCustomerType() == 1) {

                    //如果单位名称、授权代理人证件号码与原来一致 抛异常
                    if (oldBocomBasicInfo.getCustomerName().equals(bocomBasicInfo.getCustomerName()) &&
                           oldAgent.getCertificateCode().equals(newAgent.getCertificateCode())) {
                        throw new BusinessException(CodeUtil.FAIL, "单位名称、授权代理人证件号码“未发生变更，其他信息请走修改流程！");
                    }

                }
            } else {

                //法人
                BocomLegalPersonInfo oldLegalPerson = bocomLegalPersonInfoService.lambdaQuery()
                        .eq(BocomLegalPersonInfo::getBocomBasicInfoId, oldBocomBasicInfo.getId())
                        .one();
                BocomLegalPersonInfo newLegalPersonInfo = bocomBasicInfo.getBocomLegalPersonInfo();

                if (!oldBocomBasicInfo.getCustomerName().equals(bocomBasicInfo.getCustomerName()) ||
                        !oldLegalPerson.getCertificateCode().equals(newLegalPersonInfo.getCertificateCode())
                        ) {
                    throw new BusinessException(CodeUtil.FAIL, "当前账户，单位名称和法人不可变更！");
                }

            }
            
        }

        modfCntlWord = "000" + companyFlag + "0000" + legalFlag + agentFlag;
        return modfCntlWord;

    }

    @Override
    public BocomBasicInfo get(Long id) {
        return baseMapper.get(id);
    }

    @Override
    public BocomBasicInfoHistory getView(Long id) {
        //基础信息
        BocomBasicInfoHistory bocomBasicInfo = bocomBasicInfoHistoryService.getById(id);
        FileStorageDO file = fileService.findOneByBusinessId(id, FileModuleDict.ChildEnum.BOCOM_REGISTER_BUSINESS_LICENSE_HISTORY.getCode());
        FileStorageDO customerFront = fileService.findOneByBusinessId(id, FileModuleDict.ChildEnum.BOCOM_IDCARD_FRONT_HISTORY.getCode());
        FileStorageDO customerBack = fileService.findOneByBusinessId(id, FileModuleDict.ChildEnum.BOCOM_IDCARD_BACK_HISTORY.getCode());
        bocomBasicInfo.setFile(file);
        bocomBasicInfo.setFrontFile(customerFront);
        bocomBasicInfo.setBackFile(customerBack);
        BocomLegalPersonInfoHistory bocomLegalPersonInfo = bocomLegalPersonInfoHistoryService.lambdaQuery().eq(BocomLegalPersonInfoHistory::getBocomBasicInfoId, bocomBasicInfo.getId()).one();
        if (bocomLegalPersonInfo != null) {
            FileStorageDO front = fileService.findOneByBusinessId(bocomLegalPersonInfo.getId(), FileModuleDict.ChildEnum.BOCOM_LEGAL_REPRESENTATIVE_IDCARD_FRONT_HISTORY.getCode());
            FileStorageDO back = fileService.findOneByBusinessId(bocomLegalPersonInfo.getId(), FileModuleDict.ChildEnum.BOCOM_LEGAL_REPRESENTATIVE_IDCARD_BACK_HISTORY.getCode());
            bocomLegalPersonInfo.setFrontFile(front);
            bocomLegalPersonInfo.setBackFile(back);
            bocomBasicInfo.setBocomLegalPersonInfo(bocomLegalPersonInfo);
        }
        List<BocomShareholderActualControllerHistory> bocomShareholderActualControllers = bocomShareholderActualControllerHistoryService.lambdaQuery().eq(BocomShareholderActualControllerHistory::getBocomBasicInfoId, bocomBasicInfo.getId()).list();
        if (CollectionUtil.isNotEmpty(bocomShareholderActualControllers)) {
            for (BocomShareholderActualControllerHistory bocomShareholderActualController : bocomShareholderActualControllers) {
                FileStorageDO front = fileService.findOneByBusinessId(bocomShareholderActualController.getId(), FileModuleDict.ChildEnum.BOCOM_SHAREHOLDER_IDCARD_FRONT_HISTORY.getCode());
                FileStorageDO back = fileService.findOneByBusinessId(bocomShareholderActualController.getId(), FileModuleDict.ChildEnum.BOCOM_SHAREHOLDER_IDCARD_BACK_HISTORY.getCode());
                bocomShareholderActualController.setFrontFile(front);
                bocomShareholderActualController.setBackFile(back);
            }
            bocomBasicInfo.setBocomShareholderActualControllers(bocomShareholderActualControllers);
        }
        List<BocomBeneficiaryInfoHistory> bocomBeneficiaryInfos = bocomBeneficiaryInfoHistoryService.lambdaQuery().eq(BocomBeneficiaryInfoHistory::getBocomBasicInfoId, bocomBasicInfo.getId()).list();
        if (CollectionUtil.isNotEmpty(bocomBeneficiaryInfos)) {
            for (BocomBeneficiaryInfoHistory bocomBeneficiaryInfo : bocomBeneficiaryInfos) {
                FileStorageDO front = fileService.findOneByBusinessId(bocomBeneficiaryInfo.getId(), FileModuleDict.ChildEnum.BOCOM_BENEFICIARY_IDCARD_FRONT_HISTORY.getCode());
                FileStorageDO back = fileService.findOneByBusinessId(bocomBeneficiaryInfo.getId(), FileModuleDict.ChildEnum.BOCOM_BENEFICIARY_IDCARD_BACK_HISTORY.getCode());
                bocomBeneficiaryInfo.setFrontFile(front);
                bocomBeneficiaryInfo.setBackFile(back);
            }
            bocomBasicInfo.setBocomBeneficiaryInfos(bocomBeneficiaryInfos);
        }
        BocomAuthorizedAgentHistory bocomAuthorizedAgent = bocomAuthorizedAgentHistoryService.lambdaQuery().eq(BocomAuthorizedAgentHistory::getBocomBasicInfoId, bocomBasicInfo.getId()).one();
        if (bocomAuthorizedAgent != null) {
            FileStorageDO front = fileService.findOneByBusinessId(bocomAuthorizedAgent.getId(), FileModuleDict.ChildEnum.BOCOM_AUTHORIZED_AGENT_IDCARD_FRONT_HISTORY.getCode());
            FileStorageDO back = fileService.findOneByBusinessId(bocomAuthorizedAgent.getId(), FileModuleDict.ChildEnum.BOCOM_AUTHORIZED_AGENT_IDCARD_BACK_HISTORY.getCode());
            bocomAuthorizedAgent.setFrontFile(front);
            bocomAuthorizedAgent.setBackFile(back);
            bocomBasicInfo.setBocomAuthorizedAgent(bocomAuthorizedAgent);
        }
        return bocomBasicInfo;
    }

    @Override
    public EnterpriseDetailVo getBasicDetailsByName(String keyword) {
        //2003 客户身份识别
        ResponseJson responseJson = restTemplate.getForObject(getEnterpriseDetail + "?keyword=" + keyword, ResponseJson.class);
        JSONObject data = new JSONObject(responseJson.getData());
        String date = data.getStr("date");
        if (StringUtil.isEmpty(date)) {
            date = "99991231";
        }
        String scope = data.getStr("scope");
        EnterpriseDetailVo enterpriseDetailVo = new EnterpriseDetailVo();
        enterpriseDetailVo.setDate(date);
        enterpriseDetailVo.setScope(scope);
        //股东信息(工商登记)
        List<JSONObject> partnerList = new ArrayList<>();
        JSONArray partnerArray = data.getJSONArray("partnerList");
        if (CollectionUtil.isNotEmpty(partnerArray)) {
            for (Object o : partnerArray) {
                String name = (String) o;
                if (name.length() <= 4) {
                    JSONObject jsonObject = new JSONObject();
                    jsonObject.set("name", name);
                    jsonObject.set("type", 0);
                    partnerList.add(jsonObject);
                }
            }
        }
        if (CollectionUtil.isEmpty(partnerList)) {
            //实际控制人
            JSONArray actualControlArray = data.getJSONArray("actualControlList");
            if (CollectionUtil.isNotEmpty(actualControlArray)) {
                for (Object o : actualControlArray) {
                    String name = (String) o;
                    if (name.length() <= 4) {
                        JSONObject jsonObject = new JSONObject();
                        jsonObject.set("name", name);
                        jsonObject.set("type", 1);
                        partnerList.add(jsonObject);
                    }
                }
            }
        }
        enterpriseDetailVo.setPartnerList(partnerList);
        //受益所有人
        List<String> beneficialOwnerList = new ArrayList<>();
        JSONArray beneficialOwnerArray = data.getJSONArray("beneficialOwnerList");
        if (CollectionUtil.isNotEmpty(beneficialOwnerArray)) {
            for (Object o : beneficialOwnerArray) {
                String name = (String) o;
                if (name.length() <= 4) {
                    beneficialOwnerList.add(name);
                }
            }
        }
        enterpriseDetailVo.setBeneficialOwnerList(beneficialOwnerList);
        return enterpriseDetailVo;
    }

    @Override
    public BocomBasicInfo findByCustomerNumber(String customerNumber) {
        return baseMapper.findByCustomerNumber(customerNumber);
    }

    @Override
    public List<BocomBasicInfo> findSuccessCustomer() {
        return baseMapper.findSuccessCustomer();
    }

    @Override
    public GridPage<BocomBasicInfo> findUserData(BaseSearch baseSearch) {
        User user = ThreadLocalUtil.getUser();
        Page page = PageHelper.startPage(baseSearch.getPage(), baseSearch.getRows());
        List<BocomBasicInfo> result = this.baseMapper.findUserData(user.getLoginName());
        for (BocomBasicInfo bocomBasicInfo : result) {
            if (StringUtil.isNotEmpty(bocomBasicInfo.getCustomerStatus())) {
                Dictionary status = dictionaryService.getByCode(bocomBasicInfo.getCustomerStatus());
                bocomBasicInfo.setCustomerStatus(status.getName());
            }
            if (StringUtil.isNotEmpty(bocomBasicInfo.getStage())) {
                Dictionary stage = dictionaryService.getByCode(bocomBasicInfo.getStage());
                bocomBasicInfo.setStageStr(stage.getName());
            }
            List<BusinessProcessingLog> businessProcessingLogs = businessProcessingLogService.listForNullValueOfEndTime(bocomBasicInfo.getId(), ConstantUtil.BOCOM_BASIC_INFO);
            if (CollectionUtil.isNotEmpty(businessProcessingLogs)) {
                BusinessProcessingLog businessProcessingLog = businessProcessingLogs.get(0);
                if (businessProcessingLog.getTaskName().equals("审核")) {
                    bocomBasicInfo.setAssigner("风控");
                } else if (businessProcessingLog.getTaskName().equals("用户录入")) {
                    if (bocomBasicInfo.getCustomerSource().equals("贸理通C")) {
                        UserDO userDO = cUserService.getByLoginName(bocomBasicInfo.getUserCreate());
                        bocomBasicInfo.setAssigner(userDO.getUserName());
                    } else if (bocomBasicInfo.getCustomerSource().equals("贸理通B")) {
                        User userServiceByLoginName = userService.getByLoginName(bocomBasicInfo.getUserCreate());
                        bocomBasicInfo.setAssigner(userServiceByLoginName.getName());
                    }
                }
            }
        }
        return new GridPage<>(baseSearch.getRows(), baseSearch.getPage(), page.getTotal(), result);
    }

    @Override
    public void termination(Long id) {

        //存在生效中的登记簿 则不允许终止
        List<BocomVipAccountBasicInfo> vipAccountBasicInfoList = bocomVipAccountBasicInfoService.lambdaQuery().eq(BocomVipAccountBasicInfo::getBocomBasicInfoId, id)
                .eq(BocomVipAccountBasicInfo::getAccountStatusReal, BocomVipAccountStatusDic.ChildEnum.VIP_ACCOUNT_EFFECT.getCode())
                .list();
        if (CollectionUtil.isNotEmpty(vipAccountBasicInfoList)) {
            throw new BusinessException(CodeUtil.FAIL, "存在生效中的账户，不允许终止！");
        }

        BusinessProcessingLog processingLog = new BusinessProcessingLog();
        //查询日志信息
        List<BusinessProcessingLog> businessProcessingLogs = businessProcessingLogService.listForNullValueOfEndTime(id, ConstantUtil.BOCOM_BASIC_INFO);
        if (businessProcessingLogs != null && businessProcessingLogs.size() > 0) {
            BusinessProcessingLog lastLog = businessProcessingLogs.get(businessProcessingLogs.size() - 1);
            //任务是否有正在运行的task
            Boolean hasRunTask = false;
            Set<String> historyTaskId = new HashSet<>();
            for (BusinessProcessingLog businessProcessingLog : businessProcessingLogs) {
                historyTaskId.add(businessProcessingLog.getHistoricTaskId());
            }

            for (String taskId : historyTaskId) {
                String existTaskId = null;
                for (BusinessProcessingLog businessProcessingLog : businessProcessingLogs) {
                    if (taskId.equals(businessProcessingLog.getHistoricTaskId()) && (existTaskId == null || !existTaskId.equals(businessProcessingLog.getHistoricTaskId()))) {
                        existTaskId = businessProcessingLog.getHistoricTaskId();
                        //是否存在task
                        Boolean flag = flowableService.existTask(businessProcessingLog.getHistoricTaskId());
                        if (flag) {
                            hasRunTask = true;
                            String procInstId = taskService.createTaskQuery().taskId(businessProcessingLog.getHistoricTaskId()).singleResult().getProcessInstanceId();
                            ProcessInstance processInstance = runtimeService.createProcessInstanceQuery().processInstanceId(procInstId).singleResult();
                            if (processInstance != null) {
                                List<EndEvent> endNodes;
                                BpmnModel bpmnModel = repositoryService.getBpmnModel(processInstance.getProcessDefinitionId());
                                if (bpmnModel != null) {
                                    Process mainProcess = bpmnModel.getMainProcess();
                                    endNodes = mainProcess.findFlowElementsOfType(EndEvent.class);
                                } else {
                                    throw new BusinessException(CodeUtil.FAIL, "终止失败");
                                }
                                String endId = endNodes.get(0).getId();
                                String processInstanceId = processInstance.getProcessInstanceId();
                                //执行终止
                                List<Execution> executions = runtimeService.createExecutionQuery().parentId(processInstanceId).list();
                                List<String> executionIds = new ArrayList<>();
                                executions.forEach(execution -> executionIds.add(execution.getId()));
                                runtimeService.createChangeActivityStateBuilder().moveExecutionsToSingleActivityId(executionIds, endId).changeState();
                            }
                        }
                    }
                }
            }
            if (hasRunTask) {
                // 2.添加业务处理日志
                processingLog.setBusnessKey(id);
                processingLog.setBusinessType(ConstantUtil.BOCOM_BASIC_INFO);
                processingLog.setHistoricTaskId(lastLog.getHistoricTaskId() + "1");
                processingLog.setAssignee(ThreadLocalUtil.getUser());
                processingLog.setAssigneeType(ConstantConversionUtil.PROCESS_TASK);
                processingLog.setTaskDefKey(lastLog.getTaskDefKey());
                processingLog.setTaskName(ConstantUtil.FPRCEDTERMINATE);
                processingLog.setStatus(ConstantUtil.FPRCEDTERMINATE);
                processingLog.setFormBusinessId(lastLog.getFormBusinessId());
                processingLog.setStartTime(new Date());
                processingLog.setEndTime(new Date());
                businessProcessingLogService.add(processingLog);
            }
        } else {
            // 2.添加业务处理日志
            BusinessProcessingLog businessProcessingLog = businessProcessingLogService.findLastByBusiness(id, ConstantUtil.BOCOM_BASIC_INFO);
            processingLog.setBusnessKey(id);
            processingLog.setBusinessType(ConstantUtil.BOCOM_BASIC_INFO);
            processingLog.setHistoricTaskId(businessProcessingLog.getHistoricTaskId() + "1");
            processingLog.setAssignee(ThreadLocalUtil.getUser());
            processingLog.setAssigneeType(ConstantConversionUtil.PROCESS_TASK);
            processingLog.setTaskDefKey(businessProcessingLog.getTaskDefKey());
            processingLog.setTaskName(ConstantUtil.FPRCEDTERMINATE);
            processingLog.setStatus(ConstantUtil.FPRCEDTERMINATE);
            processingLog.setFormBusinessId(businessProcessingLog.getFormBusinessId());
            processingLog.setStartTime(new Date());
            processingLog.setEndTime(new Date());
            businessProcessingLogService.add(processingLog);
        }
        this.lambdaUpdate().eq(BocomBasicInfo::getId, id).set(BocomBasicInfo::getStage, BocomCustomerStageEnums.TERMINATION.getCode()).set(BocomBasicInfo::getCustomerStatus, BocomCustomerStatuEnums.TERMINATION.getCode()).update();
    }

    @Override
    public void batchReSearch() {
        List<BocomBasicInfo> list = this.baseMapper.findAll();
        if (CollectionUtil.isNotEmpty(list)) {
            list.forEach(basic -> {
                research(basic.getId());
            });
        }
    }

    @Override
    public void research(Long id) {
        BocomBasicInfo bocomBasicInfo = get(id);
        B2BJEBM1102RequestV2 b2BJEBM1102RequestV2 = new B2BJEBM1102RequestV2();
        B2BJEBM1102RequestV2.B2BJEBM1102RequestV2Biz b2BJEBM1102RequestV2Biz = new B2BJEBM1102RequestV2.B2BJEBM1102RequestV2Biz();
        B2BJEBM1102RequestV2.B2BJEBM1102RequestV2Biz.PptmBody pptmBody = new B2BJEBM1102RequestV2.B2BJEBM1102RequestV2Biz.PptmBody();
        pptmBody.setOprTp("1");
        pptmBody.setMshpCustId(bocomBasicInfo.getCustomerNumber());
        b2BJEBM1102RequestV2Biz.setPptmBody(pptmBody);
        b2BJEBM1102RequestV2.setBizContent(b2BJEBM1102RequestV2Biz);
        B2BJEBM1102ResponseV2 b2BJEBM1102ResponseV2 = bocomApiService.sendToBocom(b2BJEBM1102RequestV2, BocomApiConstant.B2BJEBM_1102_URL);
        B2BJEBM1102ResponseV2.PptmBody body = b2BJEBM1102ResponseV2.getPptmBody();
        if (!b2BJEBM1102ResponseV2.isSuccess() || body.getCustSts() == null) {
            String returnMsg = b2BJEBM1102ResponseV2.getPptmHead().getReturnMsg();
            throw new BusinessException(CodeUtil.FAIL, "刷新失败!" + returnMsg);
        } else {
            String custSts = body.getCustSts();
            Integer custStsInt = Integer.valueOf(custSts);
            bocomBasicInfo.setCustSts(custStsInt);
            String vrfySts = body.getCustInfVrfySts();
            if (StringUtil.isNotEmpty(vrfySts)) {
                if (vrfySts.equals("0")) {
                    vrfySts = "待系统核验";
                    bocomBasicInfo.setStage(BocomCustomerStageEnums.SUBMIT.getCode());
                } else if (vrfySts.equals("1")) {
                    vrfySts = "核验成功";
                    bocomBasicInfo.setStage("");
                } else if (vrfySts.equals("2")) {
                    vrfySts = "核验失败";
                    bocomBasicInfo.setStage("");
                } else if (vrfySts.equals("3")) {
                    vrfySts = "系统核验中";
                    bocomBasicInfo.setStage(BocomCustomerStageEnums.SUBMIT.getCode());
                } else if (vrfySts.equals("4")) {
                    vrfySts = "银行审核中";
                    bocomBasicInfo.setStage("");
                }
            }
            if (custSts.equals("2")) {
                bocomBasicInfo.setCustomerStatus(BocomCustomerStatuEnums.TERMINATION.getCode());
                bocomBasicInfo.setStage("");
            }
            bocomBasicInfo.setVerificationStatus(vrfySts);
            String userAtuhSts = body.getUserAtuhSts();
            //0-待用户授权 1-银行审核中 2-授权失败(用户拒绝)3-授权失败(银行拒绝)4-授权成
            if (userAtuhSts.equals("0")) {
                userAtuhSts = "待用户授权";
            } else if (userAtuhSts.equals("1")) {
                userAtuhSts = "银行审核中";
            } else if (userAtuhSts.equals("2")) {
                userAtuhSts = "授权失败(用户拒绝)";
            } else if (userAtuhSts.equals("3")) {
                userAtuhSts = "授权失败(银行拒绝)";
            } else if (userAtuhSts.equals("4")) {
                userAtuhSts = "授权成功";
            }
            bocomBasicInfo.setUserAtuhSts(userAtuhSts);
            String vrfyFailStsWord = body.getVrfyFailStsWord();
            bocomBasicInfo.setVrfyFailStsWord(vrfyFailStsWord);
            autoCustomerRealStatus(bocomBasicInfo);
            this.updateById(bocomBasicInfo);
        }
    }

    @Override
    public GridPage<BocomBasicInfo> findBySearch(BocomSearchVo bocomSearchVo) {
        Long currentUserId = ThreadLocalUtil.getUserId();
        List<Long> pers = permissionService.getPermissionIdByUserId(currentUserId);
        Permission per = permissionService.getByEname(ConstantConversionUtil.VIEW_ALL_BOCOM);
        if (per == null) {
            throw new ValidatorException(CodeUtil.FAIL, "数据可见-查看全员权限不能为空");
        }
        if (!pers.contains(per.getId())
                && !ThreadLocalUtil.getUser().getLoginName().equals(ConstantConversionUtil.ADMINISTORIES)) {
            User user = ThreadLocalUtil.getUser();
            String loginName = user.getLoginName();
            bocomSearchVo.setLoginName(loginName);
        }
        Page page = PageHelper.startPage(bocomSearchVo.getPage(), bocomSearchVo.getRows());
        List<BocomBasicInfo> basicInfos = baseMapper.findBySearch(bocomSearchVo);
        for (BocomBasicInfo basicInfo : basicInfos) {
            if (StringUtil.isNotEmpty(basicInfo.getCustomerStatus())) {
                Dictionary status = dictionaryService.getByCode(basicInfo.getCustomerStatus());
                basicInfo.setCustomerStatus(status.getName());
            }
            if (StringUtil.isNotEmpty(basicInfo.getStage())) {
                Dictionary stage = dictionaryService.getByCode(basicInfo.getStage());
                basicInfo.setStageStr(stage.getName());
            }
            List<BusinessProcessingLog> businessProcessingLogs = businessProcessingLogService.listForNullValueOfEndTime(basicInfo.getId(), ConstantUtil.BOCOM_BASIC_INFO);
            if (CollectionUtil.isNotEmpty(businessProcessingLogs)) {
                BusinessProcessingLog businessProcessingLog = businessProcessingLogs.get(0);
                if (businessProcessingLog.getTaskName().equals("审核")) {
                    basicInfo.setAssigner("风控");
                } else if (businessProcessingLog.getTaskName().equals("用户录入")) {
                    if (basicInfo.getCustomerSource().equals("贸理通C")) {
                        UserDO userDO = cUserService.getByLoginName(basicInfo.getUserCreate());
                        basicInfo.setAssigner(userDO.getUserName());
                    } else if (basicInfo.getCustomerSource().equals("贸理通B")) {
                        User user = userService.getByLoginName(basicInfo.getUserCreate());
                        basicInfo.setAssigner(user.getName());
                    }
                }
            }
            List<BusinessProcessingLogDetailVo> byBusiness = businessProcessingLogService.findByBusiness(basicInfo.getId(), ConstantUtil.BOCOM_BASIC_INFO);
            if (CollectionUtil.isNotEmpty(byBusiness)) {
                basicInfo.setButton(false);
            } else {
                User user = userService.getByLoginName(basicInfo.getUserCreate());
                if (user != null) {
                    basicInfo.setButton(true);
                } else {
                    basicInfo.setButton(false);
                }
            }
            String vrfyFailStsWord = basicInfo.getVrfyFailStsWord();
            if (StringUtil.isNotEmpty(vrfyFailStsWord)) {
                char charToFind = '1';
                int index = vrfyFailStsWord.indexOf(charToFind);
                if (index >= 0) {
                    basicInfo.setReason(true);
                }
            }
            autoAddVipAccountFlag(basicInfo);

            //填充法人授权人
            if (basicInfo.getCustomerType() == 0) {
                BocomLegalPersonInfo legalPersonInfo = bocomLegalPersonInfoService.lambdaQuery()
                        .eq(BocomLegalPersonInfo::getBocomBasicInfoId, basicInfo.getId())
                        .one();
                if (legalPersonInfo != null) {
                    basicInfo.setAuthenticator(legalPersonInfo.getName());
                }
            } else if (basicInfo.getCustomerType() == 1) {
                BocomShareholderActualController actualController = bocomShareholderActualControllerService.lambdaQuery()
                        .eq(BocomShareholderActualController::getBocomBasicInfoId, basicInfo.getId())
                        .eq(BocomShareholderActualController::getPersonType, 2)
                        .one();
                if (actualController != null) {
                    basicInfo.setAuthenticator(actualController.getName());
                }
            }
        }
        return new GridPage<>(bocomSearchVo.getRows(), bocomSearchVo.getPage(), page.getTotal(), page.getResult());
    }

    private void updateInfo(BocomBasicInfo bocomBasicInfo) {
        //删除之前的文件
        fileService.lambdaUpdate().eq(FileStorageDO::getBusinessType, FileModuleDict.ChildEnum.BOCOM_REGISTER_BUSINESS_LICENSE.getCode()).eq(FileStorageDO::getBusinessId, bocomBasicInfo.getId()).set(FileStorageDO::getBusinessId, null).update();
        Long fileId = bocomBasicInfo.getFileId();
        Long front1 = bocomBasicInfo.getFront();
        Long back1 = bocomBasicInfo.getBack();
        if (fileId != null) {
            FileStorageDO fileStorageDO = fileService.getById(fileId);
            fileStorageDO.setId(null);
            fileStorageDO.setBusinessId(bocomBasicInfo.getId());
            fileService.save(fileStorageDO);
        }
        if (front1 != null) {
            FileStorageDO fileStorageDO = fileService.getById(front1);
            fileStorageDO.setId(null);
            fileStorageDO.setBusinessId(bocomBasicInfo.getId());
            fileService.save(fileStorageDO);
        }
        if (back1 != null) {
            FileStorageDO fileStorageDO = fileService.getById(back1);
            fileStorageDO.setId(null);
            fileStorageDO.setBusinessId(bocomBasicInfo.getId());
            fileService.save(fileStorageDO);
        }
        //删除历史数据
        bocomLegalPersonInfoService.lambdaUpdate().eq(BocomLegalPersonInfo::getBocomBasicInfoId, bocomBasicInfo.getId()).remove();
        bocomShareholderActualControllerService.lambdaUpdate().eq(BocomShareholderActualController::getBocomBasicInfoId, bocomBasicInfo.getId()).remove();
        bocomBeneficiaryInfoService.lambdaUpdate().eq(BocomBeneficiaryInfo::getBocomBasicInfoId, bocomBasicInfo.getId()).remove();
        bocomAuthorizedAgentService.lambdaUpdate().eq(BocomAuthorizedAgent::getBocomBasicInfoId, bocomBasicInfo.getId()).remove();
        //保存新数据
        BocomLegalPersonInfo bocomLegalPersonInfo = bocomBasicInfo.getBocomLegalPersonInfo();
        if (bocomLegalPersonInfo != null) {
            bocomLegalPersonInfo.setBocomBasicInfoId(bocomBasicInfo.getId());
            bocomLegalPersonInfoService.save(bocomLegalPersonInfo);
            Long front = bocomLegalPersonInfo.getFront();
            if (front != null) {
                FileStorageDO fileStorageDO = fileService.getById(front);
                fileStorageDO.setId(null);
                fileStorageDO.setBusinessId(bocomLegalPersonInfo.getId());
                fileService.save(fileStorageDO);
            }
            Long back = bocomLegalPersonInfo.getBack();
            if (back != null) {
                FileStorageDO fileStorageDOBack = fileService.getById(back);
                fileStorageDOBack.setId(null);
                fileStorageDOBack.setBusinessId(bocomLegalPersonInfo.getId());
                fileService.save(fileStorageDOBack);
            }
        }
        List<BocomShareholderActualController> bocomShareholderActualControllers = bocomBasicInfo.getBocomShareholderActualControllers();
        if (CollectionUtil.isNotEmpty(bocomShareholderActualControllers)) {
            for (BocomShareholderActualController bocomShareholderActualController : bocomShareholderActualControllers) {
                bocomShareholderActualController.setBocomBasicInfoId(bocomBasicInfo.getId());
                bocomShareholderActualControllerService.save(bocomShareholderActualController);
                Long front = bocomShareholderActualController.getFront();
                if (front != null) {
                    FileStorageDO fileStorageDO = fileService.getById(front);
                    fileStorageDO.setId(null);
                    fileStorageDO.setBusinessId(bocomShareholderActualController.getId());
                    fileStorageDO.setBusinessType(FileModuleDict.ChildEnum.BOCOM_SHAREHOLDER_IDCARD_FRONT.getCode());
                    fileService.save(fileStorageDO);
                }
                Long back = bocomShareholderActualController.getBack();
                if (back != null) {
                    FileStorageDO fileStorageDOBack = fileService.getById(back);
                    fileStorageDOBack.setId(null);
                    fileStorageDOBack.setBusinessId(bocomShareholderActualController.getId());
                    fileStorageDOBack.setBusinessType(FileModuleDict.ChildEnum.BOCOM_SHAREHOLDER_IDCARD_BACK.getCode());
                    fileService.save(fileStorageDOBack);
                }
            }
        }
        List<BocomBeneficiaryInfo> bocomBeneficiaryInfos = bocomBasicInfo.getBocomBeneficiaryInfos();
        if (CollectionUtil.isNotEmpty(bocomBeneficiaryInfos)) {
            for (BocomBeneficiaryInfo bocomBeneficiaryInfo : bocomBeneficiaryInfos) {
                bocomBeneficiaryInfo.setBocomBasicInfoId(bocomBasicInfo.getId());
                bocomBeneficiaryInfoService.save(bocomBeneficiaryInfo);
                Long front = bocomBeneficiaryInfo.getFront();
                if (front != null) {
                    FileStorageDO fileStorageDO = fileService.getById(front);
                    fileStorageDO.setId(null);
                    fileStorageDO.setBusinessId(bocomBeneficiaryInfo.getId());
                    fileStorageDO.setBusinessType(FileModuleDict.ChildEnum.BOCOM_BENEFICIARY_IDCARD_FRONT.getCode());
                    fileService.save(fileStorageDO);
                }
                Long back = bocomBeneficiaryInfo.getBack();
                if (back != null) {
                    FileStorageDO fileStorageDOBack = fileService.getById(back);
                    fileStorageDOBack.setId(null);
                    fileStorageDOBack.setBusinessId(bocomBeneficiaryInfo.getId());
                    fileStorageDOBack.setBusinessType(FileModuleDict.ChildEnum.BOCOM_BENEFICIARY_IDCARD_BACK.getCode());
                    fileService.save(fileStorageDOBack);
                }
            }
        }
        BocomAuthorizedAgent bocomAuthorizedAgent = bocomBasicInfo.getBocomAuthorizedAgent();
        if (bocomAuthorizedAgent != null) {
            bocomAuthorizedAgent.setBocomBasicInfoId(bocomBasicInfo.getId());
            bocomAuthorizedAgentService.save(bocomAuthorizedAgent);
            Long front = bocomAuthorizedAgent.getFront();
            if (front != null) {
                FileStorageDO fileStorageDO = fileService.getById(front);
                fileStorageDO.setId(null);
                fileStorageDO.setBusinessId(bocomAuthorizedAgent.getId());
                fileStorageDO.setBusinessType(FileModuleDict.ChildEnum.BOCOM_AUTHORIZED_AGENT_IDCARD_FRONT.getCode());
                fileService.save(fileStorageDO);
            }
            Long back = bocomAuthorizedAgent.getBack();
            if (back != null) {
                FileStorageDO fileStorageDOBack = fileService.getById(back);
                fileStorageDOBack.setId(null);
                fileStorageDOBack.setBusinessId(bocomAuthorizedAgent.getId());
                fileStorageDOBack.setBusinessType(FileModuleDict.ChildEnum.BOCOM_AUTHORIZED_AGENT_IDCARD_BACK.getCode());
                fileService.save(fileStorageDOBack);
            }
        }
        if (bocomBasicInfo.getVisible()) {
            //保存历史
            Long historyId = addHistory(bocomBasicInfo);
            bocomBasicInfo.setHistoryId(historyId);
        }
        this.updateById(bocomBasicInfo);
    }

    /**
     * 填充是否可以新增会员登记簿
     *
     * @param bocomBasicInfo
     */
    private void autoAddVipAccountFlag(BocomBasicInfo bocomBasicInfo) {

        if (bocomBasicInfo != null) {
            //客户状态为生效 且 该客户名下不存在待生效的登记簿 或者 该客户下账户状态为 生效的 会员登记簿少于五个时 展示新增账户按钮
            Integer addVipAccount = 1;
            if (BocomCustomerStatuEnums.SUCCESS.getCode().equals(bocomBasicInfo.getCustomerStatus())) {
                List<BocomVipAccountBasicInfo> vipAccountBasicInfoList = bocomVipAccountBasicInfoService.lambdaQuery()
                        .eq(BocomVipAccountBasicInfo::getBocomBasicInfoId, bocomBasicInfo.getId())
                        .list();
                if (CollectionUtil.isNotEmpty(vipAccountBasicInfoList)) {

                    long count = vipAccountBasicInfoList.stream().filter(c -> "待生效".equals(c.getAccountStatusReal())).count();
                    if (count > 0) {
                        addVipAccount = 0;
                    }
                    long effectCount = vipAccountBasicInfoList.stream().filter(c -> c.getAccountStatus() == 1).count();
                    if (effectCount > 4) {
                        addVipAccount = 0;
                    }
                }

            }

            bocomBasicInfo.setAddVipAccount(addVipAccount);
        }

    }

    /**
     * 填充账户真实状态
     *
     * @param vipAccountBasicInfo
     */
//    private void autoAccountRealStatus(BocomVipAccountBasicInfo vipAccountBasicInfo) {
//
//        if (vipAccountBasicInfo != null) {
//            BocomVipLimitInfo vipLimitInfo = bocomVipLimitInfoService
//                    .lambdaQuery()
//                    .eq(BocomVipLimitInfo::getBocomVipAccountBasicInfoId, vipAccountBasicInfo.getId())
//                    .one();
//            String realStatus = "";
//            if (vipAccountBasicInfo.getAccountStatus() == 1) {
//                // 授权状态 0-待用户授权 1-银行审核中 2-授权失败（用户拒绝）3-授权失败（银行拒绝）4-授权成功
//                //授权代理人授权状态
//                Integer authorizationStatus = vipAccountBasicInfo.getAuthorizationStatus();
//                //法人授权状态
//                Integer legalAuthorizationStatus = vipAccountBasicInfo.getLegalAuthorizationStatus();
//
//
//                if (authorizationStatus == 1 || legalAuthorizationStatus == 1 ||
//                        authorizationStatus == 2 || legalAuthorizationStatus == 2 ||
//                        authorizationStatus == 3 || legalAuthorizationStatus == 3) {
//                    //任一授权状态为 1/2/3 时 账户真实状态置为 开通失败
//                    realStatus = "开通失败";
//                }
//
//                if ((authorizationStatus == 0 || authorizationStatus == 4) && (authorizationStatus == 0 || authorizationStatus == 4)) {
//                    //授权状态组合为 0+0 || 0+4 时 且 可收可付款（无收入管控且无支出管控）且 接口返回的登记簿状态为是生效 时  账户真实状态置为 生效
//                    if (vipAccountBasicInfo.getChdbokSts() != null && vipAccountBasicInfo.getChdbokSts() == 1 || (vipLimitInfo != null && vipLimitInfo.getIncFlg() == 1 && vipLimitInfo.getPayFlg() == 1)) {
//                        realStatus = "生效";
//                    } else {
//                        //授权状态组合为 0+0 || 0+4 时 且 可收可付款（无收入管控且无支出管控） 时  账户真实状态置为 待生效
//                        realStatus = "待生效";
//                    }
//                }
//
//                if (authorizationStatus == 4 && authorizationStatus == 4) {
//                    //授权状态组合为 4+4 且 可收可付款（无收入管控且无支出管控） 时  账户真实状态置 为 生效
//                    if (vipAccountBasicInfo.getChdbokSts() != null && vipAccountBasicInfo.getChdbokSts() == 1 || (vipLimitInfo != null && vipLimitInfo.getIncFlg() == 1 && vipLimitInfo.getPayFlg() == 1)) {
//                        realStatus = "生效";
//                    }
//                }
//
//            } else {
//                realStatus = "失效";
//            }
//
//            vipAccountBasicInfo.setAccountStatusReal(realStatus);
//        }
//    }

    /**
     * 填充客户真实状态
     *
     * @param bocomBasicInfo
     */
    private void autoCustomerRealStatus(BocomBasicInfo bocomBasicInfo) {
        if (bocomBasicInfo != null) {
            if (bocomBasicInfo.getCustSts() == 1 &&
                    ("待系统核验".equals(bocomBasicInfo.getVerificationStatus()) || "系统核验中".equals(bocomBasicInfo.getVerificationStatus()))) {
                // 生效 + 待系统核验/系统核验中 = 待生效
                bocomBasicInfo.setCustomerStatus(BocomCustomerStatuEnums.OPENING.getCode());
            }
            if (bocomBasicInfo.getCustSts() == 1 && "核验成功".equals(bocomBasicInfo.getVerificationStatus())) {
                // 生效 + 核验成功 = 生效
                bocomBasicInfo.setCustomerStatus(BocomCustomerStatuEnums.SUCCESS.getCode());
            }
            if (bocomBasicInfo.getCustSts() == 1 && "银行审核中".equals(bocomBasicInfo.getVerificationStatus())) {
                // 生效 + 银行审核中 = 开通失败
                bocomBasicInfo.setCustomerStatus(BocomCustomerStatuEnums.FAIL.getCode());
            }
            if (bocomBasicInfo.getCustSts() == null && "核验失败".equals(bocomBasicInfo.getVerificationStatus())) {
                // null + 核验失败 = 开通失败
                bocomBasicInfo.setCustomerStatus(BocomCustomerStatuEnums.FAIL.getCode());
            }
            if (bocomBasicInfo.getCustSts() == 2) {
                bocomBasicInfo.setCustomerStatus(BocomCustomerStatuEnums.TERMINATION.getCode());
            }
            if (bocomBasicInfo.getCustSts() == null && StringUtil.isEmpty(bocomBasicInfo.getVerificationStatus())) {
                bocomBasicInfo.setCustomerStatus(BocomCustomerStatuEnums.TERMINATION.getCode());
            }

        }
    }

    /**
     * 重置法人授权二维码
     *
     * @param bocomBasicInfo
     */
    private void resetUrlAuthorized(BocomBasicInfo bocomBasicInfo) {

        if (bocomBasicInfo != null) {


            B2BJEBM2001RequestV1 b2BJEBM2001RequestV1 = new B2BJEBM2001RequestV1();
            B2BJEBM2001RequestV1.B2BJEBM2001RequestV1Biz b2BJEBM2001RequestV1Biz = new B2BJEBM2001RequestV1.B2BJEBM2001RequestV1Biz();
            B2BJEBM2001RequestV1.B2BJEBM2001RequestV1Biz.PptmBody pptmBody = new B2BJEBM2001RequestV1.B2BJEBM2001RequestV1Biz.PptmBody();

            //平台流水号
            pptmBody.setPlfmSerNo(bocomBasicInfo.getChangePlatformSerialNumber());
            //会员客户号
            pptmBody.setMshpCustId(bocomBasicInfo.getCustomerNumber());
            //功能码 01--查询 02--重置 03--登记簿开立授权
            pptmBody.setFuncCode("02");


            b2BJEBM2001RequestV1Biz.setPptmBody(pptmBody);
            b2BJEBM2001RequestV1.setBizContent(b2BJEBM2001RequestV1Biz);
            B2BJEBM2001ResponseV1.PptmBody pptmBodyResponse = bocomVipCommonService.resetUrl(b2BJEBM2001RequestV1);

            pptmBodyResponse.getNotyQue().forEach(notyQue -> {
                if ("1".equals(notyQue.getNotyPushObj())) {
                    bocomBasicInfo.setQrCode(notyQue.getMerchNotyBase64Stream());
                    bocomBasicInfo.setQrCodeEffectTime(new Date());
//                    replaceBase64(vipAccountBasicInfo);
                }
            });
        }

        lambdaUpdate().eq(BocomBasicInfo::getId, bocomBasicInfo.getId())
                .set(BocomBasicInfo::getQrCode, bocomBasicInfo.getQrCode())
                .set(BocomBasicInfo::getQrCodeEffectTime, new Date())
                .update();

    }

}
