package com.sunxung.factoring.service.bocom.vipaccount;

import com.sunxung.factoring.entity.BaseSearch;
import com.sunxung.factoring.entity.GridPage;
import com.sunxung.factoring.entity.bocom.request.B2BJEBM2001RequestV1;
import com.sunxung.factoring.entity.bocom.request.MshpRgsnBookStateNoticeRequestV1;
import com.sunxung.factoring.entity.bocom.response.B2BJEBM2001ResponseV1;
import com.sunxung.factoring.entity.bocom.response.MshpRgsnBookStateNoticeResponseV1;
import com.sunxung.factoring.entity.bocom.vipaccount.*;
import com.baomidou.mybatisplus.extension.service.IService;
import com.sunxung.factoring.entity.bocom.vipaccount.Search.BocomTransRecordsSearch;
import com.sunxung.factoring.entity.bocom.vipaccount.Search.VipAccountSearch;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.util.List;

/**
 * <p>
 * 会员账户-基础信息 服务类
 * </p>
 *
 * @author wangyafan
 * @since 2024-07-29
 */
public interface IBocomVipAccountBasicInfoService extends IService<BocomVipAccountBasicInfo> {

    /**
     * 新增/修改
     *
     * @param bocomBasicInfoId
     */
    BocomVipAccountBasicInfo doAdd(Long bocomBasicInfoId);

    /**
     * 修改会员登记簿
     *
     * @param basicInfo
     */
    void doUpdate(BocomVipAccountBasicInfo basicInfo);

    /**
     * 详情
     *
     * @param id
     * @return
     */
    BocomVipAccountBasicInfo getDetail(Long id);

    /**
     * 分页
     *
     * @return
     */
    GridPage<BocomVipAccountBasicInfo> findBySearch(VipAccountSearch search);

    /**
     * 批量刷新登记簿状态
     */
    void refreshBatchBocomVipAccount();

    /**
     * 修改绑定实体卡信息
     *
     * @param bindAccountInfo
     */
    void updateBindAccount(BocomVipBindAccountInfo bindAccountInfo);

    /**
     * 批量刷新绑定实体卡状态
     */
    void refreshBatchBindAccountStatus();

    /**
     * 获取绑定的实体卡账户信息
     *
     * @param id
     * @return
     */
    BocomVipAccountBasicInfo getBindAccountInfoDetails(Long id);

    /**
     * 单个刷新实体卡状态
     *
     * @param bindAccountId
     */
    void refreshBindAccountStatus(Long bindAccountId);

    /**
     * 刷新单个登记簿状态
     */
    void refreshBocomVipAccount(Long id);

    /**
     * 获取当前登记簿下核验状态为正常的绑定银行卡信息
     *
     * @param id
     * @return
     */
    List<BocomVipBindAccountInfo> findAbnormalBindAccount(Long id);

    /**
     * 根据登记簿编号获取核验状态为非正常的绑定银行卡信息
     *
     * @param vipAccountNumber
     * @return
     */
    BocomVipAccountBasicInfo findAbnormalBindAccountByAccountNumber(String vipAccountNumber);

    /**
     * 重设入金激活金额
     *
     * @param bindId
     */
    void resetActvtAmt(Long bindId);

    /**
     * 提现
     *
     * @param reflectRecord
     */
    void withdrawalAccounts(BocomVipAccountReflectRecord reflectRecord);

    /**
     * 转账
     */
    void transferAccounts(BocomVipAccountBasicInfo vipAccountBasicInfo);

    /**
     * 维护会员登记簿
     *
     * @param basicInfo
     * @return
     */
    BocomVipAccountBasicInfo autoMaintenanceVipRequest(BocomVipAccountBasicInfo basicInfo);

    /**
     * 查询会员登记簿
     *
     * @param basicInfo
     * @return
     */
    BocomVipAccountBasicInfo autoQueryVipRequest(BocomVipAccountBasicInfo basicInfo);

    /**
     * 查询静默户信息
     *
     * @param silentAccountInfo
     * @return
     */
    BocomVipSilentAccountInfo autoQuerySilentAccount(BocomVipSilentAccountInfo silentAccountInfo);

    /**
     * 会员登记簿绑定账户维护
     *
     * @param bindAccountInfo
     * @return
     */
    BocomVipBindAccountInfo maintenanceVipBindAccount(BocomVipBindAccountInfo bindAccountInfo);

    /**
     * 查询会员登记簿绑定账户信息
     *
     * @param bindAccountInfo
     * @return
     */
    BocomVipBindAccountInfo queryVipBindAccount(BocomVipBindAccountInfo bindAccountInfo);

    /**
     * 重置授权二维码
     *
     * @param id
     */
    BocomVipAccountBasicInfo resetUrl(Long id);

    /**
     * 重置授权二维码
     *
     * @param basicInfo
     * @return
     */
    BocomVipAccountBasicInfo resetUrlAuthorized(BocomVipAccountBasicInfo basicInfo);

    /**
     * 获取提现手续费
     *
     * @param isBocom
     * @return
     */
    BocomReflectExchangeRate findReflectExchangeRate(Integer isBocom);

    /**
     * 通知会员登记薄接口
     *
     * @param request
     * @return
     */
    String notice(String request);

    /**
     * 下载交易通知书
     *
     * @param id
     */
    void downloadNoticeFile(Long id, HttpServletResponse response);

    /**
     * 综合明细单查询
     *
     * @param search
     */
    void downloadTradeDetailFile(BocomTransRecordsSearch search, HttpServletResponse response);

    /**
     * 从交行拉取上个月的综合明细
     *
     * @param id
     */
    void pullTradeDetailFile(Long id);

    /**
     * 批量从交行拉取上个月的综合明细
     */
    void updateBatchTradeDetailFile();

    /**
     * 提现手续费试算
     *
     * @param reflectRecord
     * @return
     */
    BigDecimal getHandlingFee(BocomVipAccountReflectRecord reflectRecord);

    /**
     * 交易记录/账单流水条件查询
     *
     * @param search
     * @return
     */
    GridPage<BocomTransRecords> transRecordsFindBySearch(BocomTransRecordsSearch search);

    /**
     * 批量更新登记簿付款/退款/提款与订单关联登记簿交易结果
     */
    void updateBatchTranserResult();

    /**
     * 通过平台流水号更新登记簿付款/退款/提款与订单关联登记簿交易结果
     *
     * @param id
     */
    void refreshTranserResultByPlfmSerNo(Long id);

    /**
     * 批量解冻会员登记簿
     */
    void batchRgsnBookThaw();

    /**
     * 单个解冻会员登记簿
     * @param id
     */
    void rgsnBookThaw(Long id);

    /**
     * 批量划扣
     */
    void batchRgsnBookBuckling();

    /**
     * 单个划扣
     * @param id
     */
    void rgsnBookBuckling(Long id);

    /**
     * 交易记录全流程处理
     * @param id
     */
    void transRecordHandleAll(Long id);

    /**
     * 划转到长银
     * @param id
     */
    void transferInkasso(Long id);

    /**
     * 批量划转到长银
     */
    void batchTransferInkasso();

}
