package com.sunxung.factoring.service.bocom.vipaccount.impl;

import cn.hutool.core.date.DateTime;
import cn.hutool.json.JSONUtil;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.sunxung.factoring.component.constance.BocomApiConstant;
import com.sunxung.factoring.component.exception.BusinessException;
import com.sunxung.factoring.component.exception.ValidatorException;
import com.sunxung.factoring.component.util.*;
import com.sunxung.factoring.dict.impl.BocomTransRecordsFundSourceDic;
import com.sunxung.factoring.dict.impl.BocomVipAccountStatusDic;
import com.sunxung.factoring.dict.impl.FileModuleDict;
import com.sunxung.factoring.entity.GridPage;
import com.sunxung.factoring.entity.bocom.log.BocomRequestLog;
import com.sunxung.factoring.entity.bocom.register.BocomAuthorizedAgent;
import com.sunxung.factoring.entity.bocom.register.BocomBasicInfo;
import com.sunxung.factoring.entity.bocom.register.BocomLegalPersonInfo;
import com.sunxung.factoring.entity.bocom.register.BocomShareholderActualController;
import com.sunxung.factoring.entity.bocom.request.*;
import com.sunxung.factoring.entity.bocom.response.*;
import com.sunxung.factoring.entity.bocom.vipaccount.*;
import com.sunxung.factoring.entity.bocom.vipaccount.Search.BocomTransRecordsSearch;
import com.sunxung.factoring.entity.bocom.vipaccount.Search.VipAccountSearch;
import com.sunxung.factoring.entity.sys.Dictionary;
import com.sunxung.factoring.entity.sys.FileStorage;
import com.sunxung.factoring.entity.sys.Permission;
import com.sunxung.factoring.mapper.bocom.vipaccount.BocomTransRecordsMapper;
import com.sunxung.factoring.mapper.bocom.vipaccount.BocomVipAccountBasicInfoMapper;
import com.sunxung.factoring.service.bocom.api.IBocomApiService;
import com.sunxung.factoring.service.bocom.log.IBocomRequestLogService;
import com.sunxung.factoring.service.bocom.register.IBocomAuthorizedAgentService;
import com.sunxung.factoring.service.bocom.register.IBocomBasicInfoService;
import com.sunxung.factoring.service.bocom.register.IBocomLegalPersonInfoService;
import com.sunxung.factoring.service.bocom.register.IBocomShareholderActualControllerService;
import com.sunxung.factoring.service.bocom.vipaccount.*;
import com.sunxung.factoring.service.sys.*;
import com.sunxung.factoring.service.sys.dto.AttachmentDto;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.servlet.http.HttpServletResponse;
import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.concurrent.CompletableFuture;

/**
 * <p>
 * 会员账户-基础信息 服务实现类
 * </p>
 *
 * @author wangyafan
 * @since 2024-07-29
 */
@Service
public class BocomVipAccountBasicInfoServiceImpl extends ServiceImpl<BocomVipAccountBasicInfoMapper, BocomVipAccountBasicInfo> implements IBocomVipAccountBasicInfoService {

    private static final Logger logger = LoggerFactory.getLogger(BocomVipAccountBasicInfoServiceImpl.class);

    @Autowired
    private IBocomVipSilentAccoutInfoService bocomVipSilentAccountInfoService;
    @Autowired
    private IBocomVipBindAccountInfoService bocomVipBindAccountInfoService;
    @Autowired
    private IBocomBasicInfoService bocomBasicInfoService;
    @Autowired
    private IBocomAuthorizedAgentService bocomAuthorizedAgentService;
    @Autowired
    private IBocomVipAccountReflectRecordService bocomVipAccountReflectRecordService;
    @Autowired
    private IBocomVipTransferAccountsRecordService bocomVipTransferAccountsRecordService;
    @Autowired
    private BocomVipCommonService bocomVipCommonService;
    @Autowired
    private SerialNumberGenerator serialNumberGenerator;
    @Autowired
    private IBocomVipLimitInfoService bocomVipLimitInfoService;
    @Autowired
    private IBocomReflectExchangeRateService bocomReflectExchangeRateService;
    @Autowired
    private PermissionService permissionService;
    @Autowired
    private IBocomLegalPersonInfoService bocomLegalPersonInfoService;
    @Autowired
    private IBocomShareholderActualControllerService bocomShareholderActualControllerService;
    @Autowired
    private IBocomApiService bocomApiService;
    @Autowired
    private IBocomRequestLogService bocomRequestLogService;
    @Autowired
    private DictionaryService dictionaryService;
    @Autowired
    private FileStorageService fileStorageService;
    @Autowired
    private ISysAttachmentRefService attachmentRefService;
    @Autowired
    private IBocomTransRecordsService bocomTransRecordsService;
    @Autowired
    private BocomTransRecordsMapper bocomTransRecordsMapper;
    @Autowired
    private IBocomVipAccountComprehensiveDetailFileRelService bocomVipAccountComprehensiveDetailFileRelService;
    @Autowired
    private IBocomVipAccountNoticeInfoService bocomVipAccountNoticeInfoService;

    @Override
    public BocomVipAccountBasicInfo doAdd(Long bocomBasicInfoId) {
        if (bocomBasicInfoId == null) {
            throw new BusinessException(CodeUtil.FAIL, "开户id不能为空！");
        }
        BocomBasicInfo basicInfo = bocomBasicInfoService.get(bocomBasicInfoId);
        if (basicInfo == null) {
            throw new BusinessException(CodeUtil.FAIL, "未查询到客户信息！");
        }
        BocomVipAccountBasicInfo vipAccountBasicInfo = new BocomVipAccountBasicInfo();
        vipAccountBasicInfo.setBocomBasicInfoId(basicInfo.getId());
        vipAccountBasicInfo.setAccountName(basicInfo.getCustomerName());
        vipAccountBasicInfo.setAccountAlias(basicInfo.getCustomerName());
        vipAccountBasicInfo.setSource("贸理通");
        vipAccountBasicInfo.setCurrency("CNY");
        //开通会员登记簿
        autoMaintenanceVipRequest(vipAccountBasicInfo);
        //查询会员登记簿信息
        BocomVipAccountBasicInfo bocomVipAccountBasicInfo = autoQueryVipRequest(vipAccountBasicInfo);
        if (bocomVipAccountBasicInfo.getAccountStatus() != null && bocomVipAccountBasicInfo.getAccountStatus() == 1) {
            bocomVipAccountBasicInfo.setOpenTime(new Date());
        }
        if (bocomVipAccountBasicInfo.getAccountStatus() != null && bocomVipAccountBasicInfo.getAccountStatus() == 3) {
            bocomVipAccountBasicInfo.setExpiringDate(new Date());
        }
        save(bocomVipAccountBasicInfo);
        if (CollectionUtil.isNotEmpty(bocomVipAccountBasicInfo.getNoticeInfoList())) {
            bocomVipAccountBasicInfo.getNoticeInfoList().forEach(n -> {
                n.setBocomVipAccountBasicInfoId(bocomVipAccountBasicInfo.getId());
                bocomVipAccountNoticeInfoService.save(n);
            });
        }

        //数据入库
        if (bocomVipAccountBasicInfo != null) {

            if (bocomVipAccountBasicInfo.getBocomVipLimitInfo() != null) {
                bocomVipAccountBasicInfo.getBocomVipLimitInfo().setBocomVipAccountBasicInfoId(bocomVipAccountBasicInfo.getId());
                bocomVipLimitInfoService.save(bocomVipAccountBasicInfo.getBocomVipLimitInfo());
            }

            autoAuthenticator(bocomVipAccountBasicInfo);
        }

        return bocomVipAccountBasicInfo;

    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void doUpdate(BocomVipAccountBasicInfo basicInfo) {

        if (basicInfo.getId() == null) {
            throw new BusinessException(CodeUtil.FAIL, "会员登记簿id不能为空！");
        }
        BocomVipAccountBasicInfo oldBasicInfo = getById(basicInfo.getId());
        basicInfo.setAccountNumber(oldBasicInfo.getAccountNumber());
        basicInfo.setBocomBasicInfoId(oldBasicInfo.getBocomBasicInfoId());
        if (oldBasicInfo != null) {
            if (basicInfo.getDeleteFlag() != null && basicInfo.getDeleteFlag() == 1) {
                basicInfo.setAccountName(oldBasicInfo.getAccountName());
                oldBasicInfo.setDeleteFlag(1);
                autoMaintenanceVipRequest(oldBasicInfo);
                removeById(oldBasicInfo);
                //删除账户额度限制/其它状态
                bocomVipLimitInfoService.remove(new QueryWrapper<BocomVipLimitInfo>()
                        .eq("bocom_vip_account_basic_info_id", oldBasicInfo.getId()));
                //删除静默户
                bocomVipSilentAccountInfoService.remove(new QueryWrapper<BocomVipSilentAccountInfo>()
                        .eq("bocom_vip_account_basic_info_id", oldBasicInfo.getId()));
                //删除绑定银行卡账户信息
                bocomVipBindAccountInfoService.remove(new QueryWrapper<BocomVipBindAccountInfo>()
                        .eq("bocom_vip_account_basic_info_id", oldBasicInfo.getId()));

            } else {

                if (CollectionUtil.isNotEmpty(basicInfo.getSilentAccountInfoList())) {
                    List<BocomVipSilentAccountInfo> newSilentAccountInfoList = basicInfo.getSilentAccountInfoList();
                    newSilentAccountInfoList.forEach(newSilentAccountInfo -> {
                        ArrayList<BocomVipSilentAccountInfo> silentAccountInfos = new ArrayList<>();
                        silentAccountInfos.add(newSilentAccountInfo);
                        oldBasicInfo.setSilentAccountInfoList(silentAccountInfos);
                        autoMaintenanceVipRequest(oldBasicInfo);
                        //静默户入库
                        newSilentAccountInfo.setBocomVipAccountBasicInfoId(oldBasicInfo.getId());
                        bocomVipSilentAccountInfoService.save(newSilentAccountInfo);
                    });
                }

                if (CollectionUtil.isNotEmpty(basicInfo.getDeleteSilentIds())) {
                    //删除静默户
                    for (Long deleteSilentId : basicInfo.getDeleteSilentIds()) {
                        BocomVipSilentAccountInfo silentAccountInfo = bocomVipSilentAccountInfoService.getById(deleteSilentId);
                        if (silentAccountInfo == null) {
                            throw new BusinessException(CodeUtil.FAIL, "未查询到静默户！");
                        }
                        if (silentAccountInfo.getBalance().compareTo(BigDecimal.ZERO) == 1) {
                            throw new BusinessException(CodeUtil.FAIL, "静默户余额大于0，不能删除！");
                        }
                        List<Long> ids = new ArrayList<>();
                        ids.add(deleteSilentId);
                        oldBasicInfo.setDeleteSilentIds(ids);
                        autoMaintenanceVipRequest(oldBasicInfo);
                        bocomVipSilentAccountInfoService.removeById(deleteSilentId);
                    }

                }
            }

        }

    }

    @Override
    public BocomVipAccountBasicInfo getDetail(Long id) {

        BocomVipAccountBasicInfo basicInfo = getById(id);
        if (basicInfo != null) {
            BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(basicInfo.getBocomBasicInfoId());
            //客户信息
            basicInfo.setCustomerName(bocomBasicInfo.getCustomerName());
            basicInfo.setCustomerName(bocomBasicInfo.getCustomerName());
            basicInfo.setCustomerNumber(bocomBasicInfo.getCustomerNumber());
            basicInfo.setCustomerSource(bocomBasicInfo.getCustomerSource());
            basicInfo.setCustomerType(bocomBasicInfo.getCustomerType());
            //渠道
            if (StringUtil.isNotEmpty(basicInfo.getChannel())) {
                Dictionary channelDic = dictionaryService.getByCode(basicInfo.getChannel());
                basicInfo.setChannel(channelDic.getName());
            }
            List<BocomVipSilentAccountInfo> silentAccountInfos = bocomVipSilentAccountInfoService.lambdaQuery()
                    .eq(BocomVipSilentAccountInfo::getBocomVipAccountBasicInfoId, id)
                    .list();
            if (CollectionUtil.isNotEmpty(silentAccountInfos)) {
                silentAccountInfos.forEach(silentAccountInfo -> {
                    silentAccountInfo.setAccountName(basicInfo.getAccountName());
                });
                basicInfo.setSilentAccountInfoList(silentAccountInfos);
            }

            //绑定银行卡信息
            List<BocomVipBindAccountInfo> bindAccountInfoList = bocomVipBindAccountInfoService.lambdaQuery()
                    .eq(BocomVipBindAccountInfo::getBocomVipAccountBasicInfoId, id)
                    .list();
            if (CollectionUtil.isNotEmpty(bindAccountInfoList)) {
                basicInfo.setBindAccountInfoList(bindAccountInfoList);
            }

            //账户额度限制/其它状态
            BocomVipLimitInfo vipLimitInfo = bocomVipLimitInfoService.lambdaQuery().eq(BocomVipLimitInfo::getBocomVipAccountBasicInfoId, id).one();
            basicInfo.setBocomVipLimitInfo(vipLimitInfo);
        }
        return basicInfo;
    }

    @Override
    public GridPage<BocomVipAccountBasicInfo> findBySearch(VipAccountSearch search) {

        Long currentUserId = ThreadLocalUtil.getUserId();
        List<Long> pers = permissionService.getPermissionIdByUserId(currentUserId);
        Permission per = null;
        if (search.getListType() != null && search.getListType() == 0) {
            per = permissionService.getByEname(ConstantConversionUtil.VIEW_ALL_BOCOM_VIP);

        } else if (search.getListType() != null && search.getListType() == 1) {
            per = permissionService.getByEname(ConstantConversionUtil.VIEW_ALL_BOCOM_VIP_FUND);
        }
        if (per == null) {
            throw new ValidatorException(CodeUtil.FAIL, "数据可见-查看全员权限不能为空");
        }

        if (!pers.contains(per.getId())
                && !ThreadLocalUtil.getUser().getLoginName().equals(ConstantConversionUtil.ADMINISTORIES)) {
            search.setUserLoginName(ThreadLocalUtil.getUser().getLoginName());
        }

        Page<BocomVipAccountBasicInfo> page = PageHelper.startPage(search.getPage(), search.getRows());
        List<BocomVipAccountBasicInfo> vipAccountBasicInfoList = baseMapper.findBySearch(search);

        if (CollectionUtil.isNotEmpty(vipAccountBasicInfoList)) {
            vipAccountBasicInfoList.forEach(vipAccountBasic -> {

                autoAuthenticator(vipAccountBasic);


                //填充真实状态
                Dictionary customerStatusRealDic = dictionaryService.getByCode(vipAccountBasic.getAccountStatusReal());
                if (customerStatusRealDic != null) {
                    vipAccountBasic.setAccountStatusReal(customerStatusRealDic.getName());
                }

                //标识是否需要重新创建会员登记簿
                Date afterFiveDaysDate = DateUtil.addDays(vipAccountBasic.getGmtModified(), 5);
                if (new Date().before(afterFiveDaysDate)) {
                    vipAccountBasic.setIsRebuild(0);
                } else {
                    vipAccountBasic.setIsRebuild(1);
                }
                //静默户数量
                Integer count = bocomVipSilentAccountInfoService.lambdaQuery()
                        .eq(BocomVipSilentAccountInfo::getBocomVipAccountBasicInfoId, vipAccountBasic.getId())
                        .count();
                vipAccountBasic.setSilentAccountNum(count);

                //最新一个绑定账户
                BocomVipBindAccountInfo bindAccountInfo = bocomVipBindAccountInfoService.lambdaQuery()
                        .eq(BocomVipBindAccountInfo::getBocomVipAccountBasicInfoId, vipAccountBasic.getId())
                        .ne(BocomVipBindAccountInfo::getBindAccSts, 2)
                        .orderByDesc(BocomVipBindAccountInfo::getGmtCreate)
                        .last("limit 1")
                        .one();
                if (bindAccountInfo != null) {
                    List<BocomVipBindAccountInfo> bindAccountInfos = new ArrayList<>();
                    bindAccountInfos.add(bindAccountInfo);
                    vipAccountBasic.setBindAccountInfoList(bindAccountInfos);
                }

            });

        }

        return new GridPage<>(search.getRows(), search.getPage(), page.getTotal(), vipAccountBasicInfoList);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void refreshBatchBocomVipAccount() {

        //更新账户状态不为失效的登记簿信息
        List<BocomVipAccountBasicInfo> vipAccountBasicInfos = lambdaQuery()
                .ne(BocomVipAccountBasicInfo::getAccountStatus, 3)
                .list();

        if (CollectionUtil.isNotEmpty(vipAccountBasicInfos)) {

            vipAccountBasicInfos.forEach(oldVip -> {
                refreshBocomVipAccount(oldVip.getId());
            });

        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateBindAccount(BocomVipBindAccountInfo bindAccountInfo) {

        if (bindAccountInfo != null) {
            if (bindAccountInfo.getId() == null) {
                bindAccountInfo.setOprTp("0");
                if (bindAccountInfo.getHasBankOfCommunications() != null && bindAccountInfo.getHasBankOfCommunications() == 0) {
                    bindAccountInfo.setBankName("交通银行");
                }
                bindAccountInfo.setBindAcctTp(0);


                BocomVipBindAccountInfo newBindAccountInfo = maintenanceVipBindAccount(bindAccountInfo);
                //如果返回的实体卡状态是  入金激活待确认
                if (2 == newBindAccountInfo.getBindSts()) {
                    bindAccountInfo.setMoneyConfirmStartTime(new Date());
                }
                bocomVipBindAccountInfoService.save(newBindAccountInfo);
            } else {
                bindAccountInfo.setOprTp("1");
                maintenanceVipBindAccount(bindAccountInfo);
                bocomVipBindAccountInfoService.removeById(bindAccountInfo.getId());
            }
        }

    }

    @Override
    public void refreshBatchBindAccountStatus() {

        //客户状态为生效
        List<BocomBasicInfo> basicInfos = bocomBasicInfoService.findSuccessCustomer();
        if (CollectionUtil.isNotEmpty(basicInfos)) {
            basicInfos.forEach(basic -> {
                List<BocomVipAccountBasicInfo> vipAccountBasicInfoList = lambdaQuery()
                        .eq(BocomVipAccountBasicInfo::getBocomBasicInfoId, basic.getId())
                        .list();
                if (CollectionUtil.isNotEmpty(vipAccountBasicInfoList)) {

                    vipAccountBasicInfoList.forEach(vip -> {
                        List<BocomVipBindAccountInfo> bindAccountInfoList = bocomVipBindAccountInfoService.lambdaQuery()
                                .eq(BocomVipBindAccountInfo::getBocomVipAccountBasicInfoId, vip.getId())
                                .ne(BocomVipBindAccountInfo::getBindSts, 1)
                                .list();
                        if (CollectionUtil.isNotEmpty(bindAccountInfoList)) {

                            bindAccountInfoList.forEach(oldBindAccount -> {

                                refreshBindAccountStatus(oldBindAccount.getId());

                            });

                        }
                    });
                }
            });
        }

    }

    @Override
    public BocomVipAccountBasicInfo getBindAccountInfoDetails(Long id) {

        BocomVipAccountBasicInfo vipAccountBasicInfo = getById(id);
        if (vipAccountBasicInfo != null) {
            BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
            vipAccountBasicInfo.setCustomerName(bocomBasicInfo.getCustomerName());
            List<BocomVipBindAccountInfo> bindAccountList = bocomVipBindAccountInfoService.lambdaQuery()
                    .eq(BocomVipBindAccountInfo::getBocomVipAccountBasicInfoId, id)
                    .list();
            if (CollectionUtil.isNotEmpty(bindAccountList)) {
                vipAccountBasicInfo.setBindAccountInfoList(bindAccountList);
            }
        }

        return vipAccountBasicInfo;
    }

    @Override
    public void refreshBindAccountStatus(Long bindAccountId) {

        BocomVipBindAccountInfo oldBindAccount = bocomVipBindAccountInfoService.getById(bindAccountId);
        if (oldBindAccount != null) {
            BocomVipBindAccountInfo newBindAccountInfo = queryVipBindAccount(oldBindAccount);
            //如果返回的实体卡状态变为入金激活待确认
            if (oldBindAccount.getBindSts() != null && oldBindAccount.getBindSts() != 2 && newBindAccountInfo.getBindSts() == 2) {
                newBindAccountInfo.setMoneyConfirmStartTime(new Date());
            }

            bocomVipBindAccountInfoService.updateById(newBindAccountInfo);

        }
    }

    @Override
    public void refreshBocomVipAccount(Long id) {

        BocomVipAccountBasicInfo vipAccountBasicInfo = getById(id);
        if (vipAccountBasicInfo != null) {
            //筛选客户状态为生效（核验成功）状态
            BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
            if ("bocomCustomerStatus_success".equals(bocomBasicInfo.getCustomerStatus())) {
                BocomVipAccountBasicInfo newVipAccountInfo = autoQueryVipRequest(vipAccountBasicInfo);
                BocomVipAccountBasicInfo oldVipAccountBasicInfo = getById(id);

                //新旧对比 如果之前状态不是客户授权中 现在是客户授权中 则重置二维码及二维码的生效时间
                if (0 == newVipAccountInfo.getAuthorizationStatus() && !newVipAccountInfo.getAuthorizationStatus().equals(oldVipAccountBasicInfo.getAuthorizationStatus())) {
                    resetUrl(newVipAccountInfo.getId());
                }
                if (1 == newVipAccountInfo.getAccountStatus() && !newVipAccountInfo.getAccountStatus().equals(oldVipAccountBasicInfo.getAccountStatus())) {
                    newVipAccountInfo.setOpenTime(new Date());
                }

                if (3 == newVipAccountInfo.getAccountStatus() && !newVipAccountInfo.getAccountStatus().equals(oldVipAccountBasicInfo.getAccountStatus())) {
                    newVipAccountInfo.setExpiringDate(new Date());

                }

                if (newVipAccountInfo.getBocomVipLimitInfo() != null) {
                    BocomVipLimitInfo bocomVipLimitInfo = newVipAccountInfo.getBocomVipLimitInfo();
                    BocomVipLimitInfo oldLimitInfo = bocomVipLimitInfoService.lambdaQuery()
                            .eq(BocomVipLimitInfo::getBocomVipAccountBasicInfoId, newVipAccountInfo.getId())
                            .one();
                    bocomVipLimitInfo.setBocomVipAccountBasicInfoId(newVipAccountInfo.getId());
                    if (oldLimitInfo != null) {
                        bocomVipLimitInfo.setId(oldLimitInfo.getId());
                        bocomVipLimitInfoService.updateById(bocomVipLimitInfo);
                    } else {
                        bocomVipLimitInfoService.save(bocomVipLimitInfo);
                    }

                }
                if (CollectionUtil.isNotEmpty(newVipAccountInfo.getBindAccountInfoList())) {
                    BocomVipBindAccountInfo bindAccountInfo = newVipAccountInfo.getBindAccountInfoList().get(0);
                    BocomVipBindAccountInfo oldBindAccount = bocomVipBindAccountInfoService.lambdaQuery()
                            .eq(BocomVipBindAccountInfo::getBocomVipAccountBasicInfoId, newVipAccountInfo.getId())
                            .one();
                    if (oldBindAccount != null) {
                        if (oldBindAccount.getBindSts() != null && oldBindAccount.getBindSts() != 2 && bindAccountInfo.getBindSts() != null && bindAccountInfo.getBindSts() == 2) {
                            oldBindAccount.setMoneyConfirmStartTime(new Date());
                            oldBindAccount.setActvtAmt(bindAccountInfo.getActvtAmt());
                        }
                        if (oldBindAccount.getBindSts() != null && oldBindAccount.getBindSts() != 1 && bindAccountInfo.getBindSts() != null && bindAccountInfo.getBindSts() == 1) {
                            oldBindAccount.setMoneyConfirmTime(new Date());
                        }

                        oldBindAccount.setBindAccSts(bindAccountInfo.getBindAccSts());
                        oldBindAccount.setBindSts(bindAccountInfo.getBindSts());
                        oldBindAccount.setManagerApproverSts(bindAccountInfo.getManagerApproverSts());
                        bocomVipBindAccountInfoService.updateById(oldBindAccount);
                    } else {
                        bocomVipBindAccountInfoService.save(bindAccountInfo);
                    }


                }
                updateById(vipAccountBasicInfo);
            }
        }

    }

    @Override
    public List<BocomVipBindAccountInfo> findAbnormalBindAccount(Long id) {

        List<BocomVipBindAccountInfo> list = bocomVipBindAccountInfoService.lambdaQuery()
                .eq(BocomVipBindAccountInfo::getBocomVipAccountBasicInfoId, id)
                .eq(BocomVipBindAccountInfo::getBindAccSts, 1)
                .list();
        if (CollectionUtil.isEmpty(list)) {
            list = new ArrayList<>();
        }
        return list;
    }

    @Override
    public BocomVipAccountBasicInfo findAbnormalBindAccountByAccountNumber(String vipAccountNumber) {
        BocomVipAccountBasicInfo vipAccountBasicInfo = lambdaQuery()
                .eq(BocomVipAccountBasicInfo::getAccountNumber, vipAccountNumber)
                .eq(BocomVipAccountBasicInfo::getAccountStatus, 1)
                .one();
        if (vipAccountBasicInfo == null) {
            throw new BusinessException(CodeUtil.FAIL, "未查到，请检查转出长银账号是否正确！");
        }

        return vipAccountBasicInfo;
    }

    @Override
    public void resetActvtAmt(Long bindId) {

        BocomVipBindAccountInfo bindAccountInfo = bocomVipBindAccountInfoService.getById(bindId);
        if (bindAccountInfo != null) {
            bindAccountInfo.setOprTp("2");
            BocomVipBindAccountInfo newBindAccount = maintenanceVipBindAccount(bindAccountInfo);

            if (2 == newBindAccount.getBindSts()) {
                newBindAccount.setMoneyConfirmStartTime(new Date());
            }

            bocomVipBindAccountInfoService.lambdaUpdate()
                    .eq(BocomVipBindAccountInfo::getId, newBindAccount.getId())
                    .set(BocomVipBindAccountInfo::getActvtAmt, newBindAccount.getActvtAmt())
                    .set(BocomVipBindAccountInfo::getMoneyConfirmStartTime, newBindAccount.getMoneyConfirmStartTime())
                    .update();
        }


    }

    @Override
    public void withdrawalAccounts(BocomVipAccountReflectRecord reflectRecord) {
        if (reflectRecord.getBocomVipAccountBasicInfoId() != null) {
            BocomVipAccountBasicInfo vipAccountBasicInfo = getById(reflectRecord.getBocomVipAccountBasicInfoId());
            if (reflectRecord.getWithdrawalAmt().compareTo(vipAccountBasicInfo.getAvailableBalance()) > 0) {
                throw new BusinessException(CodeUtil.FAIL, "账户余额不足！");
            }
        }
        BocomVipAccountReflectRecord newRecord = withdrawal(reflectRecord);
        bocomVipAccountReflectRecordService.save(newRecord);
        CompletableFuture.runAsync(() -> refreshBocomVipAccount(newRecord.getBocomVipAccountBasicInfoId()));

    }

    @Override
    public void transferAccounts(BocomVipAccountBasicInfo vipAccountBasicInfo) {

        if (vipAccountBasicInfo == null || CollectionUtil.isEmpty(vipAccountBasicInfo.getBocomVipTransferAccountsRecordList())) {
            throw new BusinessException(CodeUtil.FAIL, "转账信息不能为空！");
        }

        BigDecimal sumAmount = vipAccountBasicInfo.getBocomVipTransferAccountsRecordList().stream().map(vip -> vip.getTxnAmt())
                .reduce(BigDecimal.ZERO, BigDecimal::add);
        if (sumAmount.compareTo(vipAccountBasicInfo.getAvailableBalance()) > 0) {
            throw new BusinessException(CodeUtil.FAIL, "账户余额不足！");
        }

        BocomVipAccountBasicInfo basicInfo = transfer(vipAccountBasicInfo);
        if (basicInfo != null && CollectionUtil.isNotEmpty(basicInfo.getBocomVipTransferAccountsRecordList())) {
            for (BocomVipTransferAccountsRecord record : basicInfo.getBocomVipTransferAccountsRecordList()) {
                bocomVipTransferAccountsRecordService.save(record);
                refreshBocomVipAccount(record.getCollectionBocomVipAccountBasicInfoId());
            }
            //刷新付款的会员登记薄信息
            CompletableFuture.runAsync(() -> refreshBocomVipAccount(basicInfo.getBocomVipTransferAccountsRecordList().get(0).getPayBocomVipAccountBasicInfoId()));
        }


    }

    @Override
    public BocomVipBindAccountInfo queryVipBindAccount(BocomVipBindAccountInfo bindAccountInfo) {

        BocomVipAccountBasicInfo vipAccountBasicInfo = getById(bindAccountInfo.getBocomVipAccountBasicInfoId());
        if (vipAccountBasicInfo == null) {
            throw new BusinessException(CodeUtil.FAIL, "会员登记簿信息不能为空！");
        }
        BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
        if (bocomBasicInfo == null) {
            throw new BusinessException(CodeUtil.FAIL, "客户信息不能为空！");
        }

        B2BJEBM1206RequestV1 requestV1 = new B2BJEBM1206RequestV1();
        B2BJEBM1206RequestV1.B2BJEBM1206RequestV1Biz b2BJEBM1206RequestV1Biz = new B2BJEBM1206RequestV1.B2BJEBM1206RequestV1Biz();
        B2BJEBM1206RequestV1.B2BJEBM1206RequestV1Biz.PptmBody pptmBodyRequest = new B2BJEBM1206RequestV1.B2BJEBM1206RequestV1Biz.PptmBody();

        pptmBodyRequest.setMshpCustId(bocomBasicInfo.getCustomerNumber());
        pptmBodyRequest.setRgsnBookId(vipAccountBasicInfo.getAccountNumber());
        pptmBodyRequest.setBindAcctNo(bindAccountInfo.getBindAcctNo());
        pptmBodyRequest.setBindAcctBankNme(bindAccountInfo.getBindAcctBankNme());
        pptmBodyRequest.setBindAcctBankNo(bindAccountInfo.getBindAcctBankNo());
        pptmBodyRequest.setBindAcctBankNme(bindAccountInfo.getBindAcctBankNme());
        b2BJEBM1206RequestV1Biz.setPptmBody(pptmBodyRequest);
        requestV1.setBizContent(b2BJEBM1206RequestV1Biz);
        B2BJEBM1206ResponseV1.PptmBody pptmBody = bocomVipCommonService.queryVipBindAccount(requestV1);
        if (pptmBody != null) {
            if (CollectionUtil.isNotEmpty(pptmBody.getBindAcctList())) {
                B2BJEBM1206ResponseV1.PptmBody.BindAcct bindAcct = pptmBody.getBindAcctList().get(0);
                if (StringUtil.isNotEmpty(bindAcct.getBindSts())) {
                    bindAccountInfo.setBindSts(Integer.valueOf(bindAcct.getBindSts()));
                }
                if (StringUtil.isNotEmpty(bindAcct.getActvtAmt())) {
                    bindAccountInfo.setActvtAmt(new BigDecimal(bindAcct.getActvtAmt()));
                }
                if (StringUtil.isNotEmpty(bindAcct.getBindAccSts())) {
                    bindAccountInfo.setBindAccSts(Integer.valueOf(bindAcct.getBindAccSts()));
                }

                if (StringUtil.isNotEmpty(bindAcct.getManagerApproverSts())) {
                    bindAccountInfo.setManagerApproverSts(Integer.valueOf(bindAcct.getManagerApproverSts()));
                }

            }
        }
        return bindAccountInfo;
    }

    @Override
    public BocomVipAccountBasicInfo resetUrl(Long id) {
        BocomVipAccountBasicInfo basicInfo = getById(id);
        if (basicInfo != null) {
            resetUrlAuthorized(basicInfo);
        }
        BocomVipAccountBasicInfo newVipBasic = getById(id);
        autoAuthenticator(newVipBasic);
        return newVipBasic;
    }


    @Override
    public BocomVipAccountBasicInfo autoMaintenanceVipRequest(BocomVipAccountBasicInfo basicInfo) {

        BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(basicInfo.getBocomBasicInfoId());
        if (bocomBasicInfo == null) {
            throw new BusinessException(CodeUtil.FAIL, "客户信息不能为空！");
        }

        B2BJEBM1201RequestV2 b2BJEBM1201RequestV2 = new B2BJEBM1201RequestV2();
        B2BJEBM1201RequestV2.B2BJEBM1201RequestV2Biz b2BJEBM1201RequestV2Biz = new B2BJEBM1201RequestV2.B2BJEBM1201RequestV2Biz();

        B2BJEBM1201RequestV2.B2BJEBM1201RequestV2Biz.PptmBody pptmBodyRequest = new B2BJEBM1201RequestV2.B2BJEBM1201RequestV2Biz.PptmBody();
        if (basicInfo.getDeleteFlag() != null && basicInfo.getDeleteFlag() == 1) {
            //删除登记簿
            pptmBodyRequest.setOprTp("20");
            pptmBodyRequest.setRgsnBookPurp("13");
            //登记簿编号
            pptmBodyRequest.setRgsnBookId(basicInfo.getAccountNumber());
        } else {
            if (basicInfo.getId() == null) {
                //新增登记簿
                pptmBodyRequest.setOprTp("00");
                pptmBodyRequest.setRgsnBookPurp("13");
            } else if (basicInfo.getId() != null && CollectionUtil.isNotEmpty(basicInfo.getDeleteSilentIds())) {
                //删除静默户
                pptmBodyRequest.setOprTp("20");
                pptmBodyRequest.setRgsnBookPurp("11");
                List<Long> deleteSilentIds = basicInfo.getDeleteSilentIds();
                BocomVipSilentAccountInfo silentAccountInfo = bocomVipSilentAccountInfoService.getById(deleteSilentIds.get(0));
                //删除静默户时 此字段传送静默户编号
                if (silentAccountInfo != null) {
                    pptmBodyRequest.setRgsnBookId(silentAccountInfo.getSilentAccountNumber());
                }

            } else if (basicInfo.getId() != null && CollectionUtil.isNotEmpty(basicInfo.getSilentAccountInfoList())) {
                //新增静默户
                pptmBodyRequest.setOprTp("00");
                pptmBodyRequest.setRgsnBookPurp("11");
                //登记簿编号
                pptmBodyRequest.setRgsnBookId(basicInfo.getAccountNumber());
            } else {
                //修改账户名
                pptmBodyRequest.setOprTp("10");
                pptmBodyRequest.setRgsnBookPurp("13");
                pptmBodyRequest.setRgsnBookId(basicInfo.getAccountNumber());
            }
        }

        // 填充开户信息(会员客户号)
        pptmBodyRequest.setMshpCustId(bocomBasicInfo.getCustomerNumber());
        //平台流水号
        pptmBodyRequest.setPlfmSerNo(serialNumberGenerator.generatePlfmSerNo());
        //会员登记簿名称
        pptmBodyRequest.setRgsnBookAcctNme(basicInfo.getAccountName());
        //上级会员登记簿名称
        pptmBodyRequest.setSprirAcctNme(basicInfo.getAccountName());
        //上级会员登记簿编号
        pptmBodyRequest.setSprirAcctNo(basicInfo.getAccountNumber());
        //会员登记簿别名
        pptmBodyRequest.setBookAls(basicInfo.getAccountAlias());
        //静默户付款方信息
        List<B2BJEBM1201RequestV2.B2BJEBM1201RequestV2Biz.PptmBody.SilentAcctPayrNme> silentAcctPayrNmeList = new ArrayList<>();
        if (CollectionUtil.isNotEmpty(basicInfo.getSilentAccountInfoList())) {
            basicInfo.getSilentAccountInfoList().forEach(silent -> {
                B2BJEBM1201RequestV2.B2BJEBM1201RequestV2Biz.PptmBody.SilentAcctPayrNme silentAcctPayrNme = new B2BJEBM1201RequestV2.B2BJEBM1201RequestV2Biz.PptmBody.SilentAcctPayrNme();
                silentAcctPayrNme.setSilentAcctPayrNme(silent.getPayerAccountName());
                silentAcctPayrNmeList.add(silentAcctPayrNme);
            });
        }
        if (CollectionUtil.isNotEmpty(basicInfo.getDeleteSilentIds())) {
            basicInfo.getDeleteSilentIds().forEach(silentId -> {
                BocomVipSilentAccountInfo silent = bocomVipSilentAccountInfoService.getById(silentId);
                B2BJEBM1201RequestV2.B2BJEBM1201RequestV2Biz.PptmBody.SilentAcctPayrNme silentAcctPayrNme = new B2BJEBM1201RequestV2.B2BJEBM1201RequestV2Biz.PptmBody.SilentAcctPayrNme();
                silentAcctPayrNme.setSilentAcctPayrNme(silent.getPayerAccountName());
                silentAcctPayrNmeList.add(silentAcctPayrNme);
            });
        }
        pptmBodyRequest.setSilentAcctPayrNmeList(silentAcctPayrNmeList);
        b2BJEBM1201RequestV2Biz.setPptmBody(pptmBodyRequest);
        b2BJEBM1201RequestV2.setBizContent(b2BJEBM1201RequestV2Biz);
        B2BJEBM1201ResponseV2.PptmBody pptmBody = bocomVipCommonService.maintenanceVip(b2BJEBM1201RequestV2);
        if (pptmBody != null) {
            if ("00".equals(pptmBodyRequest.getOprTp()) && "13".equals(pptmBodyRequest.getRgsnBookPurp())) {
                basicInfo.setAccountNumber(pptmBody.getRgsnBookId());
            }
            List<BocomVipAccountNoticeInfo> noticeInfoList = new ArrayList<>();
            if (CollectionUtil.isNotEmpty(pptmBody.getNotyQue())) {
                pptmBody.getNotyQue().forEach(notyQue -> {
                    BocomVipAccountNoticeInfo noticeInfo = new BocomVipAccountNoticeInfo();
                    noticeInfo.setQrCode(notyQue.getMerchNotyBase64Stream());
                    noticeInfo.setQrCodeEffectTime(new Date());
                    noticeInfo.setNoticeObject(notyQue.getNotyPushObj());
                    noticeInfoList.add(noticeInfo);

                    if (notyQue.getNotyPushObj().equals("1")) {
                        //需要法人授权 新建会员登记簿时 法人授权状态置为 0
                        basicInfo.setLegalAuthorizationStatus(0);
                    }
                    if (notyQue.getNotyPushObj().equals("2")) {
                        //需要授权代理人授权 新建会员登记簿时 授权代理人授权状态置为 0
                        basicInfo.setAuthorizationStatus(0);
                    }
                });

                basicInfo.setPlfmSerNo(pptmBodyRequest.getPlfmSerNo());

            }
            basicInfo.setNoticeInfoList(noticeInfoList);
        }
        basicInfo.setChannel("bocom");
        basicInfo.setSource("贸理通");
        //回填静默户编号
        if ("00".equals(pptmBodyRequest.getOprTp()) && "11".equals(pptmBodyRequest.getRgsnBookPurp())) {
            List<BocomVipSilentAccountInfo> silentAccountInfoList = basicInfo.getSilentAccountInfoList();
            //此处 一次只允许新增一个静默户 一个静默户只允许有一个买方名称
            for (BocomVipSilentAccountInfo bocomVipSilentAccountInfo : silentAccountInfoList) {
                bocomVipSilentAccountInfo.setSilentAccountNumber(pptmBody.getRgsnBookId());
            }


        }
        return basicInfo;
    }

    @Override
    public BocomVipAccountBasicInfo autoQueryVipRequest(BocomVipAccountBasicInfo basicInfo) {

        BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(basicInfo.getBocomBasicInfoId());
        if (bocomBasicInfo == null) {
            throw new BusinessException(CodeUtil.FAIL, "客户信息不能为空！");
        }

        B2BJEBM1202RequestV2 requestV2 = new B2BJEBM1202RequestV2();
        B2BJEBM1202RequestV2.B2BJEBM1202RequestV2Biz b2BJEBM1201RequestV2Biz = new B2BJEBM1202RequestV2.B2BJEBM1202RequestV2Biz();

        B2BJEBM1202RequestV2.B2BJEBM1202RequestV2Biz.PptmBody pptmBodyRequest = new B2BJEBM1202RequestV2.B2BJEBM1202RequestV2Biz.PptmBody();
        // 填充开户信息(会员客户号)
        pptmBodyRequest.setMshpCustId(bocomBasicInfo.getCustomerNumber());
        //平台流水号
        pptmBodyRequest.setPlfmSerNo(serialNumberGenerator.generatePlfmSerNo());
        //登记簿编号
        pptmBodyRequest.setRgsnBookId(basicInfo.getAccountNumber());

        b2BJEBM1201RequestV2Biz.setPptmBody(pptmBodyRequest);
        requestV2.setBizContent(b2BJEBM1201RequestV2Biz);
        B2BJEBM1202ResponseV2.PptmBody pptmBody = bocomVipCommonService.queryVipAccount(requestV2);
        //
        if (pptmBody != null && StringUtil.isNotEmpty(pptmBody.getRgsnBookId())) {
            //授权代理人授权状态
            if (pptmBody.getComChdBokAuthFlg() != null) {
                basicInfo.setAuthorizationStatus(Integer.valueOf(pptmBody.getComChdBokAuthFlg()));
            }
            //账户状态
            if (pptmBody.getChdBokSts() != null) {
                basicInfo.setAccountStatus(Integer.valueOf(pptmBody.getChdBokSts()));
            }

            basicInfo.setAccountBalance(new BigDecimal(pptmBody.getBal()));
            basicInfo.setAvailableBalance(new BigDecimal(pptmBody.getAvaBal()));
            basicInfo.setFreezeAmount(basicInfo.getAccountBalance().subtract(basicInfo.getAvailableBalance()));
            basicInfo.setAccountNumber(pptmBody.getRgsnBookId());

            BocomVipLimitInfo limitInfo = new BocomVipLimitInfo();
            if (StringUtil.isNotEmpty(pptmBody.getInnLmtAmt())) {
                limitInfo.setInnLmtAmt(new BigDecimal(pptmBody.getInnLmtAmt()));
            }
            if (StringUtil.isNotEmpty(pptmBody.getOutLmtAmt())) {
                limitInfo.setOutLmtAmt(new BigDecimal(pptmBody.getOutLmtAmt()));
            }
            if (CollectionUtil.isNotEmpty(pptmBody.getLmtInfoList())) {
                pptmBody.getLmtInfoList().forEach(limitResponse -> {
                    if ("1".equals(limitResponse.getLmtPed())) {
                        //单笔限额
                        if (StringUtil.isNotEmpty(limitResponse.getLmtAmt())) {
                            limitInfo.setSglQta(new BigDecimal(limitResponse.getLmtAmt()));
                        }
                    } else if ("2".equals(limitResponse.getLmtPed())) {
                        //每日累计限额
                        if (StringUtil.isNotEmpty(limitResponse.getLmtAmt())) {
                            limitInfo.setDayCumQta(new BigDecimal(limitResponse.getLmtAmt()));
                        }
                    } else if ("3".equals(limitResponse.getLmtPed())) {
                        //每周累计限额
                        if (StringUtil.isNotEmpty(limitResponse.getLmtAmt())) {
                            limitInfo.setWekCumQta(new BigDecimal(limitResponse.getLmtAmt()));
                        }
                    } else if ("4".equals(limitResponse.getLmtPed())) {
                        //每月累计限额
                        if (StringUtil.isNotEmpty(limitResponse.getLmtAmt())) {
                            limitInfo.setMthCumQta(new BigDecimal(limitResponse.getLmtAmt()));
                        }
                    } else if ("5".equals(limitResponse.getLmtPed())) {
                        //每旬累计限额
                        if (StringUtil.isNotEmpty(limitResponse.getLmtAmt())) {
                            limitInfo.setQtrCumQta(new BigDecimal(limitResponse.getLmtAmt()));
                        }
                    } else if ("6".equals(limitResponse.getLmtPed())) {
                        //每年累计限额
                        if (StringUtil.isNotEmpty(limitResponse.getLmtAmt())) {
                            limitInfo.setYrCumQta(new BigDecimal(limitResponse.getLmtAmt()));
                        }
                    }
                });
                //收支管控标志
                if (StringUtil.isNotEmpty(pptmBody.getIaeCtlFlg())) {
                    limitInfo.setIaeCtlFlg(Integer.valueOf(pptmBody.getIaeCtlFlg()));
                }
                //收入管控
                if (StringUtil.isNotEmpty(pptmBody.getIncFlg())) {
                    limitInfo.setIncFlg(Integer.valueOf(pptmBody.getIncFlg()));
                }
                //支出管控
                if (StringUtil.isNotEmpty(pptmBody.getPayFlg())) {
                    limitInfo.setPayFlg(Integer.valueOf(pptmBody.getPayFlg()));
                }
                //取现标志
                if (StringUtil.isNotEmpty(pptmBody.getDwcFlg())) {
                    limitInfo.setDwcFlg(Integer.valueOf(pptmBody.getDwcFlg()));
                }
                //归属机构
                if (StringUtil.isNotEmpty(pptmBody.getOwnBr())) {
                    limitInfo.setBelongInstitution(pptmBody.getOwnBr());
                }
                //激活状态
                if (StringUtil.isNotEmpty(pptmBody.getAtvSts())) {
                    limitInfo.setAtvSts(Integer.valueOf(pptmBody.getAtvSts()));
                }
                basicInfo.setBocomVipLimitInfo(limitInfo);
            }

            if (CollectionUtil.isNotEmpty(pptmBody.getBindAcctList())) {
                ArrayList<BocomVipBindAccountInfo> bindAccountInfos = new ArrayList<>();
                pptmBody.getBindAcctList().forEach(bindAcct -> {
                    BocomVipBindAccountInfo bindAccountInfo = new BocomVipBindAccountInfo();
                    bindAccountInfo.setBocomVipAccountBasicInfoId(basicInfo.getId());
                    bindAccountInfo.setBindAcctNo(bindAcct.getBindAcctNo());
                    bindAccountInfo.setBindAcctNoAcctNme(bindAcct.getBindAcctNoAcctNme());
                    bindAccountInfo.setHasBankOfCommunications(Integer.valueOf(bindAcct.getOurBankOthrBankFlg()));
                    bindAccountInfo.setBindAcctBankNo(bindAcct.getBindAcctBankNo());
                    bindAccountInfo.setBindAcctBankNme(bindAcct.getBindAcctBankNme());
                    if (StringUtil.isNotEmpty(bindAcct.getBindSts())) {
                        bindAccountInfo.setBindSts(Integer.valueOf(bindAcct.getBindSts()));
                    }
                    if (StringUtil.isNotEmpty(bindAcct.getBindAccSts())) {
                        bindAccountInfo.setBindAccSts(Integer.valueOf(bindAcct.getBindAccSts()));
                    }
                    if (StringUtil.isNotEmpty(bindAcct.getManagerApproverSts())) {
                        bindAccountInfo.setManagerApproverSts(Integer.valueOf(bindAcct.getManagerApproverSts()));
                    }
                    if (StringUtil.isNotEmpty(bindAcct.getActvtAmt())) {
                        bindAccountInfo.setActvtAmt(new BigDecimal(bindAcct.getActvtAmt()));
                    }
                    bindAccountInfos.add(bindAccountInfo);
                });
                basicInfo.setBindAccountInfoList(bindAccountInfos);
            }

            if (1 == limitInfo.getIncFlg() && 1 == limitInfo.getPayFlg()) {
                //无收入管控 && 无支出管控 时 更新
                //1.登记簿状态 为 可收可付；2.授权代理人状态为 授权成功 ，法人授权状态为授权成功；
                basicInfo.setChdbokSts(1);
                basicInfo.setAuthorizationStatus(4);
                basicInfo.setLegalAuthorizationStatus(4);
            } else {
                //刷新账户信息
                bocomBasicInfoService.research(basicInfo.getBocomBasicInfoId());
                //根据账户信息中的 用户授权状态 重置 法人授权状态
                BocomBasicInfo newBocomBasicInfo = bocomBasicInfoService.get(basicInfo.getBocomBasicInfoId());
                if (newBocomBasicInfo != null) {
                    if (newBocomBasicInfo.getUserAtuhSts() != null) {
                        if (newBocomBasicInfo != null) {
                            if (StringUtil.isNotEmpty(newBocomBasicInfo.getUserAtuhSts())) {
                                if ("待用户授权".equals(newBocomBasicInfo.getUserAtuhSts())) {
                                    basicInfo.setLegalAuthorizationStatus(0);
                                }
                                if ("银行审核中".equals(newBocomBasicInfo.getUserAtuhSts())) {
                                    basicInfo.setLegalAuthorizationStatus(1);
                                }
                                if ("授权失败(用户拒绝)".equals(newBocomBasicInfo.getUserAtuhSts())) {
                                    basicInfo.setLegalAuthorizationStatus(2);
                                }
                                if ("授权失败(银行拒绝)".equals(newBocomBasicInfo.getUserAtuhSts())) {
                                    basicInfo.setLegalAuthorizationStatus(3);
                                }
                                if ("授权成功".equals(newBocomBasicInfo.getUserAtuhSts())) {
                                    basicInfo.setLegalAuthorizationStatus(4);
                                }
                            }

                        }

                    }
                }
            }
            autoAccountRealStatus(basicInfo);
        }

        return basicInfo;
    }

    @Override
    public BocomVipSilentAccountInfo autoQuerySilentAccount(BocomVipSilentAccountInfo silentAccountInfo) {

//        if (silentAccountInfo != null){
        B2BJEBM1202RequestV2 requestV2 = new B2BJEBM1202RequestV2();
        B2BJEBM1202RequestV2.B2BJEBM1202RequestV2Biz b2BJEBM1201RequestV2Biz = new B2BJEBM1202RequestV2.B2BJEBM1202RequestV2Biz();

        B2BJEBM1202RequestV2.B2BJEBM1202RequestV2Biz.PptmBody pptmBodyRequest = new B2BJEBM1202RequestV2.B2BJEBM1202RequestV2Biz.PptmBody();
        // 填充开户信息(会员客户号)
        pptmBodyRequest.setMshpCustId("PT15689000003632");
        //平台流水号
        pptmBodyRequest.setPlfmSerNo(serialNumberGenerator.generatePlfmSerNo());
        //静默户编号
        pptmBodyRequest.setRgsnBookId("31006662901300890601719311831");

        b2BJEBM1201RequestV2Biz.setPptmBody(pptmBodyRequest);
        requestV2.setBizContent(b2BJEBM1201RequestV2Biz);
        B2BJEBM1202ResponseV2.PptmBody pptmBody = bocomVipCommonService.queryVipAccount(requestV2);
//        }
        return null;
    }

    @Override
    public BocomVipBindAccountInfo maintenanceVipBindAccount(BocomVipBindAccountInfo bindAccountInfo) {

        BocomVipAccountBasicInfo vipAccountBasicInfo = getById(bindAccountInfo.getBocomVipAccountBasicInfoId());
        if (vipAccountBasicInfo == null) {
            throw new BusinessException(CodeUtil.FAIL, "会员登记簿信息不能为空！");
        }
        BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
        if (bocomBasicInfo == null) {
            throw new BusinessException(CodeUtil.FAIL, "客户信息不能为空！");
        }

        B2BJEBM1203RequestV1 requestV1 = new B2BJEBM1203RequestV1();
        B2BJEBM1203RequestV1.B2BJEBM1203RequestV1Biz b2BJEBM1203RequestV1Biz = new B2BJEBM1203RequestV1.B2BJEBM1203RequestV1Biz();
        B2BJEBM1203RequestV1.B2BJEBM1203RequestV1Biz.PptmBody pptmBodyRequest = new B2BJEBM1203RequestV1.B2BJEBM1203RequestV1Biz.PptmBody();

        pptmBodyRequest.setOprTp(bindAccountInfo.getOprTp());
        pptmBodyRequest.setPlfmSerNo(serialNumberGenerator.generatePlfmSerNo());
        pptmBodyRequest.setMshpCustId(bocomBasicInfo.getCustomerNumber());
        pptmBodyRequest.setRgsnBookId(vipAccountBasicInfo.getAccountNumber());
        pptmBodyRequest.setBindAcctTp(bindAccountInfo.getBindAcctTp().toString());
        pptmBodyRequest.setOurBankOthrBankFlg(bindAccountInfo.getHasBankOfCommunications().toString());
//        pptmBodyRequest.setOurBankOthrBankFlg("1");
        pptmBodyRequest.setBindAcctNo(bindAccountInfo.getBindAcctNo());
        pptmBodyRequest.setBindAcctNoAcctNme(bindAccountInfo.getBindAcctNoAcctNme());
        pptmBodyRequest.setBindAcctBankNo(bindAccountInfo.getBindAcctBankNo());
        pptmBodyRequest.setBindAcctBankNme(bindAccountInfo.getBankName());
        b2BJEBM1203RequestV1Biz.setPptmBody(pptmBodyRequest);
        requestV1.setBizContent(b2BJEBM1203RequestV1Biz);
        B2BJEBM1203ResponseV1.PptmBody pptmBody = bocomVipCommonService.maintenanceVipBindAccount(requestV1);
        if (pptmBody != null) {
            if (StringUtil.isNotEmpty(pptmBody.getBindSts())) {
                bindAccountInfo.setBindSts(Integer.valueOf(pptmBody.getBindSts()));
            }
            if (StringUtil.isNotEmpty(pptmBody.getBindAccSts())) {
                bindAccountInfo.setBindAccSts(Integer.valueOf(pptmBody.getBindAccSts()));
            }
            if (StringUtil.isNotEmpty(pptmBody.getManagerApproverSts())) {
                bindAccountInfo.setManagerApproverSts(Integer.valueOf(pptmBody.getManagerApproverSts()));
            }
            if (StringUtil.isNotEmpty(pptmBody.getActvtAmt())) {
                bindAccountInfo.setActvtAmt(new BigDecimal(pptmBody.getActvtAmt()));
                bindAccountInfo.setMoneyConfirmStartTime(new Date());
            }
        }


        return bindAccountInfo;

    }

    /**
     * 转账（同时转给多个账户）
     *
     * @param vipAccountBasicInfo
     * @return
     */
    private BocomVipAccountBasicInfo transfer(BocomVipAccountBasicInfo vipAccountBasicInfo) {

        if (vipAccountBasicInfo != null) {

            if (vipAccountBasicInfo == null) {
                throw new BusinessException(CodeUtil.FAIL, "转出账户信息不能为空！");
            }
            BocomBasicInfo basicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
            if (basicInfo == null) {
                throw new BusinessException(CodeUtil.FAIL, "转出账户信息不能为空！");
            }

            B2BJEBP1001RequestV2 b2BJEBP1001RequestV2 = new B2BJEBP1001RequestV2();
            B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz b2BJEBP1001RequestV2Biz = new B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz();
            B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody pptmBody = new B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody();
            pptmBody.setPlfmSerNo(serialNumberGenerator.generatePlfmSerNo());
            //交易日期
            pptmBody.setTxnDt(DateUtil.getDayStringFormatYMD(new Date()));
            //交易发送时间
            SimpleDateFormat dateFormat = new SimpleDateFormat("HHmmss");
            String HHmmss = dateFormat.format(new Date());
            pptmBody.setTxnSendTme(HHmmss);
            pptmBody.setBsnOrdrTp("2");
            //平台业务订单号
            pptmBody.setPlfmBsnOrdrNo(serialNumberGenerator.nextValue(BocomApiConstant.PLATFORM_BUSINESS_ORDER_CODE));
            //平台支付订单号
            pptmBody.setPlfmPayOrdrNo(pptmBody.getPlfmBsnOrdrNo());
            //交易类型 默认直接付款
            pptmBody.setTxnTp("03");
            pptmBody.setPayrCustId(basicInfo.getCustomerNumber());
            pptmBody.setPayrRgsnBookId(vipAccountBasicInfo.getAccountNumber());
            List<B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody.TxnInf> txnInfList = new ArrayList<>();
            if (CollectionUtil.isNotEmpty(vipAccountBasicInfo.getBocomVipTransferAccountsRecordList())) {

                for (BocomVipTransferAccountsRecord transferAccountsRecord : vipAccountBasicInfo.getBocomVipTransferAccountsRecordList()) {
                    BocomVipAccountBasicInfo collection = getById(transferAccountsRecord.getCollectionBocomVipAccountBasicInfoId());
                    if (basicInfo == null) {
                        throw new BusinessException(CodeUtil.FAIL, "转入账户信息不能为空！");
                    }
                    BocomBasicInfo collectionBasicInfo = bocomBasicInfoService.get(collection.getBocomBasicInfoId());
                    if (collectionBasicInfo == null) {
                        throw new BusinessException(CodeUtil.FAIL, "转入账户信息不能为空！");
                    }

                    B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody.TxnInf txnInf = new B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody.TxnInf();


                    //交易信息
                    txnInf.setPlfmOrdrNo(serialNumberGenerator.nextValue(BocomApiConstant.PLATFORM_ORDER_CODE));
                    txnInf.setRcvrRgsnBookId(collection.getAccountNumber());
                    txnInf.setRcvrCustId(collectionBasicInfo.getCustomerNumber());
                    txnInf.setTxnCcy(vipAccountBasicInfo.getCurrency());
                    if (transferAccountsRecord.getTxnAmt() != null) {
                        BigDecimal txnAmt = transferAccountsRecord.getTxnAmt().setScale(2, BigDecimal.ROUND_HALF_UP);
                        transferAccountsRecord.setTxnAmt(txnAmt);
                        txnInf.setOrdrAmt(txnAmt.toString());
                        txnInf.setTxnAmt(transferAccountsRecord.getTxnAmt().toString());
                    }
                    txnInfList.add(txnInf);
                }
                pptmBody.setTxnInf(txnInfList);
                b2BJEBP1001RequestV2Biz.setPptmBody(pptmBody);
                b2BJEBP1001RequestV2.setBizContent(b2BJEBP1001RequestV2Biz);

                vipAccountBasicInfo.setPlfmSerNo(pptmBody.getPlfmSerNo());
                B2BJEBP1001ResponseV2.PptmBody pptmBodyResponse = bocomVipCommonService.transferAccounts(b2BJEBP1001RequestV2);
                for (BocomVipTransferAccountsRecord record : vipAccountBasicInfo.getBocomVipTransferAccountsRecordList()) {
                    record.setTransNo(pptmBodyResponse.getInrSerNo());
                    record.setTxnSts(pptmBodyResponse.getTxnSts());


                    //内部转出
                    BocomTransRecords transRecords = new BocomTransRecords();
//                    transRecords.setRelPlfmPayOrdrNo(record.getRelPlfmPayOrdrNo());
                    transRecords.setPlfmSerNo(pptmBody.getPlfmSerNo());
                    transRecords.setPlfmPayOrdrNo(pptmBody.getPlfmPayOrdrNo());
                    transRecords.setAccountNumber(vipAccountBasicInfo.getAccountNumber());
                    transRecords.setAccountName(vipAccountBasicInfo.getAccountName());
                    transRecords.setIncomeExpenditureType(1);
                    transRecords.setBusinessType(3);
                    transRecords.setCurrency("CNY");
                    transRecords.setTxnAmt(record.getTxnAmt());
                    BocomVipAccountBasicInfo counterpartyAccount = getById(record.getCollectionBocomVipAccountBasicInfoId());
                    if (counterpartyAccount != null) {
                        transRecords.setCounterpartyAccountNumber(counterpartyAccount.getAccountNumber());
                        transRecords.setCounterpartyAccountName(counterpartyAccount.getAccountName());
                    }
                    transRecords.setPostscript(record.getRemark());
                    if ("00".equals(pptmBodyResponse.getTxnSts())) {
                        //成功
                        transRecords.setTxnStatus("bocomTransState_success");
                        transRecords.setTxnCompleteDate(new Date());
                    }
                    if ("01".equals(pptmBodyResponse.getTxnSts())) {
                        //失败
                        transRecords.setTxnStatus("bocomTransState_failure");
                        transRecords.setFailReason(pptmBodyResponse.getErrInf());
                        transRecords.setTxnCompleteDate(new Date());
                    }
                    if ("02".equals(pptmBodyResponse.getTxnSts())) {
                        //待查
                        transRecords.setTxnStatus("bocomTransState_pending");
                    }
                    if ("03".equals(pptmBodyResponse.getTxnSts())) {
                        //待授权
                        transRecords.setTxnStatus("bocomTransState_authorize");
                    }
                    if ("04".equals(pptmBodyResponse.getTxnSts())) {
                        //授权拒绝
                        transRecords.setTxnStatus("bocomTransState_authorize_refuse");
                    }
                    if ("05".equals(pptmBodyResponse.getTxnSts())) {
                        //延时中
                        transRecords.setTxnStatus("bocomTransState_delay");
                    }
                    transRecords.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.VIPACCOUNT_TO_VIPACCOUNT.getCode());
                    transRecords.setAccountType(1);
                    bocomTransRecordsService.save(transRecords);
                    //内部转入
                    BocomTransRecords collectionTransRecords = new BocomTransRecords();
                    BeanUtils.copyProperties(transRecords, collectionTransRecords, "id");
                    collectionTransRecords.setIncomeExpenditureType(0);
                    collectionTransRecords.setBusinessType(2);
                    collectionTransRecords.setCounterpartyAccountName(transRecords.getAccountName());
                    collectionTransRecords.setCounterpartyAccountNumber(transRecords.getAccountNumber());
                    collectionTransRecords.setAccountNumber(transRecords.getCounterpartyAccountNumber());
                    collectionTransRecords.setAccountName(transRecords.getCounterpartyAccountName());
                    bocomTransRecordsService.save(collectionTransRecords);

                }
            }

        }


        return vipAccountBasicInfo;
    }

    /**
     * 提现
     *
     * @param reflectRecord
     * @return
     */
    private BocomVipAccountReflectRecord withdrawal(BocomVipAccountReflectRecord reflectRecord) {

        if (reflectRecord != null) {

            BocomVipAccountBasicInfo vipAccountBasicInfo = getById(reflectRecord.getBocomVipAccountBasicInfoId());

            if (vipAccountBasicInfo == null) {
                throw new BusinessException(CodeUtil.FAIL, "转出账户信息不能为空！");
            }

            BocomBasicInfo basicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
            if (basicInfo == null) {
                throw new BusinessException(CodeUtil.FAIL, "转出账户信息不能为空！");
            }

            BocomVipBindAccountInfo bindAccountInfo = bocomVipBindAccountInfoService.getById(reflectRecord.getBocomVipBindAccountInfoId());
            if (bindAccountInfo == null) {
                throw new BusinessException(CodeUtil.FAIL, "收款方账户信息不能为空！");
            }

            B2BJEBP1007RequestV2 b2BJEBP1007RequestV2 = new B2BJEBP1007RequestV2();
            B2BJEBP1007RequestV2.B2BJEBP1007RequestV2Biz b2BJEBP1007RequestV2Biz = new B2BJEBP1007RequestV2.B2BJEBP1007RequestV2Biz();
            B2BJEBP1007RequestV2.B2BJEBP1007RequestV2Biz.PptmBody pptmBody = new B2BJEBP1007RequestV2.B2BJEBP1007RequestV2Biz.PptmBody();

            pptmBody.setPlfmSerNo(serialNumberGenerator.generatePlfmSerNo());
            //交易日期
            pptmBody.setTxnDt(DateUtil.getDayStringFormatYMD(new Date()));
            //交易发送时间
            SimpleDateFormat dateFormat = new SimpleDateFormat("HHmmss");
            String HHmmss = dateFormat.format(new Date());
            pptmBody.setTxnSendTme(HHmmss);
            //平台业务订单号
            pptmBody.setPlfmBsnOrdrNo(serialNumberGenerator.nextValue(BocomApiConstant.PLATFORM_BUSINESS_ORDER_CODE));
            //平台支付订单号
            pptmBody.setPlfmPayOrdrNo(pptmBody.getPlfmBsnOrdrNo());
            //平台业务类型
            pptmBody.setBsnOrdrTp("4");
            //平台订单号
            pptmBody.setPlfmOrdrNo(serialNumberGenerator.generatePlfmSerNo());
            //付款方客户号
            pptmBody.setPayrCustId(basicInfo.getCustomerNumber());
            //付款方登记簿编号
            pptmBody.setPayrRgsnBookId(vipAccountBasicInfo.getAccountNumber());
            //收款方账号
            pptmBody.setRcvrAcctNo(bindAccountInfo.getBindAcctNo());
            //交易币种
            pptmBody.setTxnCcy(vipAccountBasicInfo.getCurrency());
            //订单金额
            if (reflectRecord.getWithdrawalAmt() != null) {
                BigDecimal withdrawalAmt = reflectRecord.getWithdrawalAmt().setScale(2, BigDecimal.ROUND_HALF_UP);
                reflectRecord.setWithdrawalAmt(withdrawalAmt);
                pptmBody.setOrdrAmt(withdrawalAmt.toString());
            }

            b2BJEBP1007RequestV2Biz.setPptmBody(pptmBody);
            b2BJEBP1007RequestV2.setBizContent(b2BJEBP1007RequestV2Biz);
            B2BJEBP1007ResponseV2.PptmBody pptmBodyResponse = bocomVipCommonService.withdrawal(b2BJEBP1007RequestV2);

            reflectRecord.setTransNo(pptmBodyResponse.getInrSerNo());
            reflectRecord.setTxnSts(pptmBodyResponse.getTxnSts());

            //交易记录
            BocomTransRecords transRecords = new BocomTransRecords();
            transRecords.setPlfmSerNo(pptmBody.getPlfmSerNo());
            transRecords.setPlfmPayOrdrNo(pptmBody.getPlfmPayOrdrNo());
            transRecords.setAccountName(vipAccountBasicInfo.getAccountName());
            transRecords.setAccountNumber(vipAccountBasicInfo.getAccountNumber());
            transRecords.setIncomeExpenditureType(1);
            transRecords.setBusinessType(4);
            transRecords.setCurrency("CNY");
            transRecords.setTxnAmt(reflectRecord.getWithdrawalAmt());
            transRecords.setHdlFee(reflectRecord.getPoundageAmt());
            transRecords.setCounterpartyAccountName(bindAccountInfo.getBindAcctNoAcctNme());
            transRecords.setCounterpartyAccountNumber(bindAccountInfo.getBindAcctNo());
            transRecords.setCounterpartyBankName(bindAccountInfo.getBankName());
            transRecords.setCounterpartyBankNumber(bindAccountInfo.getBindAcctBankNo());
            transRecords.setAcctgSerNo(pptmBodyResponse.getAcctgSerNo());
            transRecords.setAcctgDt(pptmBodyResponse.getAcctgDt());
            transRecords.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.VIPACCOUNT_TO_BANK_CARD.getCode());
            transRecords.setAccountType(1);
            if ("00".equals(pptmBodyResponse.getTxnSts())) {
                //成功
                transRecords.setTxnStatus("bocomTransState_success");
            }
            if ("01".equals(pptmBodyResponse.getTxnSts())) {
                //失败
                transRecords.setTxnStatus("bocomTransState_failure");
                transRecords.setFailReason(pptmBodyResponse.getErrInf());
            }
            if ("02".equals(pptmBodyResponse.getTxnSts())) {
                //待查
                transRecords.setTxnStatus("bocomTransState_pending");
            }
            if ("03".equals(pptmBodyResponse.getTxnSts())) {
                //待授权
                transRecords.setTxnStatus("bocomTransState_authorize");
            }
            if ("05".equals(pptmBodyResponse.getTxnSts())) {
                //授权拒绝
                transRecords.setTxnStatus("bocomTransState_authorize_refuse");
            }
            transRecords.setPostscript(reflectRecord.getRemark());
            if (StringUtil.isNotEmpty(pptmBodyResponse.getErrInf())) {
                transRecords.setFailReason(pptmBodyResponse.getErrInf());
            }
            if (StringUtil.isNotEmpty(pptmBodyResponse.getTxnSts()) && ("00".equals(pptmBodyResponse.getTxnSts()) || "01".equals(pptmBodyResponse.getTxnSts()))) {
                transRecords.setTxnCompleteDate(new Date());
            }
            bocomTransRecordsService.save(transRecords);


        }

        return reflectRecord;

    }


    /**
     * 重置登记簿认证二维码
     *
     * @param vipAccountBasicInfo
     * @return
     */
    @Override
    public BocomVipAccountBasicInfo resetUrlAuthorized(BocomVipAccountBasicInfo vipAccountBasicInfo) {

        //刷新会员登记簿
        refreshBocomVipAccount(vipAccountBasicInfo.getId());

        if (vipAccountBasicInfo != null) {
            BocomBasicInfo basicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
            if (basicInfo == null) {
                throw new BusinessException(CodeUtil.FAIL, "账户信息不能为空！");
            }

            B2BJEBM2001RequestV1 b2BJEBM2001RequestV1 = new B2BJEBM2001RequestV1();
            B2BJEBM2001RequestV1.B2BJEBM2001RequestV1Biz b2BJEBM2001RequestV1Biz = new B2BJEBM2001RequestV1.B2BJEBM2001RequestV1Biz();
            B2BJEBM2001RequestV1.B2BJEBM2001RequestV1Biz.PptmBody pptmBody = new B2BJEBM2001RequestV1.B2BJEBM2001RequestV1Biz.PptmBody();

            //平台流水号
            pptmBody.setPlfmSerNo(vipAccountBasicInfo.getPlfmSerNo());
            //会员客户号
            pptmBody.setMshpCustId(basicInfo.getCustomerNumber());
            //登记簿编号
            pptmBody.setRgsnBookId(vipAccountBasicInfo.getAccountNumber());
            //登记簿名称
            pptmBody.setRgsnBookAcctNme(vipAccountBasicInfo.getAccountName());
            //功能码 01--查询 02--重置 03--登记簿开立授权
            pptmBody.setFuncCode("02");


            b2BJEBM2001RequestV1Biz.setPptmBody(pptmBody);
            b2BJEBM2001RequestV1.setBizContent(b2BJEBM2001RequestV1Biz);
            B2BJEBM2001ResponseV1.PptmBody pptmBodyResponse = bocomVipCommonService.resetUrl(b2BJEBM2001RequestV1);

            List<BocomVipAccountNoticeInfo> noticeInfoList = new ArrayList<>();
            pptmBodyResponse.getNotyQue().forEach(notyQue -> {

                if (notyQue.getNotyPushObj().equals("1")) {
                    if (4 != vipAccountBasicInfo.getLegalAuthorizationStatus()) {
                        //未授权成功时，更新授权码
                        //全删全进
                        bocomVipAccountNoticeInfoService.remove(new QueryWrapper<BocomVipAccountNoticeInfo>()
                                .eq("bocom_vip_account_basic_info_id", vipAccountBasicInfo.getId())
                                .eq("notice_object", "1"));
                        if (CollectionUtil.isNotEmpty(vipAccountBasicInfo.getNoticeInfoList())) {
                            vipAccountBasicInfo.getNoticeInfoList().forEach(n -> {
                                bocomVipAccountNoticeInfoService.save(n);
                            });
                        }

                    }
                } else if (notyQue.getNotyPushObj().equals("2")) {
                    if (4 != vipAccountBasicInfo.getAuthorizationStatus()) {
                        //未授权成功时，更新授权码
                        //全删全进
                        bocomVipAccountNoticeInfoService.remove(new QueryWrapper<BocomVipAccountNoticeInfo>()
                                .eq("bocom_vip_account_basic_info_id", vipAccountBasicInfo.getId())
                                .eq("notice_object", "2"));
                        if (CollectionUtil.isNotEmpty(vipAccountBasicInfo.getNoticeInfoList())) {
                            vipAccountBasicInfo.getNoticeInfoList().forEach(n -> {
                                bocomVipAccountNoticeInfoService.save(n);
                            });
                        }

                    }
                }
            });
        }

        return vipAccountBasicInfo;

    }

    @Override
    public BocomReflectExchangeRate findReflectExchangeRate(Integer isBocom) {
        BocomReflectExchangeRate reflectExchangeRate = bocomReflectExchangeRateService.lambdaQuery()
                .eq(BocomReflectExchangeRate::getIsBocom, isBocom)
                .one();
        return reflectExchangeRate;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public String notice(String request) {


        //解密
        HashMap<String, String> requestMap = bocomApiService.decryptRequest(request);
        String encryptKey = requestMap.get("encrypt_key");
        String bizContent = requestMap.get("biz_content");
        HashMap<String, String> responseV1 = new HashMap();

        Map<String, String> map = JSONUtil.toBean(bizContent, Map.class);
        if ("22".equals(map.get("notice_type"))) {
            //会员登记簿状态变更通知
            logger.error("会员登记簿状态变更通知回调请求报文:" + JSONUtil.toJsonStr(requestMap));
            String rgsnBookId = map.get("rgsn_book_id");
            String chdbokSts = map.get("chdbok_sts");
            if (StringUtil.isNotEmpty(rgsnBookId) && StringUtil.isNotEmpty(chdbokSts)) {
                lambdaUpdate().eq(BocomVipAccountBasicInfo::getAccountNumber, rgsnBookId)
                        .set(BocomVipAccountBasicInfo::getChdbokSts, chdbokSts)
                        .update();
                responseV1.put("biz_state", "S");
                responseV1.put("rsp_code", "000000");
                responseV1.put("rsp_msg", "交易成功");
                responseV1.put("response_result", "0");
            } else {
                responseV1.put("biz_state", "F");
                responseV1.put("rsp_code", "000000");
                responseV1.put("response_result", "1");
                responseV1.put("rsp_msg", "交易失败");
            }


        }

        if ("11".equals(map.get("notice_type"))) {
            //会员登记簿动账通知
            logger.error("会员登记簿动账通知回调请求报文:" + JSONUtil.toJsonStr(requestMap));
            String notice_message = map.get("notice_message");
            String txn_type = map.get("txn_type");
            if (StringUtil.isNotEmpty(txn_type) && StringUtil.isNotEmpty(notice_message)) {
                String[] values = notice_message.split("/");
                if (values.length > 0) {
                    //会计流水号
                    String serNo = values[3];
                    //余额
                    String balance = values[5];
                    BigDecimal balanceBig = BigDecimal.ZERO;
                    if (StringUtil.isNotEmpty(balance)) {
                        balanceBig = new BigDecimal(balance);
                    }
                    //登记簿编号
                    String accountNumber = values[7];
                    //登记簿名称
                    String accountName = values[8];
                    //币种
                    String currency = values[10];
                    //此次交易金额
                    String thisAmount = values[11];
                    BigDecimal thisAmountBig = BigDecimal.ZERO;
                    if (StringUtil.isNotEmpty(thisAmount)) {
                        thisAmountBig = new BigDecimal(thisAmount);
                    }
                    //可用余额
//                    String amount = values[12];
//                    BigDecimal amountBig = null;
//                    if (StringUtil.isNotEmpty(amount)) {
//                        amountBig = new BigDecimal(amount);
//                    }
                    //支付订单号（长银传送）
                    String payNoInkasso = values[20];
                    //支付订单号（会计日+会计流水号）
                    String payNo = values[1] + serNo;
                    //对方账号
                    String counterpartyAccountNumber = values[13];
                    //对方户名
                    String counterpartyAccountName = values[14];
                    //对方地址
                    String counterpartyAddress = values[15];
                    //对方行号
                    String counterpartyBankNumber = values[16];
                    //对方行名
                    String counterpartyBankName = values[17];
                    if (StringUtil.isNotEmpty(accountNumber)) {

                        if (StringUtil.isNotEmpty(payNoInkasso)) {
                            List<BocomTransRecords> transRecordsList = bocomTransRecordsService.lambdaQuery()
                                    .eq(BocomTransRecords::getPlfmPayOrdrNo, payNoInkasso)
                                    .list();
                            if (CollectionUtil.isNotEmpty(transRecordsList)) {
                                transRecordsList.forEach(records -> {
                                    records.setAcctgDt(values[1]);
                                    records.setAcctgSerNo(serNo);
                                    bocomTransRecordsService.updateById(records);
                                });
                            }
                        } else {
                            BocomVipSilentAccountInfo silentAccountInfo = bocomVipSilentAccountInfoService.lambdaQuery()
                                    .eq(BocomVipSilentAccountInfo::getSilentAccountNumber, accountNumber)
                                    .one();
                            BocomVipAccountBasicInfo vipAccountBasicInfo = null;
                            if (silentAccountInfo == null) {
                                vipAccountBasicInfo = lambdaQuery().eq(BocomVipAccountBasicInfo::getAccountNumber, accountNumber).one();
                            }
                            if (silentAccountInfo != null || vipAccountBasicInfo != null) {
                                //静默户余额
                                if (silentAccountInfo != null) {
                                    silentAccountInfo.setBalance(balanceBig);
                                    bocomVipSilentAccountInfoService.updateById(silentAccountInfo);
                                }

                                if ("56".equals(txn_type)) {
                                    //56 （实体卡入金激活/付款方往静默户打款）
                                    BocomTransRecords transRecords = new BocomTransRecords();
                                    transRecords.setAccountName(accountName);
                                    transRecords.setAccountNumber(accountNumber);
                                    //会计流水号
                                    transRecords.setAcctgSerNo(values[3]);
                                    //会计日期
                                    transRecords.setAcctgDt(values[1]);
                                    //平台流水号
//                                transRecords.setPlfmSerNo(serNo);
                                    //支付订单号
                                    transRecords.setPlfmPayOrdrNo(payNo);
                                    //收支类型
                                    transRecords.setIncomeExpenditureType(0);
                                    //业务类型
                                    transRecords.setBusinessType(1);
                                    //币种
                                    transRecords.setCurrency(currency);
                                    //对方账号
                                    transRecords.setCounterpartyBankNumber(counterpartyBankNumber);
                                    transRecords.setCounterpartyBankName(counterpartyBankName);
                                    transRecords.setCounterpartyAccountNumber(counterpartyAccountNumber);
                                    transRecords.setCounterpartyAccountName(counterpartyAccountName);
                                    transRecords.setCounterpartyAddress(counterpartyAddress);
                                    transRecords.setTxnAmt(thisAmountBig);
                                    String completeTime = values[6];
                                    String dayStringFormatYMD = DateUtil.getDayStringFormatYMD(new Date());
                                    String completeDateStr = dayStringFormatYMD + completeTime;
                                    DateTime date = cn.hutool.core.date.DateUtil.parse(completeDateStr);
                                    transRecords.setTxnCompleteDate(date);
                                    transRecords.setPostscript(values[18]);
                                    if (silentAccountInfo != null) {
                                        //外部到静默户 新增逻辑 外部到静默户 需要前置新增三条 解冻 划扣 划转至长银账户的记录
                                        transRecords.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.OUTSIDE_TO_SILENT.getCode());
                                        transRecords.setTxnStatus("bocomTransState_success");
                                        transRecords.setAccountType(0);
                                        bocomTransRecordsService.save(transRecords);
                                        addToSilentRecords(transRecords);

                                    } else {
                                        //实体卡到登记簿 新增逻辑 需要前置新增两条 解冻 划转至长银账户的记录
                                        transRecords.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.OUTSIDE_TO_VIPACCOUNT.getCode());
                                        transRecords.setTxnStatus("bocomTransState_success");
                                        transRecords.setAccountType(1);
                                        bocomTransRecordsService.save(transRecords);
                                        addToVipAccountRecords(transRecords);
                                    }


                                } else {
                                    bocomTransRecordsService.lambdaUpdate()
                                            .eq(BocomTransRecords::getPlfmPayOrdrNo, payNoInkasso)
                                            .set(BocomTransRecords::getAcctgSerNo, values[3])
                                            .set(BocomTransRecords::getAcctgDt, values[1])
                                            .update();
                                }
                            }
                        }

                    }


                }
                responseV1.put("biz_state", "S");
                responseV1.put("rsp_code", "000000");
                responseV1.put("rsp_msg", "交易成功");
                responseV1.put("response_result", "0");

            } else {
                responseV1.put("biz_state", "F");
                responseV1.put("rsp_code", "000000");
                responseV1.put("response_result", "1");
                responseV1.put("rsp_msg", "交易失败");
            }

        }
        String responseStr = JSONUtil.toJsonStr(responseV1);
        logger.error("会员登记簿状态变更通知/动账通知回调响应报文:" + responseStr);

        //返回加密
        String response = bocomApiService.encryptResponse(responseStr, encryptKey);

        //添加日志
        BocomRequestLog requestLog = new BocomRequestLog();
        requestLog.setUrl(BocomApiConstant.MSHP_RGSN_BOOK_STATE_NOTICE_URL);
        requestLog.setRequest(JSON.toJSONString(requestMap));
        requestLog.setResponse(responseStr);
        requestLog.setSuccess(true);
        // 日志采用异步保存，否则可能因为调用方法添加事务导致异常后的回滚
        CompletableFuture.runAsync(() -> bocomRequestLogService.save(requestLog));
        return response;
    }

    @Override
    public void downloadNoticeFile(Long id, HttpServletResponse response) {

        if (id == null) {
            throw new BusinessException(CodeUtil.FAIL, "id不能为空！");
        }
        BocomTransRecords transRecords = bocomTransRecordsService.getById(id);
        if (transRecords == null) {
            throw new BusinessException(CodeUtil.FAIL, "交易记录不能为空！");
        }
        AttachmentDto attachmentDto = AttachmentDto.builder()
                .setEntityId(id)
                .setChildEnum(FileModuleDict.ChildEnum.BOCOM_TRANSACTION_RECORD_FILE)
                .build();
        List<FileStorage> files = attachmentRefService.getFiles(attachmentDto);
        if (CollectionUtil.isEmpty(files)) {
            BocomVipAccountBasicInfo payBasicInfo = null;
            if (BocomTransRecordsFundSourceDic.ChildEnum.OUTSIDE_TO_SILENT.getCode().equals(transRecords.getFundSource()) ||
                    BocomTransRecordsFundSourceDic.ChildEnum.SILENT_TO_SILENT.getCode().equals(transRecords.getFundSource()) ||
                    BocomTransRecordsFundSourceDic.ChildEnum.SILENT_TO_VIPACCOUNT.getCode().equals(transRecords.getFundSource())) {
                BocomVipSilentAccountInfo silentAccountInfo = bocomVipSilentAccountInfoService.lambdaQuery()
                        .eq(BocomVipSilentAccountInfo::getSilentAccountNumber, transRecords.getAccountNumber())
                        .one();
                if (silentAccountInfo != null) {
                    payBasicInfo = getById(silentAccountInfo.getBocomVipAccountBasicInfoId());
                }
            } else {
                payBasicInfo = lambdaQuery()
                        .eq(BocomVipAccountBasicInfo::getAccountNumber, transRecords.getAccountNumber())
                        .one();
            }
            if (payBasicInfo != null) {
                BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(payBasicInfo.getBocomBasicInfoId());
                if (bocomBasicInfo != null) {
                    ReceiptSingleTransferRequestV1 requestV1 = new ReceiptSingleTransferRequestV1();
                    ReceiptSingleTransferRequestV1.ReceiptSingleTransferRequestV1Biz requestV1Biz = new ReceiptSingleTransferRequestV1.ReceiptSingleTransferRequestV1Biz();
                    //客户号
                    requestV1Biz.setCustId(bocomBasicInfo.getCustomerNumber());
                    //会计流水号
                    requestV1Biz.setAcctgSerNo(transRecords.getAcctgSerNo());
                    //会计日期
                    requestV1Biz.setAcctgDt(transRecords.getAcctgDt());
                    //登记簿编号
                    requestV1Biz.setRgsnBookId(transRecords.getAccountNumber());
                    requestV1.setBizContent(requestV1Biz);
                    requestV1.setDownloadPath(BocomApiConstant.FILE_PATH);
                    ReceiptSingleTransferResponseV1 responseV1 = bocomVipCommonService.downloadNoticeFile(requestV1);
                    if (responseV1 != null) {
                        FileStorage fileStorage = new FileStorage(responseV1.getFileName(), BocomApiConstant.FILE_PATH + responseV1.getFileName(), FileModuleDict.ChildEnum.BOCOM_TRANSACTION_RECORD_FILE);
                        fileStorageService.saveAttachmentRefByFileStorage(fileStorage, FileModuleDict.ChildEnum.BOCOM_TRANSACTION_RECORD_FILE, transRecords.getId());
                    }
                }

            }
            files = attachmentRefService.getFiles(attachmentDto);
        }

        fileStorageService.do_UploadFile(response, files.get(0).getId());

    }

    @Override
    public void downloadTradeDetailFile(BocomTransRecordsSearch search, HttpServletResponse response) {

        if (search == null) {
            throw new BusinessException(CodeUtil.FAIL, "id不能为空！");
        }
        QueryWrapper<BocomVipAccountComprehensiveDetailFileRel> querryWrapper = new QueryWrapper<>();
        querryWrapper.eq("bocom_vip_account_basic_info_id", search.getId());
        querryWrapper.gt("date", search.getStartDate());
        querryWrapper.lt("date", search.getEndDate());
        List<BocomVipAccountComprehensiveDetailFileRel> fileRelList = bocomVipAccountComprehensiveDetailFileRelService.list(querryWrapper);
        if (CollectionUtil.isEmpty(fileRelList)) {
            throw new BusinessException(CodeUtil.FAIL, "未查询到符合条件的文件！");
        }
        fileRelList.forEach(fileRel -> {
            AttachmentDto attachmentDto = AttachmentDto.builder()
                    .setEntityId(fileRel.getId())
                    .setChildEnum(FileModuleDict.ChildEnum.BOCOM_TRADE_DETAIL_TRANSFER_FILE)
                    .build();
            List<FileStorage> files = attachmentRefService.getFiles(attachmentDto);
            fileStorageService.downloadZipFile(files, FileModuleDict.ChildEnum.BOCOM_TRADE_DETAIL_TRANSFER_FILE.getCname(), FileModuleDict.ChildEnum.BOCOM_TRADE_DETAIL_TRANSFER_FILE, response);
        });


    }

    @Override
    public void pullTradeDetailFile(Long id) {
        BocomVipAccountBasicInfo vipAccountBasicInfo = getById(id);
        if (vipAccountBasicInfo != null) {
            BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
            if (bocomBasicInfo != null) {
                TradeDetailTransferRequestV1 requestV1 = new TradeDetailTransferRequestV1();
                TradeDetailTransferRequestV1.TradeDetailTransferRequestV1Biz requestV1Biz = new TradeDetailTransferRequestV1.TradeDetailTransferRequestV1Biz();
                //客户号
                requestV1Biz.setCustId(bocomBasicInfo.getCustomerNumber());
                //登记簿名称
                requestV1Biz.setRgsnBookAcctNme(vipAccountBasicInfo.getAccountName());
                //登记簿编号
                requestV1Biz.setRgsnBookId(vipAccountBasicInfo.getAccountNumber());
                //查询起始月份,YYYYMM
                Date startDate = DateUtil.addMonths(new Date(), -1);
                SimpleDateFormat dateFormat = new SimpleDateFormat("YYYYMM");
                requestV1Biz.setEnqreBgnMth(dateFormat.format(startDate));
                //查询终止月份,YYYYMM
                requestV1Biz.setEnqreEndMth(dateFormat.format(new Date()));
                requestV1.setBizContent(requestV1Biz);

                TradeDetailTransferResponseV1 responseV1 = bocomVipCommonService.downloadTradeDetailFile(requestV1);
                if (responseV1 != null && "S".equals(responseV1.getBizState())) {
                    BocomVipAccountComprehensiveDetailFileRel fileRel = new BocomVipAccountComprehensiveDetailFileRel();
                    fileRel.setBocomVipAccountBasicInfoId(id);
                    fileRel.setDate(startDate);
                    bocomVipAccountComprehensiveDetailFileRelService.save(fileRel);
                    requestV1.setDownloadPath(BocomApiConstant.FILE_PATH);
                    //保存文件
                    if (responseV1 != null) {
                        FileStorage fileStorage = new FileStorage(responseV1.getFileName(), BocomApiConstant.FILE_PATH + responseV1.getFileName(), FileModuleDict.ChildEnum.BOCOM_TRANSACTION_RECORD_FILE);
                        fileStorageService.saveAttachmentRefByFileStorage(fileStorage, FileModuleDict.ChildEnum.BOCOM_TRADE_DETAIL_TRANSFER_FILE, fileRel.getId());
                    }
                }
            }
        }
    }

    @Override
    public void updateBatchTradeDetailFile() {

        List<BocomVipAccountBasicInfo> list = list();
        if (CollectionUtil.isNotEmpty(list)) {
            list.forEach(vipAccountBasicInfo -> {
                if (vipAccountBasicInfo != null) {
                    pullTradeDetailFile(vipAccountBasicInfo.getId());
                }
            });
        }

    }

    @Override
    public BigDecimal getHandlingFee(BocomVipAccountReflectRecord reflectRecord) {

        if (reflectRecord != null) {

            if (reflectRecord.getBocomVipAccountBasicInfoId() == null) {
                throw new BusinessException(CodeUtil.FAIL, "会员登记簿id不能为空！");
            }
            BocomVipAccountBasicInfo vipAccountBasicInfo = getById(reflectRecord.getBocomVipAccountBasicInfoId());
            BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
            if (bocomBasicInfo == null) {
                throw new BusinessException(CodeUtil.FAIL, "会员账户信息不能为空！");
            }
            BocomVipBindAccountInfo bindAccountInfo = bocomVipBindAccountInfoService.lambdaQuery().eq(BocomVipBindAccountInfo::getBocomVipAccountBasicInfoId, vipAccountBasicInfo.getId())
                    .one();
            if (bindAccountInfo == null) {
                throw new BusinessException(CodeUtil.FAIL, "绑定实体卡信息为空！");
            }
            B2BJETP1007RequestV1 requestV1 = new B2BJETP1007RequestV1();
            B2BJETP1007RequestV1.B2BJETP1007RequestV1Biz b2BJETP1007RequestV1Biz = new B2BJETP1007RequestV1.B2BJETP1007RequestV1Biz();
            B2BJETP1007RequestV1.B2BJETP1007RequestV1Biz.PptmBody pptmBody = new B2BJETP1007RequestV1.B2BJETP1007RequestV1Biz.PptmBody();
            pptmBody.setMshpCustId(bocomBasicInfo.getCustomerNumber());
            pptmBody.setPayrAcctNo(vipAccountBasicInfo.getAccountNumber());
            pptmBody.setPayrAcctNme(vipAccountBasicInfo.getAccountName());
            pptmBody.setRcvrAcctNo(bindAccountInfo.getBindAcctNo());
            pptmBody.setRcvrAcctNme(bindAccountInfo.getBindAcctNoAcctNme());
            pptmBody.setAmt(reflectRecord.getWithdrawalAmt().toString());
            pptmBody.setOurBankOthrBankFlg(bindAccountInfo.getHasBankOfCommunications().toString());
            pptmBody.setRcvrBankNo(bindAccountInfo.getBindAcctBankNo());
            pptmBody.setPayChl("1");
            b2BJETP1007RequestV1Biz.setPptmBody(pptmBody);
            requestV1.setBizContent(b2BJETP1007RequestV1Biz);
            B2BJETP1007ResponseV1.PptmBody pptmBodyResponse = bocomVipCommonService.getHandlingFee(requestV1);
            if (pptmBodyResponse != null) {
                if (StringUtil.isNotEmpty(pptmBodyResponse.getPoundageAmt())) {
                    return new BigDecimal(pptmBodyResponse.getPoundageAmt());
                }

            }
        }

        return null;
    }

    @Override
    public GridPage<BocomTransRecords> transRecordsFindBySearch(BocomTransRecordsSearch search) {

        List<BocomTransRecords> bocomTransRecords = null;
        Page<BocomVipAccountBasicInfo> page = PageHelper.startPage(search.getPage(), search.getRows());
        if (search != null && search.getBillFlow() == 1) {
            bocomTransRecords = bocomTransRecordsMapper.transRecordsFindBySearch(search);
        }
        if (search != null && search.getBillFlow() == 0 && search.getIsVipAccount() == 0) {
            bocomTransRecords = bocomTransRecordsMapper.transRecordsSilentFindBySearch(search);
        }
        if (search != null && search.getBillFlow() == 0 && search.getIsVipAccount() == 1) {
            bocomTransRecords = bocomTransRecordsMapper.transRecordsVipAccountFindBySearch(search);
        }
        if (CollectionUtil.isNotEmpty(bocomTransRecords)) {
            bocomTransRecords.forEach(records -> {
                Dictionary fundSourceDic = dictionaryService.getByCode(records.getFundSource());
                if (fundSourceDic != null) {
                    records.setFundSource(fundSourceDic.getName());
                }
            });
        }
        return new GridPage<>(search.getRows(), search.getPage(), page.getTotal(), bocomTransRecords);
    }

    @Override
    public void updateBatchTranserResult() {

        List<BocomTransRecords> transRecordsList = bocomTransRecordsService.lambdaQuery().ne(BocomTransRecords::getBusinessType, 1)
                .notIn(BocomTransRecords::getTxnStatus, "bocomTransState_success", "bocomTransState_failure")
                .list();
        if (CollectionUtil.isNotEmpty(transRecordsList)) {
            transRecordsList.forEach(transRecords -> {
                if (transRecords != null) {
                    refreshTranserResultByPlfmSerNo(transRecords.getId());
                }
            });
        }
    }

    @Override
    public void refreshTranserResultByPlfmSerNo(Long id) {

        if (id != null) {
            BocomTransRecords transRecords = bocomTransRecordsService.getById(id);
            if (transRecords != null) {
                B2BJEBP2001RequestV2 requestV2 = new B2BJEBP2001RequestV2();
                B2BJEBP2001RequestV2.B2BJEBP2001RequestV2Biz b2BJEBP2001RequestV2Biz = new B2BJEBP2001RequestV2.B2BJEBP2001RequestV2Biz();
                B2BJEBP2001RequestV2.B2BJEBP2001RequestV2Biz.PptmBody pptmBody = new B2BJEBP2001RequestV2.B2BJEBP2001RequestV2Biz.PptmBody();
                pptmBody.setQryFlg("2");
                pptmBody.setPlfmSerNo(transRecords.getPlfmSerNo());
                b2BJEBP2001RequestV2Biz.setPptmBody(pptmBody);
                requestV2.setBizContent(b2BJEBP2001RequestV2Biz);
                B2BJEBP2001ResponseV2.PptmBody pptmBodyResponse = bocomVipCommonService.getTranserResult(requestV2);
                if (pptmBodyResponse != null) {
                    if ("00".equals(pptmBodyResponse.getTxnSts())) {
                        //成功
                        transRecords.setTxnStatus("bocomTransState_success");
                        transRecords.setTxnCompleteDate(new Date());
                    }
                    if ("01".equals(pptmBodyResponse.getTxnSts())) {
                        //失败
                        transRecords.setTxnStatus("bocomTransState_failure");
                        transRecords.setFailReason(pptmBodyResponse.getErrInf());
                        transRecords.setTxnCompleteDate(new Date());
                    }
                    if ("02".equals(pptmBodyResponse.getTxnSts())) {
                        //待查
                        transRecords.setTxnStatus("bocomTransState_pending");
                    }
                    if ("03".equals(pptmBodyResponse.getTxnSts())) {
                        //待授权
                        transRecords.setTxnStatus("bocomTransState_authorize");
                    }
                    if ("04".equals(pptmBodyResponse.getTxnSts())) {
                        //授权拒绝
                        transRecords.setTxnStatus("bocomTransState_authorize_refuse");
                    }
                    if ("05".equals(pptmBodyResponse.getTxnSts())) {
                        //延时中
                        transRecords.setTxnStatus("bocomTransState_delay");
                    }
                    bocomTransRecordsService.updateById(transRecords);
                }

            }
        }

    }

    @Override
    public void batchRgsnBookThaw() {

        List<BocomTransRecords> transRecordsList = bocomTransRecordsService.lambdaQuery().eq(BocomTransRecords::getBusinessType, 5)
                .eq(BocomTransRecords::getBusinessType, 5)
                .groupBy(BocomTransRecords::getRelPlfmPayOrdrNo)
                .isNull(BocomTransRecords::getTxnStatus)
                .list();
        if (CollectionUtil.isNotEmpty(transRecordsList)) {
            transRecordsList.forEach(transRecords -> {
                rgsnBookThaw(transRecords.getId());
            });
        }

    }

    @Override
    public void rgsnBookThaw(Long id) {

        BocomTransRecords transRecords = bocomTransRecordsService.getById(id);
        if (transRecords != null) {
            if (transRecords.getTxnStatus() != null) {
                throw new BusinessException(CodeUtil.FAIL, "交易记录已处理，不能重复处理！");
            }

            B2BJEBP1005RequestV1 b2BJEBP1005RequestV1 = new B2BJEBP1005RequestV1();
            B2BJEBP1005RequestV1.B2BJEBP1005RequestV1Biz b2BJEBP1005RequestV1Biz = new B2BJEBP1005RequestV1.B2BJEBP1005RequestV1Biz();
            B2BJEBP1005RequestV1.B2BJEBP1005RequestV1Biz.PptmBody pptmBody = new B2BJEBP1005RequestV1.B2BJEBP1005RequestV1Biz.PptmBody();
            pptmBody.setPlfmSerNo(serialNumberGenerator.generatePlfmSerNo());
            pptmBody.setTxnDt(DateUtil.getDayStringFormatYMD(new Date()));
            SimpleDateFormat dateFormat = new SimpleDateFormat("HHmmss");
            String HHmmss = dateFormat.format(new Date());
            pptmBody.setTxnSendTme(HHmmss);
            pptmBody.setPlfmBsnOrdrNo(serialNumberGenerator.nextValue(BocomApiConstant.PLATFORM_BUSINESS_ORDER_CODE));
            pptmBody.setBsnOrdrTp("5");
            pptmBody.setPlfmPayOrdrNo(serialNumberGenerator.nextValue(BocomApiConstant.PLATFORM_BUSINESS_ORDER_CODE));
            pptmBody.setPlfmOrdrNo(serialNumberGenerator.nextValue(BocomApiConstant.PLATFORM_ORDER_CODE));
            pptmBody.setOrglPlfmBsnOrdrNo(transRecords.getRelPlfmPayOrdrNo());
            pptmBody.setOrglPlfmOrdrNo(transRecords.getRelPlfmPayOrdrNo());
            pptmBody.setOrglPlfmPayOrdrNo(transRecords.getRelPlfmPayOrdrNo());
            pptmBody.setTxnCcy(transRecords.getCurrency());
            pptmBody.setOrdrAmt(transRecords.getTxnAmt().toString());
            b2BJEBP1005RequestV1Biz.setPptmBody(pptmBody);
            b2BJEBP1005RequestV1.setBizContent(b2BJEBP1005RequestV1Biz);
            B2BJEBP1005ResponseV1.PptmBody response = bocomVipCommonService.rgsnBookThaw(b2BJEBP1005RequestV1);
            if (response != null) {
                transRecords.setPlfmPayOrdrNo(pptmBody.getPlfmPayOrdrNo());
                transRecords.setPlfmSerNo(pptmBody.getPlfmSerNo());
                if ("00".equals(response.getTxnSts())) {
                    //成功
                    transRecords.setTxnStatus("bocomTransState_success");
                    transRecords.setTxnCompleteDate(new Date());
                }
                if ("01".equals(response.getTxnSts())) {
                    //失败
                    transRecords.setTxnStatus("bocomTransState_failure");
                    transRecords.setFailReason(response.getErrInf());
                    transRecords.setTxnCompleteDate(new Date());
                }

                if ("02".equals(response.getTxnSts())) {
                    //待查
                    transRecords.setTxnStatus("bocomTransState_pending");
                }
                if ("03".equals(response.getTxnSts())) {
                    //待授权
                    transRecords.setTxnStatus("bocomTransState_authorize");
                }
                if ("04".equals(response.getTxnSts())) {
                    //授权拒绝
                    transRecords.setTxnStatus("bocomTransState_authorize_refuse");
                    transRecords.setTxnCompleteDate(new Date());
                }
                if ("05".equals(response.getTxnSts())) {
                    //延时中
                    transRecords.setTxnStatus("bocomTransState_delay");
                }
                bocomTransRecordsService.updateById(transRecords);

            }
        }
    }

    @Override
    public void batchRgsnBookBuckling() {
        List<BocomTransRecords> transRecordsList = bocomTransRecordsService.lambdaQuery()
                .eq(BocomTransRecords::getBusinessType, 6)
                .groupBy(BocomTransRecords::getRelPlfmPayOrdrNo)
                .isNull(BocomTransRecords::getTxnStatus)
                .list();
        if (CollectionUtil.isNotEmpty(transRecordsList)) {
            transRecordsList.forEach(transRecords -> {
                if (transRecords != null) {
                    rgsnBookBuckling(transRecords.getId());
                }

            });
        }
    }

    @Override
    public void rgsnBookBuckling(Long id) {

        BocomTransRecords transRecords = bocomTransRecordsService.getById(id);
        if (transRecords != null) {
            if (transRecords.getTxnStatus() != null) {
                throw new BusinessException(CodeUtil.FAIL, "交易记录已处理，不能重复处理！");
            }
            BocomVipSilentAccountInfo silentAccountInfo = null;
            BocomVipAccountBasicInfo vipAccountBasicInfo = null;

            if (transRecords.getAccountType() == 0) {
                silentAccountInfo = bocomVipSilentAccountInfoService.lambdaQuery()
                        .eq(BocomVipSilentAccountInfo::getSilentAccountNumber, transRecords.getAccountNumber())
                        .one();
                if (silentAccountInfo == null) {
                    throw new BusinessException(CodeUtil.FAIL, "未查询出静默户信息！");
                }
                vipAccountBasicInfo = getById(silentAccountInfo.getBocomVipAccountBasicInfoId());
                if (vipAccountBasicInfo == null) {
                    throw new BusinessException(CodeUtil.FAIL, "未查询出登记簿信息！");
                }
            }
            if (transRecords.getAccountType() == 1) {
                vipAccountBasicInfo = lambdaQuery()
                        .eq(BocomVipAccountBasicInfo::getAccountNumber, transRecords.getAccountNumber())
                        .one();
                if (vipAccountBasicInfo == null) {
                    throw new BusinessException(CodeUtil.FAIL, "未查询出登记簿信息！");
                }
                silentAccountInfo = bocomVipSilentAccountInfoService.lambdaQuery()
                        .eq(BocomVipSilentAccountInfo::getSilentAccountNumber, transRecords.getCounterpartyAccountNumber())
                        .one();
                if (silentAccountInfo == null) {
                    throw new BusinessException(CodeUtil.FAIL, "未查询出静默户信息！");
                }
            }

            BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
            if (bocomBasicInfo != null) {
                B2BJEBP1001RequestV2 b2BJEBP1001RequestV2 = new B2BJEBP1001RequestV2();
                B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz b2BJEBP1001RequestV2Biz = new B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz();
                B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody pptmBody = new B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody();

                ArrayList<B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody.TxnInf> txnInfList = new ArrayList<>();
                B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody.TxnInf txnInf = new B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody.TxnInf();

                pptmBody.setPlfmSerNo(serialNumberGenerator.generatePlfmSerNo());
                //交易日期
                pptmBody.setTxnDt(DateUtil.getDayStringFormatYMD(new Date()));
                //交易发送时间
                SimpleDateFormat dateFormat = new SimpleDateFormat("HHmmss");
                String HHmmss = dateFormat.format(new Date());
                pptmBody.setTxnSendTme(HHmmss);
                pptmBody.setBsnOrdrTp("2");
                //平台业务订单号
                pptmBody.setPlfmBsnOrdrNo(serialNumberGenerator.nextValue(BocomApiConstant.PLATFORM_BUSINESS_ORDER_CODE));
                //平台支付订单号
                pptmBody.setPlfmPayOrdrNo(pptmBody.getPlfmBsnOrdrNo());
                //交易类型 默认直接付款
                pptmBody.setTxnTp("03");
                pptmBody.setPayrCustId(bocomBasicInfo.getCustomerNumber());
                pptmBody.setPayrRgsnBookId(transRecords.getAccountNumber());

                //交易信息
                txnInf.setPlfmOrdrNo(serialNumberGenerator.nextValue(BocomApiConstant.PLATFORM_ORDER_CODE));
                txnInf.setRcvrRgsnBookId(vipAccountBasicInfo.getAccountNumber());
                txnInf.setRcvrCustId(bocomBasicInfo.getCustomerNumber());
                txnInf.setTxnCcy(vipAccountBasicInfo.getCurrency());

                txnInf.setOrdrAmt(transRecords.getTxnAmt().toString());
                txnInf.setTxnAmt(transRecords.getTxnAmt().toString());
                txnInfList.add(txnInf);

                pptmBody.setTxnInf(txnInfList);
                b2BJEBP1001RequestV2Biz.setPptmBody(pptmBody);
                b2BJEBP1001RequestV2.setBizContent(b2BJEBP1001RequestV2Biz);
                B2BJEBP1001ResponseV2.PptmBody response = bocomVipCommonService.transferAccounts(b2BJEBP1001RequestV2);

                if (response != null) {

                    //平台流水号
                    transRecords.setPlfmSerNo(pptmBody.getPlfmSerNo());
                    //支付订单号
                    transRecords.setPlfmPayOrdrNo(pptmBody.getPlfmPayOrdrNo());
                    if ("00".equals(response.getTxnSts())) {
                        //成功
                        transRecords.setTxnStatus("bocomTransState_success");
                        transRecords.setTxnCompleteDate(new Date());
                    }
                    if ("01".equals(response.getTxnSts())) {
                        //失败
                        transRecords.setTxnStatus("bocomTransState_failure");
                        transRecords.setFailReason(response.getErrInf());
                        transRecords.setTxnCompleteDate(new Date());
                    }

                    if ("02".equals(response.getTxnSts())) {
                        //待查
                        transRecords.setTxnStatus("bocomTransState_pending");
                    }
                    if ("03".equals(response.getTxnSts())) {
                        //待授权
                        transRecords.setTxnStatus("bocomTransState_authorize");
                    }
                    if ("04".equals(response.getTxnSts())) {
                        //授权拒绝
                        transRecords.setTxnStatus("bocomTransState_authorize_refuse");
                        transRecords.setTxnCompleteDate(new Date());
                    }
                    if ("05".equals(response.getTxnSts())) {
                        //延时中
                        transRecords.setTxnStatus("bocomTransState_delay");
                    }
                    bocomTransRecordsService.updateById(transRecords);
                    //更新反向记录
                    BocomTransRecords transRecordsReverse = bocomTransRecordsService.lambdaQuery()
                            .eq(BocomTransRecords::getRelPlfmPayOrdrNo, transRecords.getRelPlfmPayOrdrNo())
                            .eq(BocomTransRecords::getFundSource, BocomTransRecordsFundSourceDic.ChildEnum.SILENT_TO_VIPACCOUNT.getCode())
                            .eq(BocomTransRecords::getAccountNumber, transRecords.getCounterpartyAccountNumber())
                            .eq(BocomTransRecords::getCounterpartyAccountNumber, transRecords.getAccountNumber())
                            .ne(BocomTransRecords::getId, transRecords.getId())
                            .one();
                    if (transRecordsReverse != null) {
                        transRecordsReverse.setTxnStatus(transRecords.getTxnStatus());
                        transRecordsReverse.setTxnCompleteDate(transRecords.getTxnCompleteDate());
                        transRecordsReverse.setFailReason(transRecords.getFailReason());
                        transRecordsReverse.setPlfmPayOrdrNo(transRecords.getPlfmPayOrdrNo());
                        transRecordsReverse.setPlfmSerNo(transRecords.getPlfmSerNo());
                        bocomTransRecordsService.updateById(transRecordsReverse);
                    }

                }


            }


        }


    }

    @Override
    public void transRecordHandleAll(Long id) {

        BocomTransRecords transRecords = bocomTransRecordsService.getById(id);
        if (transRecords == null) {
            throw new BusinessException(CodeUtil.FAIL, "交易记录不能为空！");
        }
        if (5 == transRecords.getBusinessType()) {
            //解冻
            rgsnBookThaw(id);
        }
        if (6 == transRecords.getBusinessType()) {
            //划扣
            rgsnBookBuckling(id);
        }
        if (BocomTransRecordsFundSourceDic.ChildEnum.VIPACCOUNT_TO_INKASSO.getCode().equals(transRecords.getFundSource())) {
            //划转至长银登记簿
            transferInkasso(id);
        }
    }

    @Override
    public void transferInkasso(Long id) {

        BocomTransRecords transRecords = bocomTransRecordsService.getById(id);
        if (transRecords == null) {
            throw new BusinessException(CodeUtil.FAIL, "交易记录不能为空！");
        }
        if (transRecords.getTxnStatus() != null) {
            throw new BusinessException(CodeUtil.FAIL, "交易记录已处理，不能重复处理！");
        }
        //长银登记簿
        BocomVipAccountBasicInfo InkassoVip = null;
        //付款方登记簿
        BocomVipAccountBasicInfo vipAccountBasicInfo = null;
        BocomVipAccountBasicInfo accountBasicInfo = lambdaQuery()
                .eq(BocomVipAccountBasicInfo::getAccountNumber, transRecords.getAccountNumber())
                .one();
        if (accountBasicInfo != null) {
            //判断是否为长银登记簿
            if (accountBasicInfo.getInkasso() == 1) {
                InkassoVip = accountBasicInfo;
                vipAccountBasicInfo = lambdaQuery()
                        .eq(BocomVipAccountBasicInfo::getAccountNumber, transRecords.getCounterpartyAccountNumber())
                        .one();
            }
            if (accountBasicInfo.getInkasso() == 0) {
                InkassoVip = lambdaQuery()
                        .eq(BocomVipAccountBasicInfo::getAccountNumber, transRecords.getCounterpartyAccountNumber())
                        .one();
                vipAccountBasicInfo = accountBasicInfo;
            }

        }
        BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.get(vipAccountBasicInfo.getBocomBasicInfoId());
        //获取能正常使用得长银登记簿
        if (InkassoVip != null) {
            B2BJEBP1001RequestV2 b2BJEBP1001RequestV2 = new B2BJEBP1001RequestV2();
            B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz b2BJEBP1001RequestV2Biz = new B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz();
            B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody pptmBody = new B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody();
            ArrayList<B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody.TxnInf> txnInfList = new ArrayList<>();
            B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody.TxnInf txnInf = new B2BJEBP1001RequestV2.B2BJEBP1001RequestV2Biz.PptmBody.TxnInf();

            if (InkassoVip.getAccountNumber().equals(transRecords.getAccountNumber())) {

            }
            BocomBasicInfo InkassoBocomBasicInfo = bocomBasicInfoService.get(InkassoVip.getBocomBasicInfoId());


            pptmBody.setPlfmSerNo(serialNumberGenerator.generatePlfmSerNo());
            //交易日期
            pptmBody.setTxnDt(DateUtil.getDayStringFormatYMD(new Date()));
            //交易发送时间
            SimpleDateFormat dateFormat = new SimpleDateFormat("HHmmss");
            String HHmmss = dateFormat.format(new Date());
            pptmBody.setTxnSendTme(HHmmss);
            pptmBody.setBsnOrdrTp("2");
            //平台业务订单号
            pptmBody.setPlfmBsnOrdrNo(serialNumberGenerator.nextValue(BocomApiConstant.PLATFORM_BUSINESS_ORDER_CODE));
            //平台支付订单号
            pptmBody.setPlfmPayOrdrNo(pptmBody.getPlfmBsnOrdrNo());
            //交易类型 默认直接付款
            pptmBody.setTxnTp("03");
            pptmBody.setPayrCustId(bocomBasicInfo.getCustomerNumber());
            pptmBody.setPayrRgsnBookId(vipAccountBasicInfo.getAccountNumber());

            //交易信息
            txnInf.setPlfmOrdrNo(serialNumberGenerator.nextValue(BocomApiConstant.PLATFORM_ORDER_CODE));
            txnInf.setRcvrRgsnBookId(InkassoVip.getAccountNumber());
            txnInf.setRcvrCustId(InkassoBocomBasicInfo.getCustomerNumber());
            txnInf.setTxnCcy(vipAccountBasicInfo.getCurrency());

            txnInf.setOrdrAmt(transRecords.getTxnAmt().toString());
            txnInf.setTxnAmt(transRecords.getTxnAmt().toString());
            txnInfList.add(txnInf);

            pptmBody.setTxnInf(txnInfList);
            b2BJEBP1001RequestV2Biz.setPptmBody(pptmBody);
            b2BJEBP1001RequestV2.setBizContent(b2BJEBP1001RequestV2Biz);
            B2BJEBP1001ResponseV2.PptmBody response = bocomVipCommonService.transferAccounts(b2BJEBP1001RequestV2);
            if (response != null) {
                //平台流水号
                transRecords.setPlfmSerNo(pptmBody.getPlfmSerNo());
                //支付订单号
                transRecords.setPlfmPayOrdrNo(pptmBody.getPlfmPayOrdrNo());
                if ("00".equals(response.getTxnSts())) {
                    //成功
                    transRecords.setTxnStatus("bocomTransState_success");
                    transRecords.setTxnCompleteDate(new Date());
                }
                if ("01".equals(response.getTxnSts())) {
                    //失败
                    transRecords.setTxnStatus("bocomTransState_failure");
                    transRecords.setFailReason(response.getErrInf());
                    transRecords.setTxnCompleteDate(new Date());
                }

                if ("02".equals(response.getTxnSts())) {
                    //待查
                    transRecords.setTxnStatus("bocomTransState_pending");
                }
                if ("03".equals(response.getTxnSts())) {
                    //待授权
                    transRecords.setTxnStatus("bocomTransState_authorize");
                }
                if ("04".equals(response.getTxnSts())) {
                    //授权拒绝
                    transRecords.setTxnStatus("bocomTransState_authorize_refuse");
                    transRecords.setTxnCompleteDate(new Date());
                }
                if ("05".equals(response.getTxnSts())) {
                    //延时中
                    transRecords.setTxnStatus("bocomTransState_delay");
                }
                bocomTransRecordsService.updateById(transRecords);

                //更新反向记录
                BocomTransRecords transRecordsReverse = bocomTransRecordsService.lambdaQuery()
                        .eq(BocomTransRecords::getRelPlfmPayOrdrNo, transRecords.getRelPlfmPayOrdrNo())
                        .eq(BocomTransRecords::getFundSource, BocomTransRecordsFundSourceDic.ChildEnum.VIPACCOUNT_TO_INKASSO.getCode())
                        .eq(BocomTransRecords::getAccountNumber, transRecords.getCounterpartyAccountNumber())
                        .eq(BocomTransRecords::getCounterpartyAccountNumber, transRecords.getAccountNumber())
                        .ne(BocomTransRecords::getId, transRecords.getId())
                        .one();
                if (transRecordsReverse != null) {
                    transRecordsReverse.setTxnStatus(transRecords.getTxnStatus());
                    transRecordsReverse.setTxnCompleteDate(transRecords.getTxnCompleteDate());
                    transRecordsReverse.setFailReason(transRecords.getFailReason());
                    transRecordsReverse.setPlfmPayOrdrNo(transRecords.getPlfmPayOrdrNo());
                    transRecordsReverse.setPlfmSerNo(transRecords.getPlfmSerNo());
                    bocomTransRecordsService.updateById(transRecordsReverse);
                }
            }


        }


    }

    @Override
    public void batchTransferInkasso() {

        List<BocomTransRecords> list = bocomTransRecordsService.lambdaQuery()
                .eq(BocomTransRecords::getFundSource, BocomTransRecordsFundSourceDic.ChildEnum.VIPACCOUNT_TO_INKASSO.getCode())
                .in(BocomTransRecords::getBusinessType, 2, 3)
                .groupBy(BocomTransRecords::getRelPlfmPayOrdrNo)
                .isNull(BocomTransRecords::getTxnStatus)
                .list();
        if (CollectionUtil.isNotEmpty(list)) {
            list.forEach(bocomTransRecords -> {
                transferInkasso(bocomTransRecords.getId());
            });
        }

    }

    /**
     * 新增外部入账到静默户的关联交易记录
     *
     * @param transRecords
     */
    private void addToSilentRecords(BocomTransRecords transRecords) {

        //静默户信息
        BocomVipSilentAccountInfo vipSilentAccountInfo = bocomVipSilentAccountInfoService
                .lambdaQuery()
                .eq(BocomVipSilentAccountInfo::getSilentAccountNumber, transRecords.getAccountNumber())
                .one();
        //登记簿信息
        BocomVipAccountBasicInfo vipAccountBasicInfo = lambdaQuery()
                .eq(BocomVipAccountBasicInfo::getId, vipSilentAccountInfo.getBocomVipAccountBasicInfoId())
                .one();

        BocomTransRecords bocomTransRecords = new BocomTransRecords();
        //解冻
        bocomTransRecords.setBusinessType(5);
        //对方账号
        bocomTransRecords.setIncomeExpenditureType(0);
        bocomTransRecords.setTxnAmt(transRecords.getTxnAmt());
        bocomTransRecords.setCurrency(transRecords.getCurrency());
        bocomTransRecords.setAccountNumber(vipSilentAccountInfo.getSilentAccountNumber());
        bocomTransRecords.setAccountName(vipSilentAccountInfo.getAccountName());
        bocomTransRecords.setCounterpartyAccountNumber(vipSilentAccountInfo.getSilentAccountNumber());
        bocomTransRecords.setCounterpartyAccountName(vipSilentAccountInfo.getAccountName());
        bocomTransRecords.setRelPlfmPayOrdrNo(transRecords.getPlfmPayOrdrNo());
        bocomTransRecords.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.SILENT_TO_SILENT.getCode());
        bocomTransRecords.setAccountType(0);
        bocomTransRecordsService.save(bocomTransRecords);

        //划扣至登记簿
        if (vipSilentAccountInfo != null) {
            BocomTransRecords records = new BocomTransRecords();
            records.setBusinessType(6);
            records.setIncomeExpenditureType(1);
            records.setTxnAmt(transRecords.getTxnAmt());
            records.setCurrency(transRecords.getCurrency());
            records.setRelPlfmPayOrdrNo(transRecords.getPlfmPayOrdrNo());
            records.setAccountNumber(vipSilentAccountInfo.getSilentAccountNumber());
            records.setAccountName(vipSilentAccountInfo.getAccountName());
            records.setCounterpartyAccountName(vipAccountBasicInfo.getAccountName());
            records.setCounterpartyAccountNumber(vipAccountBasicInfo.getAccountNumber());
            records.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.SILENT_TO_VIPACCOUNT.getCode());
            records.setAccountType(0);
            bocomTransRecordsService.save(records);
            BocomTransRecords recordsRevers = new BocomTransRecords();
            recordsRevers.setAccountType(0);
            recordsRevers.setIncomeExpenditureType(0);
            recordsRevers.setTxnAmt(transRecords.getTxnAmt());
            recordsRevers.setCurrency(transRecords.getCurrency());
            recordsRevers.setRelPlfmPayOrdrNo(transRecords.getPlfmPayOrdrNo());
            recordsRevers.setBusinessType(6);
            recordsRevers.setAccountNumber(vipAccountBasicInfo.getAccountName());
            recordsRevers.setAccountName(vipAccountBasicInfo.getAccountName());
            recordsRevers.setCounterpartyAccountNumber(vipSilentAccountInfo.getSilentAccountNumber());
            recordsRevers.setCounterpartyAccountName(vipSilentAccountInfo.getAccountName());
            recordsRevers.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.SILENT_TO_VIPACCOUNT.getCode());
            bocomTransRecordsService.save(recordsRevers);
        }

        //划转至 长银登记簿
        BocomVipAccountBasicInfo InkassoVip = lambdaQuery().eq(BocomVipAccountBasicInfo::getInkasso, 1)
                .eq(BocomVipAccountBasicInfo::getChdbokSts, 1)
                .eq(BocomVipAccountBasicInfo::getAccountStatus, 1)
                .eq(BocomVipAccountBasicInfo::getAuthorizationStatus, 4)
                .one();
        if (InkassoVip != null) {
            //内部转出
            BocomTransRecords records = new BocomTransRecords();
            records.setBusinessType(3);
            records.setIncomeExpenditureType(1);
            records.setAccountNumber(vipAccountBasicInfo.getAccountNumber());
            records.setAccountName(vipAccountBasicInfo.getAccountName());
            records.setCounterpartyAccountName(InkassoVip.getAccountName());
            records.setCounterpartyAccountNumber(InkassoVip.getAccountNumber());
            records.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.VIPACCOUNT_TO_INKASSO.getCode());
            records.setAccountType(1);
            records.setTxnAmt(transRecords.getTxnAmt());
            records.setCurrency(transRecords.getCurrency());
            records.setRelPlfmPayOrdrNo(transRecords.getPlfmPayOrdrNo());
            bocomTransRecordsService.save(records);
            //内部转入
            BocomTransRecords recordsRevers = new BocomTransRecords();
            records.setIncomeExpenditureType(0);
            recordsRevers.setBusinessType(2);
            recordsRevers.setAccountNumber(InkassoVip.getAccountNumber());
            recordsRevers.setAccountName(InkassoVip.getAccountName());
            recordsRevers.setCounterpartyAccountNumber(vipAccountBasicInfo.getAccountNumber());
            recordsRevers.setCounterpartyAccountName(vipAccountBasicInfo.getAccountName());
            recordsRevers.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.VIPACCOUNT_TO_INKASSO.getCode());
            recordsRevers.setTxnAmt(transRecords.getTxnAmt());
            recordsRevers.setCurrency(transRecords.getCurrency());
            recordsRevers.setRelPlfmPayOrdrNo(transRecords.getPlfmPayOrdrNo());
            bocomTransRecordsService.save(recordsRevers);

        }
    }

    /**
     * 新增实体卡到登记簿入账的关联交易记录
     *
     * @param transRecords
     */
    private void addToVipAccountRecords(BocomTransRecords transRecords) {
        if (transRecords != null) {
            //登记簿信息
            BocomVipAccountBasicInfo vipAccountBasicInfo = lambdaQuery()
                    .eq(BocomVipAccountBasicInfo::getAccountNumber, transRecords.getAccountNumber())
                    .one();
            //解冻
            BocomTransRecords bocomTransRecords = new BocomTransRecords();
            bocomTransRecords.setBusinessType(5);
            bocomTransRecords.setIncomeExpenditureType(0);
            //对方账号
            bocomTransRecords.setCounterpartyAccountNumber(vipAccountBasicInfo.getAccountNumber());
            bocomTransRecords.setCounterpartyAccountName(vipAccountBasicInfo.getAccountName());
            bocomTransRecords.setRelPlfmPayOrdrNo(transRecords.getPlfmPayOrdrNo());
            bocomTransRecords.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.VIPACCOUNT_TO_VIPACCOUNT.getCode());
            bocomTransRecords.setAccountType(1);
            bocomTransRecords.setTxnAmt(transRecords.getTxnAmt());
            bocomTransRecords.setCurrency(transRecords.getCurrency());

            bocomTransRecordsService.save(bocomTransRecords);
            //划转至 长银登记簿
            BocomVipAccountBasicInfo InkassoVip = lambdaQuery().eq(BocomVipAccountBasicInfo::getInkasso, 1)
                    .eq(BocomVipAccountBasicInfo::getChdbokSts, 1)
                    .eq(BocomVipAccountBasicInfo::getAccountStatus, 1)
                    .eq(BocomVipAccountBasicInfo::getAuthorizationStatus, 4)
                    .one();
            if (InkassoVip != null) {
                BocomTransRecords records = new BocomTransRecords();
                //内部转出
                records.setBusinessType(3);
                records.setIncomeExpenditureType(1);
                records.setTxnAmt(transRecords.getTxnAmt());
                records.setCurrency(transRecords.getCurrency());
                records.setAccountNumber(vipAccountBasicInfo.getAccountNumber());
                records.setAccountName(vipAccountBasicInfo.getAccountName());
                records.setCounterpartyAccountName(InkassoVip.getAccountName());
                records.setCounterpartyAccountNumber(InkassoVip.getAccountNumber());
                records.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.VIPACCOUNT_TO_INKASSO.getCode());
                records.setAccountType(1);
                bocomTransRecordsService.save(records);
                //内部转入
                BocomTransRecords recordsRevers = new BocomTransRecords();
                BeanUtils.copyProperties(transRecords, recordsRevers, "id");
                recordsRevers.setBusinessType(2);
                records.setIncomeExpenditureType(0);
                recordsRevers.setAccountNumber(InkassoVip.getAccountNumber());
                recordsRevers.setAccountName(InkassoVip.getAccountName());
                recordsRevers.setCounterpartyAccountNumber(vipAccountBasicInfo.getAccountNumber());
                recordsRevers.setCounterpartyAccountName(vipAccountBasicInfo.getAccountName());
                transRecords.setFundSource(BocomTransRecordsFundSourceDic.ChildEnum.VIPACCOUNT_TO_INKASSO.getCode());
                records.setAccountType(1);
                bocomTransRecordsService.save(transRecords);

            }
        }
    }

    /**
     * 填充账户真实状态
     *
     * @param vipAccountBasicInfo
     */
    private void autoAccountRealStatus(BocomVipAccountBasicInfo vipAccountBasicInfo) {

        if (vipAccountBasicInfo != null) {
            BocomVipLimitInfo vipLimitInfo = bocomVipLimitInfoService
                    .lambdaQuery()
                    .eq(BocomVipLimitInfo::getBocomVipAccountBasicInfoId, vipAccountBasicInfo.getId())
                    .one();
            String realStatus = "";
            if (vipAccountBasicInfo.getAccountStatus() == 1) {
                // 授权状态 0-待用户授权 1-银行审核中 2-授权失败（用户拒绝）3-授权失败（银行拒绝）4-授权成功
                //授权代理人授权状态
                Integer authorizationStatus = vipAccountBasicInfo.getAuthorizationStatus();
                //法人授权状态
                Integer legalAuthorizationStatus = vipAccountBasicInfo.getLegalAuthorizationStatus();


                if (authorizationStatus == 1 || legalAuthorizationStatus == 1 ||
                        authorizationStatus == 2 || legalAuthorizationStatus == 2 ||
                        authorizationStatus == 3 || legalAuthorizationStatus == 3) {
                    //任一授权状态为 1/2/3 时 账户真实状态置为 开通失败
                    vipAccountBasicInfo.setAccountStatusReal(BocomVipAccountStatusDic.ChildEnum.VIP_ACCOUNT_OPENING_FAILED.getCode());
                }

                if ((authorizationStatus == 0 || authorizationStatus == 4) && (legalAuthorizationStatus == 0 || legalAuthorizationStatus == 4)) {
                    //授权状态组合为 0+0 || 0+4 时 且 可收可付款（无收入管控且无支出管控）且 接口返回的登记簿状态为是生效 时  账户真实状态置为 生效
                    if (vipAccountBasicInfo.getChdbokSts() != null && vipAccountBasicInfo.getChdbokSts() == 1 || (vipLimitInfo != null && vipLimitInfo.getIncFlg() == 1 && vipLimitInfo.getPayFlg() == 1)) {
                        vipAccountBasicInfo.setAccountStatusReal(BocomVipAccountStatusDic.ChildEnum.VIP_ACCOUNT_EFFECT.getCode());
                    } else {
                        //授权状态组合为 0+0 || 0+4 时 且 可收可付款（无收入管控且无支出管控） 时  账户真实状态置为 待生效
                        vipAccountBasicInfo.setAccountStatusReal(BocomVipAccountStatusDic.ChildEnum.VIP_ACCOUNT_PENDING_EFFECT.getCode());
                    }
                }

                if (authorizationStatus == 4 && legalAuthorizationStatus == 4) {
                    //授权状态组合为 4+4 且 可收可付款（无收入管控且无支出管控） 时  账户真实状态置 为 生效
                    if (vipAccountBasicInfo.getChdbokSts() != null && vipAccountBasicInfo.getChdbokSts() == 1 || (vipLimitInfo != null && vipLimitInfo.getIncFlg() == 1 && vipLimitInfo.getPayFlg() == 1)) {
                        vipAccountBasicInfo.setAccountStatusReal(BocomVipAccountStatusDic.ChildEnum.VIP_ACCOUNT_EFFECT.getCode());
                    }
                }

            } else {
                vipAccountBasicInfo.setAccountStatusReal(BocomVipAccountStatusDic.ChildEnum.VIP_ACCOUNT_PENDING_EXPIRE.getCode());
            }
        }
    }

    /**
     * 填充授权代理人
     *
     * @param bocomVipAccountBasicInfo
     */
    private void autoAuthenticator(BocomVipAccountBasicInfo bocomVipAccountBasicInfo) {

        BocomBasicInfo basicInfo = bocomBasicInfoService.get(bocomVipAccountBasicInfo.getBocomBasicInfoId());
        List<BocomVipAccountNoticeInfo> noticeInfoList = bocomVipAccountNoticeInfoService.lambdaQuery()
                .eq(BocomVipAccountNoticeInfo::getBocomVipAccountBasicInfoId, bocomVipAccountBasicInfo.getId())
                .list();
        List<BocomVipAccountNoticeInfo> noticeInfos = new ArrayList<>();
        if (CollectionUtil.isNotEmpty(noticeInfoList)) {
            //授权代理人
            BocomAuthorizedAgent authorizedAgent = bocomAuthorizedAgentService.lambdaQuery()
                    .eq(BocomAuthorizedAgent::getBocomBasicInfoId, basicInfo.getId())
                    .one();
            //法人
            BocomLegalPersonInfo legalPersonInfo = bocomLegalPersonInfoService.lambdaQuery()
                    .eq(BocomLegalPersonInfo::getBocomBasicInfoId, basicInfo.getId())
                    .one();
            //负责人
            BocomShareholderActualController actualController = bocomShareholderActualControllerService.lambdaQuery()
                    .eq(BocomShareholderActualController::getBocomBasicInfoId, basicInfo.getId())
                    .eq(BocomShareholderActualController::getPersonType, 2)
                    .one();
            if (4 != bocomVipAccountBasicInfo.getLegalAuthorizationStatus()) {
                noticeInfoList.forEach(n -> {
                    if (n.getNoticeObject().equals("1")) {
                        if (basicInfo.getCustomerType() == 0) {
                            n.setAuthenticator(legalPersonInfo.getName());
                        } else if (basicInfo.getCustomerType() == 1) {
                            n.setAuthenticator(actualController.getName());
                        }
                        noticeInfos.add(n);
                    }

                });
            }
            if (4 != bocomVipAccountBasicInfo.getAuthorizationStatus()) {
                noticeInfoList.forEach(n -> {
                    if ("2".equals(n.getNoticeObject())) {
                        n.setAuthenticator(authorizedAgent.getName());
                        noticeInfos.add(n);
                    }
                });
            }


        }
        bocomVipAccountBasicInfo.setNoticeInfoList(noticeInfos);

    }


}
