package com.sunxung.factoring.service.bocom.vipaccount.impl;

import com.bocom.api.BocomApiException;
import com.bocom.api.utils.BocomDigest;
import com.sunxung.factoring.component.constance.BocomApiConstant;
import com.sunxung.factoring.component.exception.BusinessException;
import com.sunxung.factoring.component.util.CodeUtil;
import com.sunxung.factoring.component.util.CollectionUtil;
import com.sunxung.factoring.entity.bocom.request.*;
import com.sunxung.factoring.entity.bocom.response.*;
import com.sunxung.factoring.service.bocom.api.IBocomApiService;
import com.sunxung.factoring.service.bocom.vipaccount.BocomVipCommonService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.io.File;

/**
 * @Author Yafan Wang
 * @Date 2024/8/5 14:05
 */
@Service
public class BocomVipCommonServiceImpl implements BocomVipCommonService {

    private static final Logger logger = LoggerFactory.getLogger(BocomVipCommonServiceImpl.class);

    @Autowired
    private IBocomApiService bocomApiService;

    @Override
    public B2BJEBM1201ResponseV2.PptmBody maintenanceVip(B2BJEBM1201RequestV2 requestV2) {

        B2BJEBM1201ResponseV2.PptmBody pptmBody;
        try {
            B2BJEBM1201ResponseV2 b2BJEBM1201ResponseV2 = bocomApiService.sendToBocom(requestV2, BocomApiConstant.B2BJEBM_1201_URL);
            if (b2BJEBM1201ResponseV2.isSuccess() &&
                    b2BJEBM1201ResponseV2.getPptmBody() != null && b2BJEBM1201ResponseV2.getPptmBody().getRgsnBookId() != null) {
                pptmBody = b2BJEBM1201ResponseV2.getPptmBody();
            } else {
                throw new BusinessException(CodeUtil.FAIL, b2BJEBM1201ResponseV2.getPptmHead().getReturnMsg());
            }
        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "维护会员登记薄失败！" + e.getMessage());
        }

        return pptmBody;
    }

    @Override
    public B2BJEBM1202ResponseV2.PptmBody queryVipAccount(B2BJEBM1202RequestV2 requestV2) {
        B2BJEBM1202ResponseV2.PptmBody pptmBody;
        try {
            B2BJEBM1202ResponseV2 b2BJEBM1201ResponseV2 = bocomApiService.sendToBocom(requestV2, BocomApiConstant.B2BJEBM_1202_URL);
            if (b2BJEBM1201ResponseV2.isSuccess()) {
                pptmBody = b2BJEBM1201ResponseV2.getPptmBody();
            } else {
                throw new BusinessException(CodeUtil.FAIL, b2BJEBM1201ResponseV2.getPptmHead().getReturnMsg());
            }
        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "查询会员登记薄信息失败！" + e.getMessage());
        }

        return pptmBody;
    }

    @Override
    public B2BJEBM1203ResponseV1.PptmBody maintenanceVipBindAccount(B2BJEBM1203RequestV1 requestV1) {
        B2BJEBM1203ResponseV1.PptmBody pptmBody;
        try {
            B2BJEBM1203ResponseV1 b2BJEBM1201ResponseV2 = bocomApiService.sendToBocom(requestV1, BocomApiConstant.B2BJEBM_1203_URL);
            if (b2BJEBM1201ResponseV2.getPptmBody() != null && b2BJEBM1201ResponseV2.getPptmBody().getBindSts() != null) {
                pptmBody = b2BJEBM1201ResponseV2.getPptmBody();
            } else {
                throw new BusinessException(CodeUtil.FAIL, b2BJEBM1201ResponseV2.getPptmHead().getReturnMsg());
            }
        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "会员登记簿绑定账户失败！" + e.getMessage());
        }

        return pptmBody;
    }

    @Override
    public B2BJEBM1206ResponseV1.PptmBody queryVipBindAccount(B2BJEBM1206RequestV1 requestV1) {
        B2BJEBM1206ResponseV1.PptmBody pptmBody;
        try {
            B2BJEBM1206ResponseV1 b2BJEBM1206ResponseV1 = bocomApiService.sendToBocom(requestV1, BocomApiConstant.B2BJEBM_1206_URL);
            if (b2BJEBM1206ResponseV1.isSuccess()) {
                pptmBody = b2BJEBM1206ResponseV1.getPptmBody();
            } else {
                throw new BusinessException(CodeUtil.FAIL, b2BJEBM1206ResponseV1.getPptmHead().getReturnMsg());
            }
        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "查询会员登记簿绑定账户信息失败！" + e.getMessage());
        }

        return pptmBody;
    }

    @Override
    public B2BJEBP1007ResponseV2.PptmBody withdrawal(B2BJEBP1007RequestV2 requestV2) {

        B2BJEBP1007ResponseV2.PptmBody pptmBody;
        try {
            B2BJEBP1007ResponseV2 b2BJEBP1007ResponseV2 = bocomApiService.sendToBocom(requestV2, BocomApiConstant.B2BJEBM_1007_URL);

            if (b2BJEBP1007ResponseV2.isSuccess() && b2BJEBP1007ResponseV2.getPptmBody() != null) {
                pptmBody = b2BJEBP1007ResponseV2.getPptmBody();
            } else {
                throw new BusinessException(CodeUtil.FAIL, b2BJEBP1007ResponseV2.getPptmHead().getReturnMsg());
            }

        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "登记簿提款失败！" + e.getMessage());
        }

        return pptmBody;
    }

    @Override
    public B2BJEBP1001ResponseV2.PptmBody transferAccounts(B2BJEBP1001RequestV2 requestV2) {
        B2BJEBP1001ResponseV2 b2BJEBP1001ResponseV2 = null;
        B2BJEBP1001ResponseV2.PptmBody pptmBody;
        try {
            b2BJEBP1001ResponseV2 = bocomApiService.sendToBocom(requestV2, BocomApiConstant.B2BJEBM_1001_URL);

            if (b2BJEBP1001ResponseV2.isSuccess() && b2BJEBP1001ResponseV2.getPptmBody() != null && b2BJEBP1001ResponseV2.getPptmBody().getTxnSts() != null) {
                pptmBody = b2BJEBP1001ResponseV2.getPptmBody();
            } else {
                throw new BusinessException(CodeUtil.FAIL, b2BJEBP1001ResponseV2.getPptmHead().getReturnMsg());
            }

        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "登记簿提款失败！" + b2BJEBP1001ResponseV2.getPptmHead().getReturnMsg());
        }

        return pptmBody;
    }

    @Override
    public B2BJEBM2001ResponseV1.PptmBody resetUrl(B2BJEBM2001RequestV1 requestV1) {
        B2BJEBM2001ResponseV1.PptmBody pptmBody;
        try {
            B2BJEBM2001ResponseV1 b2BJEBM2001ResponseV1 = bocomApiService.sendToBocom(requestV1, BocomApiConstant.B2BJEBM_2001_URL);

            if (b2BJEBM2001ResponseV1.isSuccess() && b2BJEBM2001ResponseV1.getPptmBody() != null && CollectionUtil.isNotEmpty(b2BJEBM2001ResponseV1.getPptmBody().getNotyQue())) {
                pptmBody = b2BJEBM2001ResponseV1.getPptmBody();
            } else {
                throw new BusinessException(CodeUtil.FAIL, b2BJEBM2001ResponseV1.getPptmHead().getReturnMsg());

            }

        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "重置url失败！" + e.getMessage());
        }

        return pptmBody;
    }

    @Override
    public ReceiptSingleTransferResponseV1 downloadNoticeFile(ReceiptSingleTransferRequestV1 requestV1) {
        ReceiptSingleTransferResponseV1 responseV1;
        try {
            responseV1 = bocomApiService.sendToBocom(requestV1, BocomApiConstant.RECEIPT_SINGLE_TRANSFER_URL);
            Boolean result = digestFile(requestV1.getDownloadPath(), responseV1.getFileName(), responseV1.getFileHashcode());
            if (!responseV1.isSuccess() && result) {
                throw new BusinessException(CodeUtil.FAIL, responseV1.getRspMsg());
            }

        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "交易通知书下载失败！" + e.getMessage());
        }
        return responseV1;

    }

    @Override
    public TradeDetailTransferResponseV1 downloadTradeDetailFile(TradeDetailTransferRequestV1 requestV1) {
        TradeDetailTransferResponseV1 responseV1 = null;
        try {
            responseV1 = bocomApiService.sendToBocom(requestV1, BocomApiConstant.TRADE_DETAIL_TRANSFER_URL);
            if ("S".equals(responseV1.getBizState())){
                Boolean result = digestDetailFile(requestV1.getDownloadPath(), responseV1.getFileName(), responseV1.getFileHashcode());
            }


        } catch (Exception e) {
            logger.error("综合明细单查询下载失败！" + e.getMessage());
        }
        return responseV1;
    }

    @Override
    public B2BJEBP1005ResponseV1.PptmBody rgsnBookThaw(B2BJEBP1005RequestV1 requestV1) {

        B2BJEBP1005ResponseV1 responseV1;
        try {
            responseV1 = bocomApiService.sendToBocom(requestV1, BocomApiConstant.B2BJEBM_1005_URL);
            if (responseV1 == null || !responseV1.isSuccess() || responseV1.getPptmBody() == null || responseV1.getPptmBody().getTxnSts() == null) {
                throw new BusinessException(CodeUtil.FAIL, responseV1.getRspMsg());
            }
        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "会员登记簿解冻失败！" + e.getMessage());
        }
        return responseV1.getPptmBody();
    }

    @Override
    public B2BJETP1007ResponseV1.PptmBody getHandlingFee(B2BJETP1007RequestV1 requestV1) {
        B2BJETP1007ResponseV1.PptmBody pptmBody;
        try {
            B2BJETP1007ResponseV1 responseV1 = bocomApiService.sendToBocom(requestV1, BocomApiConstant.B2BJETP_1007_URL);
            if (responseV1 == null || !responseV1.isSuccess() || responseV1.getPptmBody() == null || responseV1.getPptmBody().getPoundageAmt() == null) {
                throw new BusinessException(CodeUtil.FAIL, responseV1.getRspMsg());
            }
            pptmBody = responseV1.getPptmBody();
        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "银行转账手续费试算查询失败！" + e.getMessage());
        }
        return pptmBody;
    }

    @Override
    public B2BJEBP2001ResponseV2.PptmBody getTranserResult(B2BJEBP2001RequestV2 requestV2) {
        B2BJEBP2001ResponseV2.PptmBody pptmBody;
        try {
            B2BJEBP2001ResponseV2 responseV2 = bocomApiService.sendToBocom(requestV2, BocomApiConstant.B2BJEBP_2001_URL);
            if (responseV2 == null || !responseV2.isSuccess() || responseV2.getPptmBody() == null || responseV2.getPptmBody().getTxnSts() == null) {
                throw new BusinessException(CodeUtil.FAIL, responseV2.getRspMsg());
            }
            pptmBody = responseV2.getPptmBody();
        } catch (Exception e) {
            throw new BusinessException(CodeUtil.FAIL, "会员登记簿解冻失败！" + e.getMessage());
        }
        return pptmBody;
    }

    private Boolean digestFile(String filePath, String fileName, String fileHashcode) {
        if (!filePath.endsWith("/") || !filePath.endsWith("\\")) {
            filePath = filePath + "/";
        }
        String tempFileName = fileName + ".TMP";
        File file = new File(filePath + tempFileName);
        try {
            String digestFileHashcode = BocomDigest.fileDigest(filePath + tempFileName);
            if (!digestFileHashcode.equals(fileHashcode)) {
                file.delete();
                throw new BocomApiException("Bocom fileHashCode digest not passed.");
            }
            file.renameTo(new File(filePath + fileName));
            return true;
        } catch (Exception e) {
            e.printStackTrace();
        }
        return false;
    }

    private Boolean digestDetailFile(String filePath, String fileName, String fileHashcode) {
        if (!filePath.endsWith("/") || !filePath.endsWith("\\")) {
            filePath = filePath + "/";
        }
        String tempFileName = fileName + ".TMP";
        File file = new File(filePath + tempFileName);
        try {
            String digestFileHashcode = BocomDigest.fileDigest(filePath + tempFileName);
            if (!digestFileHashcode.equals(fileHashcode)) {
                file.delete();
                logger.error("Bocom fileHashCode digest not passed.");
            }
            file.renameTo(new File(filePath + fileName));
            return true;
        } catch (Exception e) {
            logger.error(e.getMessage());
            e.printStackTrace();
        }
        return false;
    }

}
