package com.sunxung.factoring.service.ledger.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.sunxung.factoring.component.exception.ValidatorException;
import com.sunxung.factoring.component.util.CodeUtil;
import com.sunxung.factoring.entity.entprise.Enterprise;
import com.sunxung.factoring.entity.ledger.LedgerAccountHisInfo;
import com.sunxung.factoring.entity.ledger.LedgerFundGoodsAssignHis;
import com.sunxung.factoring.entity.ledger.SupplierBankCardInfoHis;
import com.sunxung.factoring.entity.ledger.vo.LedgerAccountHisInfoVo;
import com.sunxung.factoring.entity.sys.Dictionary;
import com.sunxung.factoring.mapper.ledger.LedgerAccountHisInfoMapper;
import com.sunxung.factoring.service.entprise.IEnterpriseService;
import com.sunxung.factoring.service.ledger.ILedgerAccountHisInfoService;
import com.sunxung.factoring.service.ledger.ILedgerFundGoodsAssignHisService;
import com.sunxung.factoring.service.ledger.ISupplierBankCardInfoHisService;
import com.sunxung.factoring.service.sys.DictionaryService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 分账管理-基本信息表 服务实现类
 * </p>
 *
 * @author liutao
 * @since 2024-04-25
 */
@Service("ledger_createService")
public class LedgerAccountHisInfoServiceImpl extends ServiceImpl<LedgerAccountHisInfoMapper, LedgerAccountHisInfo>
        implements ILedgerAccountHisInfoService {

    @Autowired
    private ILedgerFundGoodsAssignHisService ledgerFundGoodsAssignHisService;
    @Autowired
    private ISupplierBankCardInfoHisService supplierBankCardInfoHisService;
    @Autowired
    private DictionaryService dictionaryService;
    @Autowired
    private IEnterpriseService enterpriseService;

    @Override
    public LedgerAccountHisInfoVo getView(Long id) {
        LedgerAccountHisInfo ledgerAccountHisInfo = getById(id);
        if (ledgerAccountHisInfo == null || ledgerAccountHisInfo.getId() == null) {
            throw new ValidatorException(CodeUtil.FAIL, "分账历史信息不能为空");
        }
        if (StringUtils.isNotBlank(ledgerAccountHisInfo.getLedgerType())) {
            Dictionary ledgerTypeDict = dictionaryService.getByCode(ledgerAccountHisInfo.getLedgerType());
            ledgerAccountHisInfo.setLedgerTypeDict(ledgerTypeDict);
        }
        if (ledgerAccountHisInfo.getEnterpriseId() != null) {
            Enterprise enterprise = enterpriseService.getById(ledgerAccountHisInfo.getEnterpriseId());
            if (enterprise != null && enterprise.getCorporateName() != null) {
                ledgerAccountHisInfo.setCustomerName(enterprise.getCorporateName());
            }
        }
        LedgerAccountHisInfoVo ledgerAccountHisInfoVo = new LedgerAccountHisInfoVo();
        ledgerAccountHisInfoVo.setLedgerAccountBasicInfo(ledgerAccountHisInfo);

        //货款分配
        List<LedgerFundGoodsAssignHis> goodsAssignHisList = ledgerFundGoodsAssignHisService.list(new QueryWrapper<LedgerFundGoodsAssignHis>()
                .eq("ledger_account_his_info_id", ledgerAccountHisInfo.getId()));
        ledgerAccountHisInfoVo.setGoodsAssignList(goodsAssignHisList);

        //关联的供应商账户
        List<SupplierBankCardInfoHis> supplierBankCardInfoHisList = supplierBankCardInfoHisService.list(new QueryWrapper<SupplierBankCardInfoHis>()
                .eq("ledger_account_his_info_id", ledgerAccountHisInfo.getId()));
        ledgerAccountHisInfoVo.setSupplierBankCardInfoList(supplierBankCardInfoHisList);
        return ledgerAccountHisInfoVo;
    }
}
