package com.sunxung.factoring.web.bocom;

import com.sunxung.factoring.component.annotation.OperationLog;
import com.sunxung.factoring.component.enums.OperationTypeEnum;
import com.sunxung.factoring.component.util.ConstantUtil;
import com.sunxung.factoring.component.util.ThreadLocalUtil;
import com.sunxung.factoring.entity.BaseSearch;
import com.sunxung.factoring.entity.GridPage;
import com.sunxung.factoring.entity.ResponseJson;
import com.sunxung.factoring.entity.bocom.register.BocomBasicInfo;
import com.sunxung.factoring.entity.bocom.register.vo.BocomSearchVo;
import com.sunxung.factoring.entity.bocom.register.vo.EnterpriseDetailVo;
import com.sunxung.factoring.entity.sys.User;
import com.sunxung.factoring.service.bocom.register.IBocomBasicInfoService;
import com.sunxung.factoring.service.sys.flowable.FlowableService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * 交行注册
 *
 * @author liutao
 * @since 2024-07-29
 */
@RestController
public class BocomRegisterController {

    @Resource(name = "bocomBasicInfoService")
    private IBocomBasicInfoService bocomBasicInfoService;

    @Autowired
    private FlowableService flowableService;

    /**
     * 获取企业人员信息
     * @param keyword
     * @return
     */
    @RequestMapping("getBusinessByKeyWord")
    public ResponseJson<EnterpriseDetailVo> getBasicDetailsByName(@RequestParam String keyword){
        EnterpriseDetailVo enterpriseDetailVo = bocomBasicInfoService.getBasicDetailsByName(keyword);
        return new ResponseJson(enterpriseDetailVo);
    }

    /**
     * 暂存 提交
     *
     * @param bocomBasicInfo
     * @return
     */
    @RequestMapping("bocom/register/add")
    @OperationLog(operationModule = "交行注册", operationType = OperationTypeEnum.INSERT, description = "B端用户提交")
    public ResponseJson addInfo(@RequestBody BocomBasicInfo bocomBasicInfo) {
        bocomBasicInfoService.add(bocomBasicInfo);
        return new ResponseJson();
    }

    /**
     * c端用户提交
     *
     * @param bocomBasicInfo
     * @return
     */
    @RequestMapping("api/bocom/register/process")
    @OperationLog(operationModule = "交行注册", operationType = OperationTypeEnum.INSERT, description = "C端用户提交")
    public ResponseJson process(@RequestBody BocomBasicInfo bocomBasicInfo) {
        ThreadLocalUtil.setUser(null);
        bocomBasicInfoService.process(bocomBasicInfo);
        return new ResponseJson();
    }

    /**
     * 获取详情
     *
     * @param id
     * @return
     */
    @RequestMapping("bocom/register/getDetail")
    public ResponseJson<BocomBasicInfo> getDetail(@RequestParam Long id) {
        BocomBasicInfo bocomBasicInfo = bocomBasicInfoService.getDetail(id);
        return new ResponseJson(bocomBasicInfo);
    }

    /**
     * 全部列表
     *
     * @param bocomSearchVo
     * @return
     */
    @RequestMapping("bocom/register/findBySearch")
    public GridPage<BocomBasicInfo> findBySearch(@RequestBody BocomSearchVo bocomSearchVo) {
        GridPage<BocomBasicInfo> bocomBasicInfos = bocomBasicInfoService.findBySearch(bocomSearchVo);
        return bocomBasicInfos;
    }

    /**
     * 当前登录人录入的数据
     *
     * @return
     */
    @RequestMapping("bocom/register/findUserData")
    public GridPage<BocomBasicInfo> findUserData(BaseSearch baseSearch){
        return bocomBasicInfoService.findUserData(baseSearch);
    }

    /**
     * 交行审核
     *
     * @param bocomBasicInfo
     * @return
     */
    @RequestMapping("api/bocom/register/approval")
    @OperationLog(operationModule = "交行注册", operationType = OperationTypeEnum.INSERT, description = "交行审核")
    public ResponseJson riskReview(@RequestBody BocomBasicInfo bocomBasicInfo) {
        //拾取task
        User user = ThreadLocalUtil.getUser();
        flowableService.claimTask(bocomBasicInfo.getTaskId(), user.getId(), ConstantUtil.RISK_CONTROL_OWNER);
        bocomBasicInfoService.riskReview(bocomBasicInfo);
        return new ResponseJson();
    }

    /**
     * 交行修改
     *
     * @param bocomBasicInfo
     * @return
     */
    @RequestMapping("api/bocom/register/upadte")
    @OperationLog(operationModule = "交行注册", operationType = OperationTypeEnum.INSERT, description = "交行修改")
    public ResponseJson update(@RequestBody BocomBasicInfo bocomBasicInfo) {
        bocomBasicInfoService.updateBocomInfo(bocomBasicInfo);
        return new ResponseJson("操作成功！");
    }

    /**
     * 交行变更
     *
     * @param bocomBasicInfo
     * @return
     */
    @RequestMapping("api/bocom/register/change")
    @OperationLog(operationModule = "交行注册", operationType = OperationTypeEnum.INSERT, description = "交行变更")
    public ResponseJson change(@RequestBody BocomBasicInfo bocomBasicInfo) {
        bocomBasicInfoService.changeBocomInfo(bocomBasicInfo);
        return new ResponseJson("操作成功！");
    }

    /**
     * 终止
     *
     * @param id
     * @return
     */
    @RequestMapping("api/bocom/register/termination")
    @OperationLog(operationModule = "交行注册", operationType = OperationTypeEnum.OTHER, description = "终止")
    public ResponseJson termination(Long id){
        bocomBasicInfoService.termination(id);
        return new ResponseJson();
    }

    /**
     * 重新查询会员信息
     *
     * @param id
     * @return
     */
    @RequestMapping("api/bocom/register/research")
    @OperationLog(operationModule = "交行注册", operationType = OperationTypeEnum.OTHER, description = "重新查询会员信息")
    public ResponseJson research(Long id){
        bocomBasicInfoService.research(id);
        return new ResponseJson();
    }


    /**
     *
     * 根据客户号查询生效中的账户信息
     * @param customerNumber
     * @return
     */
    @GetMapping("bocom/findByCustomerNumber")
    public ResponseJson findByCustomerNumber(@RequestParam String customerNumber) {
        return new ResponseJson(bocomBasicInfoService.findByCustomerNumber(customerNumber));
    }

    /**
     * 查询原因
     *
     * @param id
     * @return
     */
    @RequestMapping("api/bocom/register/findReason")
    @OperationLog(operationModule = "交行注册", operationType = OperationTypeEnum.OTHER, description = "重新查询会员信息")
    public ResponseJson<List<String>> findReason(Long id){
        List<String> reason = bocomBasicInfoService.getReason(id);
        return new ResponseJson(reason);
    }

    /**
     * 重置授权二维码
     *
     * @param id
     * @return
     */
    @RequestMapping("bocom/register/resetUrlAuthorized")
    public ResponseJson<BocomBasicInfo> resetUrlAuthorized(Long id) {
        return new ResponseJson(bocomBasicInfoService.resetUrlAuthorized(id));
    }


}
