package com.sunxung.factoring.web.bocom;

import com.sunxung.factoring.entity.ResponseJson;
import com.sunxung.factoring.entity.bocom.vipaccount.BocomVipAccountBasicInfo;
import com.sunxung.factoring.entity.bocom.vipaccount.BocomVipBindAccountInfo;
import com.sunxung.factoring.service.bocom.register.IBocomBasicInfoService;
import com.sunxung.factoring.service.bocom.vipaccount.IBocomVipAccountBasicInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * @Description 会员登记薄对外Controller
 * @Author Yafan Wang
 * @Date 2024/8/5 18:23
 */
@RestController
@RequestMapping("/api")
public class BocomVipAccountApiController {

    @Autowired
    private IBocomVipAccountBasicInfoService bocomVipAccountBasicInfoService;
    @Autowired
    private IBocomBasicInfoService bocomBasicInfoService;


    /**
     * 维护会员登记簿（新增/修改会员登记簿 修改会员登记薄静默户信息）
     *
     * @param basicInfo
     * @return
     */
    @PostMapping("/bocomVipAccount/doUpdate")
    public ResponseJson doAdd(@RequestBody BocomVipAccountBasicInfo basicInfo) {
        return new ResponseJson(bocomVipAccountBasicInfoService.autoMaintenanceVipRequest(basicInfo));
    }

    /**
     * 单个刷新会员登记簿信息
     *
     * @param id
     * @return
     */
    @GetMapping("/bocomVipAccount/refreshBocomVipBasic")
    public ResponseJson queryBocomVipBasic(@RequestParam Long id) {
        bocomVipAccountBasicInfoService.refreshBocomVipAccount(id);
        return new ResponseJson("操作成功！");
    }

    /**
     * 维护会员登记簿绑定账户信息
     *
     * @param bindAccountInfo
     * @return
     */
    @PostMapping("/bocomBindAccount/doUpdate")
    public ResponseJson doAdd(@RequestBody BocomVipBindAccountInfo bindAccountInfo) {
        return new ResponseJson(bocomVipAccountBasicInfoService.maintenanceVipBindAccount(bindAccountInfo));
    }

    /**
     * 重置授权二维码
     *
     * @param id
     * @return
     */
    @GetMapping("/bocomVipAccount/resetUrlAuthorized")
    public ResponseJson doAdd(@RequestParam Long id) {
        return new ResponseJson(bocomVipAccountBasicInfoService.resetUrl(id));
    }


    /**
     * 重置会员登记簿授权二维码
     *
     * @param vipAccountBasicInfo
     * @return
     */
    @PostMapping("/bindAccount/resetUrlAuthorized")
    public ResponseJson resetUrlAuthorized(@RequestBody BocomVipAccountBasicInfo vipAccountBasicInfo) {
        return new ResponseJson(bocomVipAccountBasicInfoService.resetUrlAuthorized(vipAccountBasicInfo));
    }


    /**
     * 重设入金激活金额
     *
     * @param bindAccountInfo
     * @return
     */
    @PostMapping("bocomBindAccount/resetActvtAmt")
    public ResponseJson resetActvtAmt(@RequestBody BocomVipBindAccountInfo bindAccountInfo) {
        return new ResponseJson(bocomVipAccountBasicInfoService.maintenanceVipBindAccount(bindAccountInfo));
    }
    /**
     *
     * 刷新静默户信息
     * @param id
     * @return
     */
    @PostMapping("bocomBindAccount/refreshSilentAccount")
    public ResponseJson refreshSilentAccount(@RequestParam Long id) {
        return new ResponseJson(bocomVipAccountBasicInfoService.autoQuerySilentAccount(null));
    }

    /**
     *
     * 刷新静默户信息
     * @param id
     * @return
     */
    @PostMapping("bocomRegister/resetUrlAuthorized")
    public ResponseJson resetUrlAuthorized(@RequestParam Long id) {
        return new ResponseJson(bocomBasicInfoService.resetUrlAuthorized(id));
    }


}
