package com.sunxung.factoring.web.bocom;

import com.sunxung.factoring.component.annotation.OperationLog;
import com.sunxung.factoring.component.enums.OperationTypeEnum;
import com.sunxung.factoring.entity.GridPage;
import com.sunxung.factoring.entity.ResponseJson;
import com.sunxung.factoring.entity.bocom.vipaccount.*;
import com.sunxung.factoring.entity.bocom.vipaccount.Search.BocomTransRecordsSearch;
import com.sunxung.factoring.entity.bocom.vipaccount.Search.VipAccountSearch;
import com.sunxung.factoring.service.bocom.vipaccount.IBocomVipAccountBasicInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @Description 会员登记薄Controller
 * @Date 2024/8/5 18:21
 */
@RestController
public class BocomVipAccountController {

    @Autowired
    private IBocomVipAccountBasicInfoService bocomVipAccountBasicInfoService;


    /**
     * 新增会员登记簿
     *
     * @param bocomBasicInfoId
     * @return
     */
    @GetMapping("bocomVipAccount/doAdd")
    @OperationLog(operationModule = "交行会员账户", operationType = OperationTypeEnum.INSERT, description = "新增会员登记簿")
    public ResponseJson doAdd(@RequestParam Long bocomBasicInfoId) {
        return new ResponseJson(bocomVipAccountBasicInfoService.doAdd(bocomBasicInfoId));
    }

    /**
     * 修改会员登记簿
     *
     * @param basicInfo
     * @return
     */
    @PostMapping("bocomVipAccount/doUpdate")
    @OperationLog(operationModule = "交行会员账户", operationType = OperationTypeEnum.INSERT, description = "修改会员登记簿")
    public ResponseJson doUpdate(@RequestBody BocomVipAccountBasicInfo basicInfo) {
        bocomVipAccountBasicInfoService.doUpdate(basicInfo);
        return new ResponseJson("操作成功！");
    }

    /**
     * 重新生成认证二维码
     *
     * @param id
     * @return
     */
    @GetMapping("bocomVipAccount/resetUrl")
    @OperationLog(operationModule = "交行会员账户", operationType = OperationTypeEnum.INSERT, description = "重新生成认证二维码")
    public ResponseJson resetUrl(Long id) {
        return new ResponseJson(bocomVipAccountBasicInfoService.resetUrl(id));
    }

    /**
     * 查看会员登记簿
     *
     * @param id
     * @return
     */
    @GetMapping("bocomVipAccount/getDetail")
    public ResponseJson<BocomVipAccountBasicInfo> getDetail(@RequestParam Long id) {
        return new ResponseJson(bocomVipAccountBasicInfoService.getDetail(id));
    }

    /**
     * 列表
     *
     * @param search
     * @return
     */
    @PostMapping("bocomVipAccount/list")
    public GridPage<BocomVipAccountBasicInfo> list(@RequestBody VipAccountSearch search) {
        return bocomVipAccountBasicInfoService.findBySearch(search);
    }


    /**
     * 获取当前登记簿下核验状态为正常的绑定银行卡信息
     *
     * @param id
     * @return
     */
    @GetMapping("bocomVipAccount/findAbnormalBindAccount")
    public ResponseJson<List<BocomVipBindAccountInfo>> findAbnormalBindAccount(@RequestParam Long id) {
        return new ResponseJson<>(bocomVipAccountBasicInfoService.findAbnormalBindAccount(id));
    }

    /**
     * 根据登记簿编号获取核验状态为非正常的绑定银行卡信息
     *
     * @param vipAccountNumber
     * @return
     */
    @GetMapping("bocomVipAccount/findAbnormalBindAccountByAccountNumber")
    public ResponseJson<BocomVipAccountBasicInfo> findAbnormalBindAccountByAccountNumber(@RequestParam String vipAccountNumber) {
        return new ResponseJson<>(bocomVipAccountBasicInfoService.findAbnormalBindAccountByAccountNumber(vipAccountNumber));
    }


    /**
     * 刷新单个登记簿状态
     *
     * @param id
     * @return
     */
    @GetMapping("bocomVipAccount/refreshBocomVipAccount")
    public ResponseJson refreshBocomVipAccount(@RequestParam Long id) {
        bocomVipAccountBasicInfoService.refreshBocomVipAccount(id);
        return new ResponseJson("操作成功！");
    }

    /**
     * 修改绑定实体卡信息
     *
     * @param bindAccountInfo
     * @return
     */
    @PostMapping("bocomVipAccount/updateBindAccount")
    @OperationLog(operationModule = "交行会员账户", operationType = OperationTypeEnum.INSERT, description = "修改绑定实体卡信息")
    public ResponseJson updateBindAccount(@RequestBody BocomVipBindAccountInfo bindAccountInfo) {
        bocomVipAccountBasicInfoService.updateBindAccount(bindAccountInfo);
        return new ResponseJson("操作成功！");
    }

    /**
     * 获取绑定的实体卡账户信息
     *
     * @param id 列表id
     * @return
     */
    @GetMapping("bocomVipAccount/getBindAccountInfoDetails")
    public ResponseJson<BocomVipAccountBasicInfo> getBindAccountInfoDetails(@RequestParam Long id) {
        return new ResponseJson(bocomVipAccountBasicInfoService.getBindAccountInfoDetails(id));
    }

    /**
     * 刷新单个绑定实体卡的状态
     *
     * @param id
     * @return
     */
    @GetMapping("bocomVipAccount/refreshBindAccountStatus")
    public ResponseJson refreshBindAccountStatus(@RequestParam Long id) {
        bocomVipAccountBasicInfoService.refreshBindAccountStatus(id);
        return new ResponseJson("操作成功！");
    }

    /**
     * 重设入金激活金额
     *
     * @param id
     * @return
     */
    @GetMapping("bocomVipAccount/resetActvtAmt")
    @OperationLog(operationModule = "交行会员账户", operationType = OperationTypeEnum.INSERT, description = "重设激活金额")
    public ResponseJson resetAtvtAmt(@RequestParam Long id) {
        bocomVipAccountBasicInfoService.resetActvtAmt(id);
        return new ResponseJson("操作成功！");
    }


    /**
     * 获取提现手续费
     *
     * @param isBocom 是否交通银行 1 是 0 否
     * @return
     */
    @GetMapping("bocomVipAccount/findReflectExchangeRate")
    public ResponseJson<BocomReflectExchangeRate> transferAccounts(@RequestParam Integer isBocom) {

        return new ResponseJson(bocomVipAccountBasicInfoService.findReflectExchangeRate(isBocom));
    }

    /**
     * 提现
     *
     * @param reflectRecord
     * @return
     */
    @PostMapping("bocomVipAccount/withdrawal")
    @OperationLog(operationModule = "交行会员账户", operationType = OperationTypeEnum.INSERT, description = "提现")
    public ResponseJson withdrawal(@RequestBody BocomVipAccountReflectRecord reflectRecord) {
        bocomVipAccountBasicInfoService.withdrawalAccounts(reflectRecord);
        return new ResponseJson("操作成功！");
    }

    /**
     * 手续费试算
     *
     * @param reflectRecord
     * @return
     */
    @PostMapping("bocomVipAccount/getHandlingFee")
    public ResponseJson getHandlingFee(@RequestBody BocomVipAccountReflectRecord reflectRecord) {
        return new ResponseJson(bocomVipAccountBasicInfoService.getHandlingFee(reflectRecord));
    }

    /**
     * 转账
     *
     * @param vipAccountBasicInfo
     * @return
     */
    @PostMapping("bocomVipAccount/transferAccounts")
    @OperationLog(operationModule = "交行会员账户", operationType = OperationTypeEnum.INSERT, description = "转账")
    public ResponseJson transferAccounts(@RequestBody BocomVipAccountBasicInfo vipAccountBasicInfo) {
        bocomVipAccountBasicInfoService.transferAccounts(vipAccountBasicInfo);
        return new ResponseJson("操作成功！");
    }

    /**
     * 下载交易通知书
     *
     * @param id
     * @return
     */
    @GetMapping("bocomVipAccount/downloadNoticeFile")
    @OperationLog(operationModule = "交行会员账户", operationType = OperationTypeEnum.INSERT, description = "下载交易通知书")
    public void downloadNoticeFile(@RequestParam Long id, HttpServletResponse response) {
        bocomVipAccountBasicInfoService.downloadNoticeFile(id, response);
    }

    /**
     * 综合明细单查询下载
     *
     * @param search
     * @return
     */
    @PostMapping("bocomVipAccount/downloadTradeDetailFile")
    @OperationLog(operationModule = "交行会员账户", operationType = OperationTypeEnum.INSERT, description = "下载综合明细单")
    public void downloadTradeDetailFile(@RequestBody BocomTransRecordsSearch search, HttpServletResponse response) {
        bocomVipAccountBasicInfoService.downloadTradeDetailFile(search, response);
    }

    /**
     * 查询状态
     *
     * @param id
     * @return
     */
    @GetMapping("bocomVipAccount/refreshTranserResultByPlfmSerNo")
    public void downloadTradeDetailFile(@RequestParam Long id) {
        bocomVipAccountBasicInfoService.refreshTranserResultByPlfmSerNo(id);
    }

    /**
     * 交易记录/账单流水条列表
     *
     * @param search
     * @return
     */
    @PostMapping("bocomVipAccount/transRecordsFindBySearch")
    public GridPage<BocomTransRecords> transRecordsFindBySearch(@RequestBody BocomTransRecordsSearch search) {
        return bocomVipAccountBasicInfoService.transRecordsFindBySearch(search);
    }

    /**
     * 处理交易记录
     * @param id
     * @return
     */
    @GetMapping("bocomVipAccount/transRecordHandleAll")
    @OperationLog(operationModule = "交行会员账户", operationType = OperationTypeEnum.INSERT, description = "处理交易记录")
    public ResponseJson transRecordHandleAll(@RequestParam Long id) {
        bocomVipAccountBasicInfoService.transRecordHandleAll(id);
        return new ResponseJson("操作成功！");
    }


}
