

DROP TABLE IF EXISTS `bocom_vip_account_basic_info`;
CREATE TABLE `bocom_vip_account_basic_info` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
	`bocom_basic_info_id` BIGINT ( 20 ) DEFAULT NULL COMMENT '交通银行客户信息表id',
	`account_number` char(50) DEFAULT NULL COMMENT '账号',
	`account_name` varchar(100) DEFAULT NULL COMMENT '账户名称',
	`account_alias` varchar(100) DEFAULT NULL COMMENT '账户别名',
	`account_status` TINYINT(3) DEFAULT NULL COMMENT '账户状态 1-生效 3-失效 ',
	`authorization_status` TINYINT(3) DEFAULT NULL COMMENT '授权状态 0-待用户授权 1-银行审核中 2-授权失败（用户拒绝）3-授权失败（银行拒绝）4-授权成功',
	`channel` varchar(50) DEFAULT NULL COMMENT '渠道',
	`source` varchar(50) DEFAULT NULL COMMENT '来源',
	`account_balance` decimal(17,4) DEFAULT '0.0000' COMMENT '账户余额',
	`available_balance` decimal(17,4) DEFAULT '0.0000' COMMENT '可用余额',
	`freeze_amount` decimal(17,4) DEFAULT '0.0000' COMMENT '冻结金额',
	`open_time` datetime DEFAULT NULL  COMMENT '开通时间',
  `expiring_date` datetime DEFAULT NULL COMMENT '失效日期',
	`currency` varchar(50) DEFAULT NULL COMMENT '币种',
  `user_create` varchar(32)  DEFAULT '' COMMENT '创建人',
  `user_modified` varchar(32)  DEFAULT '' COMMENT '修改人',
  `gmt_create` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `gmt_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员账户-基础信息';

DROP TABLE IF EXISTS `bocom_vip_limit_info`;
CREATE TABLE `bocom_vip_limit_info` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
	`bocom_vip_account_basic_info_id` BIGINT ( 20 ) DEFAULT NULL COMMENT '会员账户-基础信息表id',
	`inn_lmt_amt` decimal(17,4) DEFAULT '0.0000' COMMENT '内转限额',
	`out_lmt_amt` decimal(17,4) DEFAULT '0.0000' COMMENT '外转限额',
	`sgl_qta` decimal(17,4) DEFAULT '0.0000' COMMENT '单笔限额',
	`day_cum_qta` decimal(17,4) DEFAULT '0.0000' COMMENT '日累计限额',
	`wek_cum_qta` decimal(17,4) DEFAULT '0.0000' COMMENT '周累计限额',
	`mth_cum_qta` decimal(17,4) DEFAULT '0.0000' COMMENT '月笔限额',
	`qtr_cum_qta` decimal(17,4) DEFAULT '0.0000' COMMENT '季累计限额',
	`yr_cum_qta` decimal(17,4) DEFAULT '0.0000' COMMENT '年累计限额',
	`iae_ctl_flg` TINYINT(1) DEFAULT NULL COMMENT '收支管控标志 0-否 1-是',
	`inc_flg` TINYINT(3) DEFAULT NULL COMMENT '收入管控 1-无收入管控 2-仅对外收入 3-仅对内收入 4-禁止收入',
	`pay_flg` TINYINT(3) DEFAULT NULL COMMENT '支出管控 1-无支出管控 仅对外支出 3-仅对内支出4-禁止支出',
	`dwc_flg` TINYINT(1) DEFAULT NULL COMMENT '取现标志 0-否 1-是',
	`belong_institution` varchar(50) DEFAULT NULL COMMENT '归属机构',
	`atv_sts` TINYINT(1) DEFAULT NULL COMMENT '激活状态 0-否 1-是',
  `user_create` varchar(32)  DEFAULT '' COMMENT '创建人',
  `user_modified` varchar(32)  DEFAULT '' COMMENT '修改人',
  `gmt_create` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `gmt_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员账户-账户额度限制/其它状态表';


DROP TABLE IF EXISTS `bocom_vip_silent_account_info`;
CREATE TABLE `bocom_vip_silent_account_info` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
	`bocom_vip_account_basic_info_id` BIGINT ( 20 ) DEFAULT NULL COMMENT '会员账户-基础信息表id',
	`payer_account_name` varchar(100) DEFAULT '' COMMENT '付款方打款账户名称',
  `user_create` varchar(32)  DEFAULT '' COMMENT '创建人',
  `user_modified` varchar(32)  DEFAULT '' COMMENT '修改人',
  `gmt_create` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `gmt_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员账户-静默户信息表';

DROP TABLE IF EXISTS `bocom_vip_bind_account_info`;
CREATE TABLE `bocom_vip_bind_account_info` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
	`bocom_vip_account_basic_info_id` BIGINT ( 20 ) DEFAULT NULL COMMENT '会员账户-基础信息表id',
	`is_bank_of_communications` TINYINT(1) DEFAULT '1' COMMENT '是否为交通银行 0-是 1-否',
	`bank_name` varchar(50)  DEFAULT '' COMMENT '开户银行',
	`bind_acct_tp` TINYINT(1) DEFAULT '1' COMMENT '绑定账户类型 0-对公 1-个人',
	`bind_acct_no` varchar(50)  DEFAULT '' COMMENT '绑定账号',
	`bind_acct_no_acct_nme` varchar(50)  DEFAULT '' COMMENT '绑定账户名称',
	`bind_acct_bank_no` varchar(50)  DEFAULT '' COMMENT '绑定行号',
	`bind_acct_bank_nme` varchar(50)  DEFAULT '' COMMENT '绑定账户行名',
	`branch_bank_name` varchar(100)  DEFAULT NULL COMMENT '开户支行',
	`bind_sts` TINYINT(1) DEFAULT NULL COMMENT '核验状态 0-初态 1-正常 2-入金激活待确认 3-待出金验证 4-出金待确认 5-出金失败 6-未出金 7-验证失败 8-入金激活次数超限或超时',
	`bind_acc_sts` TINYINT(1) DEFAULT NULL COMMENT '绑定状态 0-流程中 1-可用 2-不可用（拒绝或解绑）',
	`manager_approver_sts` TINYINT(1) DEFAULT NULL COMMENT '账户绑定审批状态 0--无需审批，1--客户经理审批流程中，2--客户经理审批通过，3--客户经理审批拒绝，4--网银审批流程中，5--网银审批通过，6--网银审批拒绝',
	`actvt_amt` decimal(17,4) DEFAULT '0.0000' COMMENT '入金激活金额',
	`bind_account_illustrate` varchar(255) DEFAULT NULL COMMENT '账户说明',
  `user_create` varchar(32)  DEFAULT '' COMMENT '创建人',
  `user_modified` varchar(32)  DEFAULT '' COMMENT '修改人',
  `gmt_create` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `gmt_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员账户-绑定账户信息表';

DROP TABLE IF EXISTS `bocom_vip_account_reflect_record`;
CREATE TABLE `bocom_vip_account_reflect_record` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
	`bocom_vip_account_basic_info_id` BIGINT ( 20 ) DEFAULT NULL COMMENT '会员账户-基础信息表id',
	`bocom_vip_bind_account_info_id` BIGINT ( 20 ) DEFAULT NULL COMMENT '会员账户-绑定账户信息表id',
	`withdrawal_amt` decimal(17,4) DEFAULT '0.0000' COMMENT '提现金额（用户申请）',
	`poundage_amt` decimal(17,4) DEFAULT '0.0000' COMMENT '手续费',
	`elec_trs_fee` decimal(17,4) DEFAULT '0.0000' COMMENT '提现金额（实际）',
	`trans_no` varchar(100)  DEFAULT NULL COMMENT '内部流水号',
    `txn_sts` varchar(10) DEFAULT NULL COMMENT '交易状态 00-成功 01-失败 02-待查 03-待授权 04-授权拒绝 05-延时中',
	`remark` varchar(400)  DEFAULT '' COMMENT '备注',
  `user_create` varchar(32)  DEFAULT '' COMMENT '创建人',
  `user_modified` varchar(32)  DEFAULT '' COMMENT '修改人',
  `gmt_create` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `gmt_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员账户-提现记录表';


DROP TABLE IF EXISTS `bocom_vip_transfer_account_record`;
CREATE TABLE `bocom_vip_transfer_account_record` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
	`pay_bocom_vip_account_basic_info_id` BIGINT ( 20 ) DEFAULT NULL COMMENT '付款方会员账户-基础信息表id',
	`collection_bocom_vip_account_basic_info_id` BIGINT ( 20 ) DEFAULT NULL COMMENT '收款方会员账户-基础信息表id',
	`txn_amt` decimal(17,4) DEFAULT '0.0000' COMMENT '交易金额',
	`trans_no` varchar(100)  DEFAULT NULL COMMENT '内部流水号',
	`txn_sts` varchar(10) DEFAULT NULL COMMENT '交易状态 00-成功 01-失败 02-待查 03-待授权 04-授权拒绝 05-延时中',
	`remark` varchar(400)  DEFAULT '' COMMENT '备注',
  `user_create` varchar(32)  DEFAULT '' COMMENT '创建人',
  `user_modified` varchar(32)  DEFAULT '' COMMENT '修改人',
  `gmt_create` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `gmt_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员账户-转账记录表';

alter table bocom_vip_bind_account_info add `money_confirm_start_time` timestamp  NULL COMMENT '入金激活待确认状态开始时间';

DROP TABLE IF EXISTS `bocom_reflect_exchange_rate`;
CREATE TABLE `bocom_reflect_exchange_rate` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `is_bocom` TINYINT(1) DEFAULT NULL COMMENT '是否交通银行 1 是 0 否',
  `exchange_rate` decimal(17,2) DEFAULT NULL COMMENT '汇率',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='提现手续费率表';


INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountManage' ), 'menu', '会员账户管理', 'CyAccountMemberAccountManage', 1, NULL, NULL, '1', NULL, NULL,  now(),now());


INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '新增', 'addBocomVip', 0, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '查看', 'viewBocomVip', 1, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '修改', 'updateBocomVip', 2, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '删除', 'deleteBocomVip', 3, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '操作实体卡信息', 'bindAccount', 4, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '操作静默户信息', 'silentAccount', 5, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '交易记录', 'transactionRecords', 6, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '重设入金激活金额', 'resetActvtAmt', 7, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '重新查询会员信息', 'refreshBocomVipAccount', 8, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '数据全员可见', 'viewAllBocomVip', 9, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberAccountManage' ), 'button', '查看授权码', 'viewAuthCode', 10, NULL, NULL, NULL, NULL, NULL,  now(),now());


INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountManage' ), 'menu', '账户资金管理', 'CyAccountMemberFundManage', 2, NULL, NULL, '1', NULL, NULL,  now(),now());

INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberFundManage' ), 'button', '交易记录', 'transactionRecords2', 0, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberFundManage' ), 'button', '账单流水', 'billFlow', 1, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberFundManage' ), 'button', '提现', 'withdrawal', 2, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberFundManage' ), 'button', '转账', 'transferAccounts', 3, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberFundManage' ), 'button', '数据全员可见', 'viewAllBocomVipFund', 4, NULL, NULL, NULL, NULL, NULL,  now(),now());


alter table bocom_vip_account_basic_info add `plfm_ser_no` char(50) DEFAULT NULL COMMENT '新增会员登记簿的平台流水号';
alter table bocom_vip_account_basic_info add `chdbok_sts` TINYINT(3) DEFAULT NULL COMMENT '登记簿状态 1--可收可付2-销户 ';

INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('会员账户管理-渠道类型', NULL, 'bocomVipChannel', NULL, NULL, now(), now());
INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('交通银行', (select t.id from t_dictionary t where t.code = 'bocomVipChannel'), 'bocom', NULL, 0, now(), now());

alter table bocom_vip_silent_account_info add `silent_account_number` char(50) DEFAULT NULL COMMENT '静默户编号';



DROP TABLE IF EXISTS `bocom_vip_account_comprehensive_detail_file_rel`;
CREATE TABLE `bocom_vip_account_comprehensive_detail_file_rel` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
  `bocom_vip_account_basic_info_id` BIGINT (20) DEFAULT NULL COMMENT '会员账户-基础信息表id',
  `date` datetime DEFAULT NULL COMMENT '开始日期',
  `user_create` varchar(32)  DEFAULT '' COMMENT '创建人',
  `user_modified` varchar(32)  DEFAULT '' COMMENT '修改人',
  `gmt_create` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `gmt_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员账户-综合交易明细文件';

INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'transactionRecords2' ), 'button', '下载交易通知书', 'downloadTransferNoticeFile', 0, NULL, NULL, NULL, NULL, NULL,  now(),now());
INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'transactionRecords2' ), 'button', '查询状态', 'updateTransactionRecordsStatus', 1, NULL, NULL, NULL, NULL, NULL,  now(),now());

INSERT INTO `t_permission` ( `parentId`, `type`, `cname`, `ename`, `gradation`, `moduleName`, `url`, `icon`, `user_create`, `user_modified`, `gmt_create`, `gmt_modified`)
VALUES ( (select t.id from t_permission t where ename = 'CyAccountMemberFundManage' ), 'button', '综合明细查询下载', 'downloadComprehensiveDetailFile', 5, NULL, NULL, NULL, NULL, NULL,  now(),now());


alter table bocom_vip_silent_account_info add `balance` decimal(17,2) DEFAULT '0.00' COMMENT '余额';

alter table bocom_trans_records add `fund_source` varchar(50) DEFAULT NULL COMMENT '资金来源;

alter table bocom_vip_account_basic_info add `is_Inkasso` TINYINT(1) DEFAULT 0 COMMENT '是否长银登记簿 0 否 1 是';
alter table bocom_trans_records add `rel_plfm_pay_ordr_no` varchar(200) DEFAULT NULL COMMENT '关联支付订单号';

INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('交行交易记录-资金来源', NULL, 'bocomTransRecordsFundSource', NULL, NULL, now(), now());
INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('外部-->静默户', (select t.id from t_dictionary t where t.code = 'bocomTransRecordsFundSource'), 'outsideToSilent', NULL, 0, now(), now());
INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('静默户-->静默户', (select t.id from t_dictionary t where t.code = 'bocomTransRecordsFundSource'), 'silentToSilent', NULL, 1, now(), now());
INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('静默户-->登记簿', (select t.id from t_dictionary t where t.code = 'bocomTransRecordsFundSource'), 'silentToVipAccount', NULL, 2, now(), now());
INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('登记簿-->长银登记簿', (select t.id from t_dictionary t where t.code = 'bocomTransRecordsFundSource'), 'vipAccountToInkasso', NULL, 3, now(), now());
INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('登记簿-->登记簿', (select t.id from t_dictionary t where t.code = 'bocomTransRecordsFundSource'), 'vipAccountToVipAccount', NULL, 4, now(), now());
INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('长银登记簿-->登记簿', (select t.id from t_dictionary t where t.code = 'bocomTransRecordsFundSource'), 'InkassoToVipAccount', NULL, 5, now(), now());
INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('外部-->登记簿', (select t.id from t_dictionary t where t.code = 'bocomTransRecordsFundSource'), 'outsideToVipAccount', NULL, 6, now(), now());
INSERT INTO `t_dictionary` (`name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ('登记簿-->实体卡', (select t.id from t_dictionary t where t.code = 'bocomTransRecordsFundSource'), 'vipAccountToBankCard', NULL, 7, now(), now());

alter table bocom_trans_records add `account_type` TINYINT(1) DEFAULT NULL COMMENT '账户类型 0 静默户 1 登记簿';

alter table bocom_vip_account_basic_info add `legal_authorization_status` TINYINT(3) DEFAULT NULL COMMENT '法人授权状态 0-待用户授权 1-银行审核中 2-授权失败（用户拒绝）3-授权失败（银行拒绝）4-授权成功';
alter table bocom_vip_account_basic_info add `account_status_real` varchar(100) DEFAULT '' COMMENT '账户状态（真实）';

INSERT INTO `t_dictionary` ( `name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ( '交行会员登记簿状态', NULL, 'bocomVipAccountStatus', NULL, null, now(),now());
INSERT INTO `t_dictionary` ( `name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ( '生效', (select t.id from t_dictionary t where t.code = 'bocomVipAccountStatus'), 'vipAccountEffect', NULL, 0,now(),now());
INSERT INTO `t_dictionary` ( `name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ( '待生效', (select t.id from t_dictionary t where t.code = 'bocomVipAccountStatus'), 'vipAccountPendingEffect', NULL, 1,now(),now());
INSERT INTO `t_dictionary` ( `name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ( '失效', (select t.id from t_dictionary t where t.code = 'bocomVipAccountStatus'), 'vipAccountPendingExpire', NULL, 2,now(),now());
INSERT INTO `t_dictionary` ( `name`, `parentId`, `code`, `value`, `gradation`, `gmt_create`, `gmt_modified`)
VALUES ( '开通失败', (select t.id from t_dictionary t where t.code = 'bocomVipAccountStatus'), 'vipAccountOpeningFailed', NULL, 3,now(),now());

alter table bocom_vip_bind_account_info add `money_confirm_time` timestamp  NULL COMMENT '激活时间';


DROP TABLE IF EXISTS `bocom_vip_account_notice_info`;
CREATE TABLE `bocom_vip_account_notice_info` (
  `id` bigint(20) unsigned NOT NULL AUTO_INCREMENT,
	`bocom_vip_account_basic_info_id` BIGINT ( 20 ) DEFAULT NULL COMMENT '会员账户-基础信息表id',
	`qr_code` longtext COMMENT '授权二维码',
  `qr_code_effect_time` timestamp NULL DEFAULT NULL COMMENT '授权二维码生效时间',
  `notice_object` varchar(10) DEFAULT NULL COMMENT '通知推送对象  1-法人 2-授权代理人 3-个人',
  `user_create` varchar(32)  DEFAULT '' COMMENT '创建人',
  `user_modified` varchar(32)  DEFAULT '' COMMENT '修改人',
  `gmt_create` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `gmt_modified` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='会员账户-通知推送表';